//  File vs10xx.h
//
//  For more details about the product please check http://www.seeedstudio.com/depot/
//  Copyright (c) 2012 seeed technology inc.
//  Author: Frankie.Chu
//  Version: 2.0
//  Time: June 2, 2012
//  Changing records:
//
//  This library is free software; you can redistribute it and/or
//  modify it under the terms of the GNU Lesser General Public
//  License as published by the Free Software Foundation; either
//  version 2.1 of the License, or (at your option) any later version.
//
//  This library is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//  Lesser General Public License for more details.
//
//  You should have received a copy of the GNU Lesser General Public
//  License along with this library; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA


#ifndef VS10XX_H
#define VS10XX_H
#include <SPI.h>
#include "pins_config.h"

/** VS10xx SCI Write Command byte is 0x02 */
#define VS_WRITE_COMMAND 0x02
/** VS10xx SCI Read Command byte is 0x03 */
#define VS_READ_COMMAND 0x03


#define SPI_MODE	0x0   /**< VS10xx register */
#define SPI_STATUS	0x1   /**< VS10xx register */
#define SPI_BASS	0x2   /**< VS10xx register */
#define SPI_CLOCKF	0x3   /**< VS10xx register */
#define SPI_DECODE_TIME	0x4   /**< VS10xx register */
#define SPI_AUDATA	0x5   /**< VS10xx register */
#define SPI_WRAM	0x6   /**< VS10xx register */
#define SPI_WRAMADDR	0x7   /**< VS10xx register */
#define SPI_HDAT0	0x8   /**< VS10xx register */
#define SPI_HDAT1	0x9   /**< VS10xx register */
#define SPI_AIADDR	0xa   /**< VS10xx register */
#define SPI_VOL		0xb   /**< VS10xx register */
#define SPI_AICTRL0	0xc   /**< VS10xx register */
#define SPI_AICTRL1	0xd   /**< VS10xx register */
#define SPI_AICTRL2	0xe   /**< VS10xx register */
#define SPI_AICTRL3	0xf   /**< VS10xx register */

#define SM_DIFF		0x01   /**< VS10xx register */
#define SM_JUMP		0x02   /**< VS10xx register */
#define SM_RESET	0x04   /**< VS10xx register */
#define SM_OUTOFWAV	0x08   /**< VS10xx register */
#define SM_PDOWN	0x10   /**< VS10xx register */
#define SM_TESTS	0x20   /**< VS10xx register */
#define SM_STREAM	0x40   /**< VS10xx register */
#define SM_PLUSV	0x80   /**< VS10xx register */
#define SM_DACT		0x100   /**< VS10xx register */
#define SM_SDIORD	0x200   /**< VS10xx register */
#define SM_SDISHARE	0x400   /**< VS10xx register */
#define SM_SDINEW	0x800   /**< VS10xx register */
#define SM_ADPCM        0x1000   /**< VS10xx register */
#define SM_ADPCM_HP     0x2000   /**< VS10xx register */
class VS10XX : public SPIClass
{
public:
  void selectControlBus(void)   { digitalWrite(VS_XCS, LOW);}
  void deselectControlBus(void) { digitalWrite(VS_XCS, HIGH);}
  void selectDataBus(void)      { digitalWrite(VS_XDCS, LOW);}
  void deselectDataBus(void)    { digitalWrite(VS_XDCS, HIGH);}
  void putInReset(void)         { digitalWrite(VS_XRESET, LOW);}
  void releaseFromReset(void)   { digitalWrite(VS_XRESET, HIGH);}
  char readDREQ(void) { return digitalRead(VS_DREQ);}
  void init(void);
  void initForMidiFmt(void);
  void loadMidiPlugin(void);
  void initIO(void);
  void writeRegister(unsigned char addressbyte, unsigned char highbyte, unsigned char lowbyte);
  void writeRegister(unsigned char addressbyte, unsigned int value);
  void writeData(unsigned char *databuf, unsigned char = 32); //write 32 bytes to vs1053
  unsigned int readRegister(unsigned char addressbyte); /** Read the 16-bit value of a VS10xx register */
  void reset(void); //reset for vs10xx
  void softReset(void); /* Soft Reset of VS10xx (Between songs) */
  void setVolume(unsigned char leftchannel, unsigned char rightchannel); /* Set VS10xx Volume Register */
  void sendZerosToVS10xx(void); /** Send 2048 zeros. \todo Timeouts for all DREQ busy loop waits! */
private:

};
extern VS10XX vs1053;



/* For recording func */
#if defined(__AVR_ATmega1280__)|| defined(__AVR_ATmega2560__)

#ifndef SKIP_PLUGIN_VARNAME
#define PLUGIN_SIZE 13675
PROGMEM const unsigned short plugin[13675] = { /* Compressed plugin */
#endif
  0x0007, 0x0001, 0xc01a, 0x0006, 0x0001, 0x0002, 0x0007, 0x0001, /*    0 */
  0x1800, 0x0006, 0x8006, 0x0000, 0x0007, 0x0001, 0x8034, 0x0006, /*    8 */
  0x003a, 0x0000, 0x1350, 0xf400, 0x5404, 0x0000, 0x0811, 0xf400, /*   10 */
  0x5644, 0xf400, 0x5404, 0xf400, 0x5648, 0xf400, 0x5404, 0xf400, /*   18 */
  0x5654, 0xf400, 0x5404, 0xf400, 0x5640, 0x0000, 0x800a, 0x000c, /*   20 */
  0x0000, 0x0006, 0xc010, 0xb182, 0xa3c0, 0x0030, 0x0251, 0x3900, /*   28 */
  0x6000, 0x0030, 0x0691, 0x3900, 0x4024, 0x0000, 0x0090, 0x0000, /*   30 */
  0x4000, 0x3810, 0x0024, 0x0000, 0x4200, 0x3800, 0x0024, 0x2900, /*   38 */
  0x4c40, 0x0006, 0x2016, 0x2a00, 0x040e, 0x2a00, 0x144e, 0x2a00, /*   40 */
  0x218e, 0x2a00, 0x314e, 0x0007, 0x0001, 0x8010, 0x0006, 0x001e, /*   48 */
  0x3009, 0x3851, 0x3e14, 0xf812, 0x3e11, 0xb817, 0x0000, 0x00d7, /*   50 */
  0x0020, 0x03d2, 0x3704, 0xc024, 0x0030, 0x0551, 0x3009, 0x0e06, /*   58 */
  0x3911, 0x8e06, 0x3961, 0x9bcc, 0x3f04, 0xc024, 0x36f1, 0x9817, /*   60 */
  0x36f4, 0xd812, 0x2100, 0x0000, 0x3904, 0x5bd1, 0x0007, 0x0001, /*   68 */
  0x8051, 0x0006, 0x006a, 0x3e02, 0xb857, 0x3e02, 0x7848, 0x3e08, /*   70 */
  0x3861, 0x3e08, 0xb863, 0x3e00, 0x7840, 0x0030, 0x0417, 0x3700, /*   78 */
  0x0024, 0x0000, 0x0201, 0x6012, 0x0024, 0x0006, 0xc017, 0x2800, /*   80 */
  0x1a95, 0x0000, 0x03c1, 0x3e04, 0x3811, 0x3009, 0x1fd0, 0x0023, /*   88 */
  0xffd1, 0x3083, 0x1c41, 0x3009, 0x3c10, 0xf400, 0x4400, 0x6100, /*   90 */
  0x8017, 0x0030, 0x0211, 0x0003, 0xffc1, 0xb010, 0x2457, 0x3900, /*   98 */
  0x0024, 0x2808, 0x1980, 0x3604, 0x1bd1, 0x6012, 0x0024, 0x0006, /*   a0 */
  0xc017, 0x2808, 0x16d5, 0x0000, 0x3ec1, 0x3e04, 0x3851, 0x3e00, /*   a8 */
  0xb803, 0x0030, 0x03d1, 0x3100, 0x9fc0, 0xb214, 0x9c41, 0x6010, /*   b0 */
  0x4010, 0x3009, 0x0000, 0x2800, 0x1e45, 0x003f, 0xc001, 0x2800, /*   b8 */
  0x1fc0, 0xb010, 0x0024, 0x0000, 0x0010, 0x3010, 0x0024, 0xb006, /*   c0 */
  0x0000, 0x0000, 0x0024, 0x2800, 0x2085, 0xb010, 0x0024, 0x0000, /*   c8 */
  0x0103, 0xc030, 0x0024, 0xc204, 0x0024, 0x3900, 0x8024, 0x3600, /*   d0 */
  0x9bc3, 0x2808, 0x1980, 0x3604, 0x1bd1, 0x0007, 0x0001, 0x8086, /*   d8 */
  0x0006, 0x0022, 0x3e14, 0x3811, 0x3e14, 0xb813, 0x3e05, 0x3815, /*   e0 */
  0x0030, 0x10d1, 0x3115, 0x0024, 0x3105, 0x4024, 0x0000, 0x0091, /*   e8 */
  0x0020, 0x03d3, 0x3104, 0x8024, 0x3009, 0x2a14, 0x3605, 0x2a15, /*   f0 */
  0x3904, 0x9bd5, 0x0030, 0x0711, 0x36f4, 0x9813, 0x3604, 0x0024, /*   f8 */
  0x2100, 0x0000, 0x3904, 0x5bd1, 0x0007, 0x0001, 0x8097, 0x0006, /*  100 */
  0x0032, 0x3e14, 0x3811, 0x3e10, 0x7803, 0x0000, 0x3fc1, 0xb010, /*  108 */
  0xb802, 0x0000, 0x0010, 0x3010, 0x8024, 0x6924, 0x03c1, 0x0000, /*  110 */
  0x0203, 0x2800, 0x2b15, 0xa036, 0x2042, 0x0006, 0xbfd7, 0xc010, /*  118 */
  0x9c10, 0x0023, 0xffd1, 0x3009, 0x2200, 0x3009, 0x3c50, 0xf400, /*  120 */
  0x4400, 0x3009, 0x1c01, 0x6010, 0x0024, 0x0003, 0xffc1, 0xb016, /*  128 */
  0x0024, 0x0030, 0x0250, 0x3800, 0xdbc2, 0x36f0, 0x5803, 0x2000, /*  130 */
  0x0000, 0x36f4, 0x1811, 0x0007, 0x0001, 0x0000, 0x0006, 0x8002, /*  138 */
  0x0000, 0x0007, 0x0001, 0x0100, 0x0006, 0x80cc, 0x0000, 0x0007, /*  140 */
  0x0001, 0x80b0, 0x0006, 0x002a, 0x3e11, 0xb807, 0x3009, 0x384a, /*  148 */
  0x3e11, 0x3805, 0x3e10, 0xb803, 0x3e00, 0x4442, 0x0001, 0x800a, /*  150 */
  0xbf8e, 0x8443, 0xfe06, 0x0045, 0x3011, 0x0401, 0x545e, 0x0385, /*  158 */
  0x525e, 0x2040, 0x72ce, 0x1bc1, 0x48ba, 0x9803, 0x4588, 0x4885, /*  160 */
  0x6fee, 0x1bc2, 0x4ffe, 0x9805, 0xf6fe, 0x1bc4, 0xf7f0, 0x2046, /*  168 */
  0x3801, 0xdbca, 0x2000, 0x0000, 0x36f1, 0x9807, 0x0007, 0x0001, /*  170 */
  0x80c5, 0x0006, 0x0082, 0x3e12, 0xb817, 0x3e12, 0x7808, 0x3e18, /*  178 */
  0x3821, 0x3e18, 0xb823, 0x3e10, 0x7800, 0x48b2, 0x0024, 0x3e10, /*  180 */
  0x7800, 0x3e10, 0xf802, 0x3e14, 0x3815, 0x3e14, 0xb813, 0x3e04, /*  188 */
  0x7814, 0x0030, 0x0717, 0x3f05, 0xc024, 0x0001, 0x800a, 0x0030, /*  190 */
  0x11d1, 0x0000, 0x4697, 0x3110, 0x9fd2, 0x3100, 0xdc53, 0x3a80, /*  198 */
  0x9c10, 0x3a80, 0xc024, 0x3009, 0x3f12, 0x3009, 0x1c00, 0x4090, /*  1a0 */
  0x0024, 0x3009, 0x3fc0, 0x2800, 0x3f55, 0x3009, 0x1c40, 0x3009, /*  1a8 */
  0x3c80, 0x3013, 0x1fd5, 0x3009, 0x1d00, 0x3613, 0x1c01, 0x3e22, /*  1b0 */
  0xb806, 0x3e11, 0x3805, 0x3e13, 0xb80d, 0xbd86, 0xb814, 0xbe8a, /*  1b8 */
  0x384f, 0x0000, 0x0054, 0x2914, 0x39c0, 0x0028, 0x32d1, 0x0000, /*  1c0 */
  0x0490, 0x0000, 0x4711, 0x2900, 0x2c00, 0x4186, 0x188c, 0x0000, /*  1c8 */
  0x0550, 0x0000, 0x4711, 0x2900, 0x2c00, 0x4380, 0x4001, 0x0006, /*  1d0 */
  0x0011, 0x0022, 0xffd3, 0x003e, 0x0010, 0x3110, 0x8012, 0x3100, /*  1d8 */
  0xc014, 0x0003, 0x0015, 0x3483, 0x2a00, 0x6d96, 0xb001, 0x39f0, /*  1e0 */
  0xe012, 0x3900, 0x8024, 0x0030, 0x06d7, 0x3f15, 0xc024, 0x36f4, /*  1e8 */
  0x5814, 0x36f4, 0x9813, 0x36f4, 0x1815, 0x36f0, 0xd802, 0x36f0, /*  1f0 */
  0x5800, 0x2808, 0x1980, 0x2210, 0x0000, 0x0007, 0x0001, 0x8106, /*  1f8 */
  0x0006, 0x0056, 0x3613, 0x0024, 0x3e12, 0x0024, 0x3e05, 0xb814, /*  200 */
  0x3615, 0x0024, 0x3e00, 0x7842, 0x3e00, 0xf810, 0x003f, 0xfe03, /*  208 */
  0x34c3, 0x0024, 0x3410, 0x4024, 0xf110, 0x10d0, 0x6094, 0x0024, /*  210 */
  0x4294, 0x0024, 0x0000, 0x0040, 0x2800, 0x46c5, 0x0000, 0x0024, /*  218 */
  0x3000, 0x184c, 0x2900, 0x25c0, 0xa030, 0x0024, 0x3010, 0x184c, /*  220 */
  0x2900, 0x25c0, 0x0000, 0x4448, 0xb100, 0x0001, 0x003f, 0xfe00, /*  228 */
  0x2800, 0x4885, 0x3009, 0x184c, 0x2900, 0x25c0, 0xa100, 0x0024, /*  230 */
  0x3613, 0x0024, 0x0030, 0x03d0, 0x6890, 0x0001, 0xb100, 0x1bcc, /*  238 */
  0x0000, 0x01d0, 0x2800, 0x4a45, 0x6890, 0x0024, 0x3800, 0x0024, /*  240 */
  0xb880, 0x9810, 0x36f0, 0xc024, 0x36f0, 0x5802, 0x3405, 0x9014, /*  248 */
  0x36f3, 0x0024, 0x36f2, 0x0024, 0x2000, 0x0000, 0x0000, 0x0024, /*  250 */
  0x0007, 0x0001, 0x8131, 0x0006, 0x00d8, 0x0015, 0xbd51, 0x0007, /*  258 */
  0x9250, 0xb880, 0x184c, 0x3e12, 0x0024, 0x3e05, 0xb814, 0x3615, /*  260 */
  0x0024, 0x3800, 0x0024, 0x0030, 0x0290, 0x3800, 0x0024, 0x0000, /*  268 */
  0x01c0, 0x2915, 0x8300, 0x0006, 0xc050, 0x0000, 0x0300, 0xb882, /*  270 */
  0x0024, 0x2914, 0xbec0, 0x0006, 0x6410, 0x0020, 0x0040, 0x0006, /*  278 */
  0x6550, 0x3800, 0x184c, 0x0006, 0x6410, 0x3800, 0x0024, 0x0000, /*  280 */
  0x4180, 0x0000, 0x0190, 0x3800, 0x0024, 0x0000, 0x0100, 0x2900, /*  288 */
  0x6f40, 0x3e00, 0x0024, 0x0000, 0x3c00, 0x0030, 0x03d0, 0x3000, /*  290 */
  0x5bcc, 0xb102, 0x0024, 0x0000, 0x0200, 0xa100, 0x0024, 0x0000, /*  298 */
  0x0084, 0x2800, 0x55c5, 0x0000, 0x4412, 0x0002, 0x1fd0, 0x3800, /*  2a0 */
  0x0024, 0x0003, 0x0001, 0x0000, 0x4510, 0x3613, 0x0000, 0x0030, /*  2a8 */
  0x1090, 0x3800, 0x0024, 0x0006, 0xc610, 0x3009, 0x0000, 0x3009, /*  2b0 */
  0x2001, 0x2908, 0xbe80, 0x3009, 0x0805, 0x0030, 0x0692, 0x0001, /*  2b8 */
  0xf403, 0x3009, 0x2000, 0x0000, 0x4fc0, 0x6891, 0xa002, 0x3223, /*  2c0 */
  0x0024, 0x3a00, 0x0024, 0x0030, 0x0492, 0x3a00, 0x0024, 0x0000, /*  2c8 */
  0x4452, 0x3009, 0x0901, 0x3009, 0x0800, 0xff82, 0x0024, 0x48b2, /*  2d0 */
  0x0024, 0xff34, 0x0024, 0xf1c6, 0x0024, 0x48ba, 0x0024, 0x2915, /*  2d8 */
  0x8600, 0x4ed6, 0x0024, 0x0030, 0x1190, 0x0004, 0x0001, 0x4090, /*  2e0 */
  0x904c, 0xc100, 0x984c, 0x3800, 0x0024, 0x0002, 0x1600, 0x3e15, /*  2e8 */
  0x13cc, 0x2900, 0xe240, 0x3e00, 0x0024, 0x0000, 0x0010, 0x3000, /*  2f0 */
  0x1b8c, 0x6080, 0x0024, 0x0000, 0x0024, 0x2800, 0x61c5, 0x0000, /*  2f8 */
  0x0024, 0x2900, 0x25c0, 0xb880, 0x184c, 0x2900, 0x25c0, 0xb880, /*  300 */
  0x184c, 0x0000, 0x0081, 0x6890, 0x0024, 0x0030, 0x06d0, 0x3800, /*  308 */
  0x0024, 0x0030, 0x03d0, 0x3000, 0x8024, 0xc212, 0x0024, 0x3800, /*  310 */
  0x4024, 0x0030, 0x0710, 0x3800, 0x0024, 0x0000, 0x0100, 0x0030, /*  318 */
  0x0010, 0x3000, 0x4024, 0xb100, 0x0024, 0x003f, 0xfec1, 0x2800, /*  320 */
  0x6445, 0x0000, 0x0024, 0x3000, 0x0024, 0xb010, 0x0024, 0x3800, /*  328 */
  0x0024, 0x2908, 0x0b80, 0x0000, 0x6448, 0x0007, 0x0001, 0x4110, /*  330 */
  0x0006, 0x000c, 0xbb80, 0xac44, 0xbb80, 0x0004, 0x0005, 0x0002, /*  338 */
  0x0001, 0x0040, 0x53ff, 0x80cb, 0x0100, 0x6a9c, 0x0007, 0x0001, /*  340 */
  0x0004, 0x0006, 0x8014, 0x0000, 0x0007, 0x0001, 0x411c, 0x0006, /*  348 */
  0x0009, 0x801c, 0x7fe4, 0x8039, 0x804e, 0x7fb2, 0x809d, 0x809c, /*  350 */
  0x7f64, 0x8139, 0x0007, 0x0001, 0x819d, 0x0006, 0x0040, 0x3e12, /*  358 */
  0x0024, 0x3e05, 0xb814, 0x3615, 0x0024, 0x3e00, 0x7842, 0x0004, /*  360 */
  0x8d01, 0xb884, 0x3852, 0xf400, 0x4412, 0x3243, 0x0024, 0x3204, /*  368 */
  0x0024, 0x2901, 0x5680, 0x0015, 0x9e00, 0x0000, 0x0710, 0x3800, /*  370 */
  0x184c, 0x0001, 0x5e40, 0x3e10, 0x0024, 0x0000, 0x7e40, 0x3e10, /*  378 */
  0x0024, 0x3204, 0x8024, 0x3e04, 0x888c, 0x3200, 0x0024, 0xf400, /*  380 */
  0x4008, 0x2000, 0x0000, 0x0000, 0x6d08, 0xf400, 0x4400, 0x36d3, /*  388 */
  0x0024, 0x36f4, 0x8024, 0x36f0, 0x5802, 0x3405, 0x9014, 0x36f3, /*  390 */
  0x0024, 0x36f2, 0x0024, 0x2000, 0x0000, 0x0000, 0x0024, 0x0007, /*  398 */
  0x0001, 0x01cc, 0x0006, 0x0322, 0x0000, 0x0001, 0x0001, 0x0001, /*  3a0 */
  0x0002, 0x0001, 0x0003, 0x0001, 0x0004, 0x0001, 0x0000, 0x0000, /*  3a8 */
  0xffff, 0xffff, 0xffff, 0x0001, 0x0001, 0x0005, 0xffff, 0xffff, /*  3b0 */
  0x0002, 0x0001, 0x0006, 0xffff, 0xffff, 0x0003, 0x0001, 0x0007, /*  3b8 */
  0xffff, 0xffff, 0x0007, 0x0001, 0x0008, 0xffff, 0xffff, 0x001f, /*  3c0 */
  0x0001, 0x0009, 0xffff, 0xffff, 0x0627, 0x0007, 0x000a, 0x000b, /*  3c8 */
  0x000c, 0x4f67, 0x6753, 0x0002, 0x0000, 0x0000, 0x0000, 0x0000, /*  3d0 */
  0x7856, 0x3412, 0x0000, 0x0000, 0xd80b, 0xd586, 0x011e, 0x0176, /*  3d8 */
  0x6f72, 0x6269, 0x7300, 0x0000, 0x0002, 0x44ac, 0x0000, 0x0000, /*  3e0 */
  0x0000, 0x580f, 0x0200, 0x0000, 0x0000, 0xb801, 0x4f67, 0x6753, /*  3e8 */
  0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x7856, 0x3412, 0x0100, /*  3f0 */
  0x0000, 0x27de, 0x7a38, 0x0138, 0x0376, 0x6f72, 0x6269, 0x7310, /*  3f8 */
  0x0000, 0x0056, 0x4c53, 0x4920, 0x536f, 0x6c75, 0x7469, 0x6f6e, /*  400 */
  0x204f, 0x7901, 0x0000, 0x0014, 0x0000, 0x0045, 0x4e43, 0x4f44, /*  408 */
  0x4552, 0x3d56, 0x5331, 0x3035, 0x3320, 0x7631, 0x2e35, 0x3001, /*  410 */
  0x4f67, 0x6753, 0x0000, 0x0000, 0x0000, 0x0000, 0x0000, 0x7856, /*  418 */
  0x3412, 0x0200, 0x0000, 0x11a1, 0xcb59, 0x05ff, 0xffff, 0xffcf, /*  420 */
  0x0576, 0x6f72, 0x6269, 0x730d, 0x4243, 0x5601, 0x0040, 0x0000, /*  428 */
  0x2649, 0x9224, 0x4992, 0x2449, 0x9224, 0x4992, 0x2ccb, 0xb22c, /*  430 */
  0xcbb2, 0x2ccb, 0xb22c, 0xcbb2, 0x344d, 0xd334, 0x4dd3, 0x344d, /*  438 */
  0xd334, 0x4dd3, 0x344d, 0xd334, 0x4dd3, 0x344d, 0xd334, 0x4dd3, /*  440 */
  0x80d0, 0x9055, 0x0000, 0x1000, 0x8045, 0x5114, 0xc771, 0x1c49, /*  448 */
  0x9224, 0xcbb2, 0x2c4d, 0xd334, 0xcff3, 0x3c51, 0x1445, 0xd334, /*  450 */
  0x4d55, 0x5555, 0xd775, 0x5d59, 0x9665, 0xdbb6, 0x6d5d, 0xd775, /*  458 */
  0xdff7, 0x7d61, 0x1886, 0x6118, 0x8620, 0x3464, 0x1500, 0x0004, /*  460 */
  0x0060, 0x5114, 0xc571, 0x1c47, 0x9224, 0xc9b2, 0x2c4b, 0xd334, /*  468 */
  0xcdf3, 0x3c4f, 0x1445, 0xd134, 0x4d53, 0x5555, 0xd575, 0x5d57, /*  470 */
  0x9665, 0xd9b6, 0x6d5b, 0xd775, 0xddf7, 0x7d5f, 0x1886, 0x6118, /*  478 */
  0x8621, 0x080d, 0x5905, 0x0000, 0x0100, 0x5814, 0x4571, 0x1cc7, /*  480 */
  0x9124, 0x49b2, 0x2ccb, 0xd234, 0x4df3, 0x3ccf, 0x1345, 0x5134, /*  488 */
  0x4dd3, 0x5455, 0x5575, 0x5dd7, 0x9565, 0x59b6, 0x6ddb, 0xd675, /*  490 */
  0x5df7, 0x7ddf, 0x1786, 0x6118, 0x8661, 0x0842, 0x4356, 0x0100, /*  498 */
  0x4000, 0x0016, 0x4551, 0x1cc7, 0x7124, 0x4992, 0x2ccb, 0xb234, /*  4a0 */
  0x4dd3, 0x3ccf, 0xf344, 0x5114, 0x4dd3, 0x3455, 0x5555, 0x5dd7, /*  4a8 */
  0x7565, 0x5996, 0x6ddb, 0xb675, 0x5dd7, 0x7ddf, 0xf785, 0x6118, /*  4b0 */
  0x8661, 0x1882, 0xd090, 0x1501, 0x4014, 0x0080, 0xcff3, 0x3ccb, /*  4b8 */
  0xf33c, 0xcfb3, 0x3ccb, 0xb13c, 0xcbf3, 0x3ccf, 0xb33c, 0xcff3, /*  4c0 */
  0x3ccb, 0xb31c, 0xcbb3, 0x3ccb, 0xb11c, 0xc3d2, 0x2ccd, 0xd33c, /*  4c8 */
  0xcdf2, 0x3ccf, 0xf33c, 0xcff3, 0x3ccf, 0xf33c, 0xcff3, 0x2ccf, /*  4d0 */
  0xf33c, 0xcff3, 0x3ccf, 0xf33c, 0x4f00, 0x0040, 0x8003, 0x0040, /*  4d8 */
  0x8005, 0x5268, 0xc84a, 0x0020, 0x0300, 0xc066, 0x3996, 0x6639, /*  4e0 */
  0x8aa3, 0x498a, 0xa248, 0x9ae4, 0x489a, 0xa759, 0x9a27, 0x0000, /*  4e8 */
  0x60c0, 0x0100, 0x20c0, 0x04a2, 0x5168, 0xc84a, 0x0020, 0x0600, /*  4f0 */
  0xc066, 0x5996, 0x6569, 0x9a65, 0x4996, 0xa559, 0x96e4, 0x4896, /*  4f8 */
  0x6549, 0x8ee3, 0x4896, 0x6549, 0x9264, 0x599a, 0x6559, 0x96a5, /*  500 */
  0x699a, 0x6559, 0x9a26, 0x0000, 0x70c0, 0x0100, 0x20c0, 0x04a2, /*  508 */
  0xb116, 0x1ab2, 0x0a00, 0x7800, 0x00f0, 0x6996, 0xe428, 0x86a1, /*  510 */
  0x3892, 0xa569, 0x9e00, 0x00e0, 0x0207, 0x0080, 0x001b, 0x1032, /*  518 */
  0x5476, 0x98ba, 0xdc2e, 0x3464, 0x1500, 0xf003, 0x0060, 0x1886, /*  520 */
  0xdfd7, 0x75db, 0x9665, 0xd755, 0x55d3, 0x1445, 0xcfd3, 0x34cb, /*  528 */
  0x9224, 0xc751, 0x1445, 0x711c, 0x49b2, 0x2c4d, 0xf33c, 0x5134, /*  530 */
  0x4d55, 0x755d, 0x59b6, 0x6d5d, 0xf77d, 0x5f18, 0x8601, 0x00f0, /*  538 */
  0x090e, 0x0000, 0x0156, 0x8040, 0x1888, 0xc238, 0x9044, 0x5998, /*  540 */
  0xc679, 0xa048, 0x9aa8, 0xcaba, 0xb04c, 0xdbb8, 0xcefb, 0xc050, /*  548 */
  0x1cc9, 0xd23c, 0xd154, 0x5dd9, 0xd67d, 0xe158, 0x9ee9, 0xdabe, /*  550 */
  0xf15c, 0xdff9, 0xde17, 0x1ab2, 0x1200, 0x0807, 0x0070, 0x9aa6, /*  558 */
  0x699a, 0xa669, 0x9aa6, 0x699a, 0xa669, 0x9aa6, 0x699a, 0xa269, /*  560 */
  0x9aa6, 0x699a, 0xa669, 0x9aa6, 0x298a, 0xa269, 0x9aa6, 0x699a, /*  568 */
  0xa669, 0x9aa2, 0x288a, 0xa669, 0x9aa6, 0x699a, 0xa669, 0x8aa2, /*  570 */
  0x258a, 0xa669, 0x9aa6, 0x699a, 0xa628, 0x5a96, 0x258a, 0xa669, /*  578 */
  0x9aa6, 0x698a, 0xa265, 0x5996, 0x288a, 0xa669, 0x9aa6, 0x288a, /*  580 */
  0x9625, 0x5896, 0x288a, 0xa669, 0x9aa6, 0x288a, 0x9665, 0x89a2, /*  588 */
  0x689a, 0xa669, 0x9aa6, 0x288a, 0x9628, 0x8aa6, 0x699a, 0xa669, /*  590 */
  0x9aa6, 0x288a, 0xa268, 0x9aa6, 0x699a, 0xa669, 0x9aa6, 0x288a, /*  598 */
  0xa669, 0x9aa6, 0x699a, 0xa669, 0x9aa6, 0x689a, 0xa669, 0x9aa6, /*  5a0 */
  0x699a, 0xa669, 0x9aa6, 0x699a, 0xa669, 0x9aa6, 0x699a, 0xa669, /*  5a8 */
  0x9aa6, 0x699a, 0xa669, 0x0a00, 0x4eac, 0x7000, 0x107e, 0xb001, /*  5b0 */
  0x2143, 0x6587, 0xa9cb, 0xed42, 0x4356, 0x0200, 0xe100, 0x005e, /*  5b8 */
  0xd755, 0x5555, 0x5555, 0x5555, 0x5dd7, 0x755d, 0x5555, 0x55d5, /*  5c0 */
  0x5455, 0x5555, 0x5dd7, 0x5555, 0x5555, 0x4dd3, 0x5455, 0x5555, /*  5c8 */
  0x5d55, 0x5555, 0xd534, 0x4dd3, 0x5455, 0x5555, 0x5555, 0x554d, /*  5d0 */
  0xd3d4, 0x4cd3, 0x5455, 0x5555, 0x55d5, 0x344d, 0x4dd3, 0x4cd3, /*  5d8 */
  0x5455, 0x5555, 0x4dd3, 0xd434, 0x47d3, 0x4cd3, 0x5455, 0xd534, /*  5e0 */
  0x4d4d, 0x7304, 0x47d3, 0x4cd3, 0x5455, 0xd534, 0x4d4d, 0x7334, /*  5e8 */
  0xd334, 0x4d55, 0x5555, 0xd534, 0x4d53, 0x334d, 0xd354, 0x5555, /*  5f0 */
  0x5555, 0xd534, 0x4dd3, 0x344d, 0x5555, 0x5555, 0x5555, 0xd534, /*  5f8 */
  0x4dd3, 0x5455, 0x5555, 0x5d55, 0x5555, 0xd534, 0x4d55, 0x5555, /*  600 */
  0xd575, 0x5d55, 0x5555, 0xd554, 0x5555, 0x555d, 0xd775, 0x5d55, /*  608 */
  0x5555, 0x5555, 0x55d5, 0x755d, 0x0100, 0xa40d, 0x0e00, 0xe007, /*  610 */
  0x3620, 0x64a8, 0xec30, 0x75b9, 0x5d68, 0xc82a, 0x00e0, 0x0100, /*  618 */
  0xc0e3, 0x388e, 0xe338, 0x8ae3, 0x388e, 0xe338, 0x0200, 0x800b, /*  620 */
  0x1c00, 0x0002, 0x6c40, 0xc850, 0xd961, 0xea72, 0xbbd0, 0x9095, /*  628 */
  0x0040, 0x0c00, 0x80c5, 0x7465, 0x59b6, 0x4dc5, 0x9134, 0xd595, /*  630 */
  0x1dc5, 0xb144, 0x5596, 0x1c49, 0xf24c, 0xd9b3, 0x2c4b, 0x1365, /*  638 */
  0x55f1, 0x34cd, 0xb35d, 0x5735, 0x4511, 0x0000, 0x0041, 0x0000, /*  640 */
  0x8308, 0x1191, 0x9999, 0x0101, 0x4000, 0x0c00, 0x820f, 0xc4a0, /*  648 */
  0x1120, 0x2828, 0x02d3, 0x0292, 0x0300, 0x2244, 0x8888, 0xcccc, /*  650 */
  0xcccc, 0xcc80, 0x0020, 0x0006, 0x00c1, 0xfa05, 0x0468, 0x2100, /*  658 */
  0x0232, 0x3a12, 0xc000, 0x0628, 0x3082, 0x9170, 0xbcf2, 0x2075, /*  660 */
  0x1000, 0x0000, 0x0000, 0x0600, 0xf000, 0x0060, 0x3440, 0x4444, /*  668 */
  0x5c81, 0xc101, 0x4282, 0xc202, 0x4300, 0x0000, 0x0000, 0xc000, /*  670 */
  0xc007, 0x0080, 0xd100, 0x1111, 0x7105, 0x0607, 0x0809, 0x0a0b, /*  678 */
  0x0c01, 0x0080, 0x0002, 0x0000, 0x0000, 0x2080, 0x0004, 0x0404, /*  680 */
  0x0000, 0x0000, 0x0002, 0x0000, 0x0004, 0x0400, 0x0000, 0x0000, /*  688 */
  0x0000, 0x0000, 0x000d, 0x0000, 0x0000, 0x0005, 0x0006, 0x0000, /*  690 */
  0x0001, 0x0009, 0x0003, 0x0000, 0x0002, 0x0003, 0x0009, 0x0002, /*  698 */
  0x0001, 0x0006, 0x0001, 0x0000, 0x0003, 0x000a, 0x0004, 0x0003, /*  6a0 */
  0x0002, 0x0002, 0x0007, 0x0002, 0x0004, 0x0007, 0x000b, 0x0004, /*  6a8 */
  0x0001, 0x000b, 0x0002, 0x0005, 0x0003, 0x0004, 0x0005, 0x0006, /*  6b0 */
  0x0002, 0x000c, 0x0008, 0x0007, 0x0004, 0x0008, 0x000a, 0x0004, /*  6b8 */
  0x0008, 0x000d, 0x000c, 0x0008, 0x0001, 0x0001, 0x0006, 0x804c, /*  6c0 */
  0x0000, 0x0006, 0x0048, 0x0012, 0x0000, 0x0000, 0x0009, 0x0009, /*  6c8 */
  0x0000, 0x0001, 0x0005, 0x0004, 0x0000, 0x0002, 0x000a, 0x000d, /*  6d0 */
  0x0002, 0x0001, 0x0003, 0x0002, 0x0000, 0x0003, 0x000b, 0x0006, /*  6d8 */
  0x0003, 0x0002, 0x0006, 0x000b, 0x0002, 0x0004, 0x000c, 0x000f, /*  6e0 */
  0x0004, 0x0001, 0x0011, 0x0001, 0x0000, 0x0005, 0x0002, 0x0003, /*  6e8 */
  0x0005, 0x0003, 0x000d, 0x0005, 0x0003, 0x0006, 0x0007, 0x0007, /*  6f0 */
  0x0006, 0x0002, 0x000e, 0x000a, 0x0002, 0x0007, 0x0004, 0x000c, /*  6f8 */
  0x0007, 0x0004, 0x000f, 0x000e, 0x0004, 0x0008, 0x0008, 0x0010, /*  700 */
  0x0008, 0x0001, 0x0010, 0x0008, 0x000c, 0x0002, 0x0012, 0x0011, /*  708 */
  0x0010, 0x0001, 0x0001, 0x0006, 0x8034, 0x0000, 0x0006, 0x0017, /*  710 */
  0x000e, 0x0080, 0x005f, 0x0060, 0x0155, 0x002b, 0x0002, 0x000c, /*  718 */
  0x04b6, 0x0000, 0x0004, 0x0008, 0x000c, 0x0010, 0x0018, 0x0020, /*  720 */
  0x0028, 0x002d, 0x0034, 0x0040, 0x0050, 0x0064, 0x0080, 0x0006, /*  728 */
  0x8012, 0x0000, 0x0006, 0x000e, 0x0002, 0x0006, 0x000a, 0x000e, /*  730 */
  0x0014, 0x001c, 0x0024, 0x002a, 0x0030, 0x003a, 0x0048, 0x005a, /*  738 */
  0x0072, 0x0080, 0x0006, 0x8012, 0x0000, 0x0006, 0x000e, 0x0199, /*  740 */
  0x03a2, 0x0627, 0x0800, 0x0a00, 0x0b6d, 0x0b6d, 0x0b6d, 0x0d55, /*  748 */
  0x0d55, 0x0d55, 0x1000, 0x1000, 0x1000, 0x0006, 0x8012, 0x0000, /*  750 */
  0x0006, 0x0030, 0x0002, 0x0000, 0x0000, 0x01cc, 0x0003, 0x0000, /*  758 */
  0x0001, 0x01ce, 0x0004, 0x0000, 0x0001, 0x01ce, 0x0005, 0x0000, /*  760 */
  0x0002, 0x01d0, 0x0006, 0x0000, 0x0002, 0x01d0, 0x0007, 0x0000, /*  768 */
  0x0002, 0x01d0, 0x0008, 0x0000, 0x0002, 0x01d0, 0x0009, 0x0000, /*  770 */
  0x0003, 0x01d2, 0x000a, 0x0000, 0x0003, 0x01d2, 0x000b, 0x0000, /*  778 */
  0x0003, 0x01d2, 0x000c, 0x0000, 0x0003, 0x01d2, 0x000d, 0x0000, /*  780 */
  0x0003, 0x01d2, 0x0006, 0x8056, 0x0000, 0x0006, 0x0002, 0x7ffc, /*  788 */
  0x7ffc, 0x0006, 0x8060, 0x0000, 0x0006, 0x001c, 0x0013, 0x0400, /*  790 */
  0x02fe, 0x0300, 0x002a, 0x015c, 0x0002, 0x0011, 0x0536, 0x0000, /*  798 */
  0x0004, 0x0008, 0x000c, 0x0010, 0x0018, 0x0020, 0x0028, 0x003c, /*  7a0 */
  0x005f, 0x008c, 0x00c8, 0x0118, 0x0168, 0x01c2, 0x023a, 0x02bc, /*  7a8 */
  0x0352, 0x0400, 0x0006, 0x800d, 0x0000, 0x0006, 0x0013, 0x0002, /*  7b0 */
  0x0006, 0x000a, 0x000e, 0x0014, 0x001c, 0x0024, 0x0032, 0x004d, /*  7b8 */
  0x0075, 0x00aa, 0x00f0, 0x0140, 0x0195, 0x01fe, 0x027b, 0x0307, /*  7c0 */
  0x03a9, 0x0400, 0x0006, 0x800d, 0x0000, 0x0006, 0x000a, 0x0155, /*  7c8 */
  0x02aa, 0x0355, 0x037a, 0x037a, 0x03a2, 0x0400, 0x0471, 0x06aa, /*  7d0 */
  0x0800, 0x0006, 0x8009, 0x0a00, 0x0006, 0x800d, 0x0000, 0x0006, /*  7d8 */
  0x0044, 0x0002, 0x0000, 0x0000, 0x01cc, 0x0003, 0x0000, 0x0001, /*  7e0 */
  0x01ce, 0x0004, 0x0000, 0x0001, 0x01ce, 0x0005, 0x0000, 0x0002, /*  7e8 */
  0x01d0, 0x0006, 0x0000, 0x0002, 0x01d0, 0x0007, 0x0000, 0x0002, /*  7f0 */
  0x01d0, 0x0008, 0x0000, 0x0002, 0x01d0, 0x0009, 0x0000, 0x0003, /*  7f8 */
  0x01d2, 0x000a, 0x0000, 0x0003, 0x01d2, 0x000b, 0x0000, 0x0003, /*  800 */
  0x01d2, 0x000c, 0x0000, 0x0003, 0x01d2, 0x000d, 0x0000, 0x0003, /*  808 */
  0x01d2, 0x000e, 0x0000, 0x0003, 0x01d2, 0x000f, 0x0000, 0x0003, /*  810 */
  0x01d2, 0x0010, 0x0000, 0x0003, 0x01d2, 0x0011, 0x0000, 0x0003, /*  818 */
  0x01d2, 0x0012, 0x0000, 0x0003, 0x01d2, 0x0006, 0x8042, 0x0000, /*  820 */
  0x0006, 0x0002, 0x7ffc, 0x7ffc, 0x0006, 0x8060, 0x0000, 0x0006, /*  828 */
  0x0009, 0x010f, 0x0000, 0x0000, 0x0000, 0x0000, 0xac44, 0x0000, /*  830 */
  0x0002, 0x0005, 0x0006, 0x8006, 0x0000, 0x0006, 0x0006, 0x0080, /*  838 */
  0x0400, 0xbdc0, 0xc140, 0x0007, 0x000a, 0x0006, 0x8007, 0x0000, /*  840 */
  0x0006, 0x0010, 0x0010, 0x0020, 0x0000, 0x0005, 0x000d, 0x0007, /*  848 */
  0x01d6, 0x0000, 0xffd9, 0xffff, 0x0000, 0xf000, 0x0000, 0x0000, /*  850 */
  0x05b6, 0x0707, 0x0006, 0x8080, 0x0000, 0x0007, 0x0001, 0x4125, /*  858 */
  0x0006, 0x0928, 0x0001, 0x0001, 0x0040, 0x0000, 0x0003, 0x0001, /*  860 */
  0x0000, 0x01f7, 0x0000, 0x0000, 0x0000, 0x0040, 0x0000, 0x0000, /*  868 */
  0x0001, 0x0001, 0x0001, 0x0040, 0x0000, 0x0001, 0x0001, 0x0000, /*  870 */
  0x0277, 0x0000, 0x0000, 0x0000, 0x0040, 0x0000, 0x0000, 0x0001, /*  878 */
  0x0001, 0x0001, 0x0040, 0x0000, 0x0000, 0x0001, 0x0000, 0x02f7, /*  880 */
  0x0000, 0x0000, 0x0000, 0x0040, 0x0000, 0x0000, 0x0001, 0x0001, /*  888 */
  0x0001, 0x0040, 0x0000, 0x0000, 0x0001, 0x0000, 0x0377, 0x0000, /*  890 */
  0x0000, 0x0000, 0x0040, 0x0000, 0x0000, 0x0001, 0x0001, 0x0001, /*  898 */
  0x0040, 0x0000, 0x0000, 0x0001, 0x0000, 0x03f7, 0x0000, 0x0000, /*  8a0 */
  0x0000, 0x0040, 0x0000, 0x0000, 0x0001, 0x0002, 0x0004, 0x0051, /*  8a8 */
  0x0000, 0x0001, 0x0000, 0x0002, 0x0477, 0x0001, 0xffff, 0x0001, /*  8b0 */
  0x0003, 0x0000, 0x0000, 0x0001, 0x0002, 0x0002, 0x0019, 0x0000, /*  8b8 */
  0x0000, 0x0002, 0x0000, 0x0519, 0x0001, 0xfffe, 0x0001, 0x0005, /*  8c0 */
  0x0000, 0x0000, 0x0001, 0x0002, 0x0002, 0x0031, 0x0000, 0x0001, /*  8c8 */
  0x0002, 0x0001, 0x054b, 0x0001, 0xfffd, 0x0001, 0x0007, 0x0000, /*  8d0 */
  0x0000, 0x0001, 0x0002, 0x0001, 0x000f, 0x0000, 0x0001, 0x0000, /*  8d8 */
  0x0000, 0x05ad, 0x0001, 0xfff9, 0x0001, 0x000f, 0x0000, 0x0000, /*  8e0 */
  0x0001, 0x0002, 0x0001, 0x003f, 0x0000, 0x0002, 0x0000, 0x0000, /*  8e8 */
  0x05cb, 0x0001, 0xffe1, 0x0001, 0x003f, 0x0000, 0x0000, 0x0001, /*  8f0 */
  0x0002, 0x0002, 0x00e1, 0x0000, 0x0000, 0x0000, 0x0004, 0x0649, /*  8f8 */
  0x0001, 0xfff9, 0x00e1, 0x000f, 0x0000, 0x0000, 0x0001, 0x0002, /*  900 */
  0x0002, 0x00e1, 0x0000, 0x0000, 0x0000, 0x0002, 0x080b, 0x0001, /*  908 */
  0xfff9, 0x000f, 0x000f, 0x0000, 0x0000, 0x0001, 0x0002, 0x0001, /*  910 */
  0x000f, 0x0000, 0x0003, 0x0000, 0x0000, 0x09cd, 0x0001, 0xfff9, /*  918 */
  0x0001, 0x000f, 0x0000, 0x0000, 0x0001, 0x0004, 0x0002, 0x0031, /*  920 */
  0x0000, 0x0001, 0x0001, 0x0001, 0x09eb, 0x0000, 0x0000, 0x0000, /*  928 */
  0x0007, 0x0000, 0x0000, 0x0001, 0x0000, 0x1400, 0x0010, 0x1400, /*  930 */
  0x0008, 0x1400, 0x0018, 0x1400, 0x0004, 0x1400, 0x0014, 0x1400, /*  938 */
  0x000c, 0x1400, 0x001c, 0x1400, 0x0002, 0x1400, 0x0012, 0x1400, /*  940 */
  0x000a, 0x1400, 0x001a, 0x1400, 0x0006, 0x1400, 0x0016, 0x1400, /*  948 */
  0x000e, 0x1400, 0x001e, 0x1400, 0x0001, 0x1800, 0x0021, 0x1800, /*  950 */
  0x0011, 0x1800, 0x0031, 0x1800, 0x0009, 0x1800, 0x0029, 0x1800, /*  958 */
  0x0019, 0x1800, 0x0039, 0x1800, 0x0005, 0x1800, 0x0025, 0x1800, /*  960 */
  0x0015, 0x1800, 0x0035, 0x1800, 0x000d, 0x1800, 0x002d, 0x1800, /*  968 */
  0x001d, 0x1800, 0x003d, 0x1800, 0x0003, 0x1c00, 0x0043, 0x1c00, /*  970 */
  0x0023, 0x1c00, 0x0063, 0x1c00, 0x0013, 0x1c00, 0x0053, 0x1c00, /*  978 */
  0x0033, 0x1c00, 0x0073, 0x1c00, 0x000b, 0x1c00, 0x004b, 0x1c00, /*  980 */
  0x002b, 0x1c00, 0x006b, 0x1c00, 0x001b, 0x1c00, 0x005b, 0x1c00, /*  988 */
  0x003b, 0x1c00, 0x007b, 0x1c00, 0x0007, 0x1c00, 0x0047, 0x1c00, /*  990 */
  0x0027, 0x1c00, 0x0067, 0x1c00, 0x0017, 0x1c00, 0x0057, 0x1c00, /*  998 */
  0x0037, 0x1c00, 0x0077, 0x1c00, 0x000f, 0x1c00, 0x004f, 0x1c00, /*  9a0 */
  0x002f, 0x1c00, 0x006f, 0x1c00, 0x001f, 0x1c00, 0x005f, 0x1c00, /*  9a8 */
  0x003f, 0x1c00, 0x007f, 0x1c00, 0x0000, 0x0c00, 0x0004, 0x0c00, /*  9b0 */
  0x0002, 0x0c00, 0x0006, 0x0c00, 0x0001, 0x1000, 0x0009, 0x1000, /*  9b8 */
  0x0005, 0x1000, 0x000d, 0x1000, 0x0003, 0x1400, 0x0013, 0x1400, /*  9c0 */
  0x000b, 0x1400, 0x001b, 0x1400, 0x0007, 0x1800, 0x0027, 0x1800, /*  9c8 */
  0x0017, 0x1800, 0x0037, 0x1800, 0x000f, 0x1c00, 0x004f, 0x1c00, /*  9d0 */
  0x002f, 0x1c00, 0x006f, 0x1c00, 0x001f, 0x2000, 0x009f, 0x2000, /*  9d8 */
  0x005f, 0x2000, 0x00df, 0x2000, 0x003f, 0x2400, 0x013f, 0x2400, /*  9e0 */
  0x00bf, 0x2400, 0x01bf, 0x2400, 0x007f, 0x2800, 0x027f, 0x2800, /*  9e8 */
  0x017f, 0x2800, 0x037f, 0x2800, 0x00ff, 0x2c00, 0x04ff, 0x2c00, /*  9f0 */
  0x02ff, 0x2c00, 0x06ff, 0x2c00, 0x01ff, 0x3000, 0x09ff, 0x3000, /*  9f8 */
  0x05ff, 0x3000, 0x0dff, 0x3000, 0x03ff, 0x3400, 0x13ff, 0x3400, /*  a00 */
  0x0bff, 0x3400, 0x1bff, 0x3400, 0x07ff, 0x3800, 0x27ff, 0x3800, /*  a08 */
  0x17ff, 0x3800, 0x37ff, 0x3800, 0x0fff, 0x3c00, 0x4fff, 0x3c00, /*  a10 */
  0x2fff, 0x3c00, 0x6fff, 0x3c00, 0x1fff, 0x4000, 0x9fff, 0x4000, /*  a18 */
  0x5fff, 0x4000, 0xdfff, 0x4000, 0x3fff, 0x4400, 0x3fff, 0x4401, /*  a20 */
  0xbfff, 0x4400, 0xbfff, 0x4401, 0x7fff, 0x4400, 0x7fff, 0x4401, /*  a28 */
  0xffff, 0x4400, 0xffff, 0x4401, 0x0000, 0x0c00, 0x0004, 0x0c00, /*  a30 */
  0x0002, 0x0c00, 0x0006, 0x0c00, 0x0001, 0x1000, 0x0009, 0x1000, /*  a38 */
  0x0005, 0x1000, 0x000d, 0x1000, 0x0003, 0x1400, 0x0013, 0x1400, /*  a40 */
  0x000b, 0x1400, 0x001b, 0x1400, 0x0007, 0x1800, 0x0027, 0x1800, /*  a48 */
  0x0017, 0x1800, 0x0037, 0x1800, 0x000f, 0x1c00, 0x004f, 0x1c00, /*  a50 */
  0x002f, 0x1c00, 0x006f, 0x1c00, 0x001f, 0x2000, 0x009f, 0x2000, /*  a58 */
  0x005f, 0x2000, 0x00df, 0x2000, 0x003f, 0x2400, 0x013f, 0x2400, /*  a60 */
  0x00bf, 0x2400, 0x01bf, 0x2400, 0x007f, 0x2800, 0x027f, 0x2800, /*  a68 */
  0x017f, 0x2800, 0x037f, 0x2800, 0x00ff, 0x2c00, 0x04ff, 0x2c00, /*  a70 */
  0x02ff, 0x2c00, 0x06ff, 0x2c00, 0x01ff, 0x3000, 0x09ff, 0x3000, /*  a78 */
  0x05ff, 0x3000, 0x0dff, 0x3000, 0x03ff, 0x3400, 0x13ff, 0x3400, /*  a80 */
  0x0bff, 0x3400, 0x1bff, 0x3400, 0x07ff, 0x3800, 0x27ff, 0x3800, /*  a88 */
  0x17ff, 0x3800, 0x37ff, 0x3800, 0x0fff, 0x3c00, 0x4fff, 0x3c00, /*  a90 */
  0x2fff, 0x3c00, 0x6fff, 0x3c00, 0x1fff, 0x4000, 0x9fff, 0x4000, /*  a98 */
  0x5fff, 0x4000, 0xdfff, 0x4000, 0x3fff, 0x4400, 0x3fff, 0x4401, /*  aa0 */
  0xbfff, 0x4400, 0xbfff, 0x4401, 0x7fff, 0x4400, 0x7fff, 0x4401, /*  aa8 */
  0xffff, 0x4400, 0xffff, 0x4401, 0x0000, 0x0c00, 0x0004, 0x0c00, /*  ab0 */
  0x0002, 0x0c00, 0x0006, 0x0c00, 0x0001, 0x1000, 0x0009, 0x1000, /*  ab8 */
  0x0005, 0x1000, 0x000d, 0x1000, 0x0003, 0x1400, 0x0013, 0x1400, /*  ac0 */
  0x000b, 0x1400, 0x001b, 0x1400, 0x0007, 0x1800, 0x0027, 0x1800, /*  ac8 */
  0x0017, 0x1800, 0x0037, 0x1800, 0x000f, 0x1c00, 0x004f, 0x1c00, /*  ad0 */
  0x002f, 0x1c00, 0x006f, 0x1c00, 0x001f, 0x2000, 0x009f, 0x2000, /*  ad8 */
  0x005f, 0x2000, 0x00df, 0x2000, 0x003f, 0x2400, 0x013f, 0x2400, /*  ae0 */
  0x00bf, 0x2400, 0x01bf, 0x2400, 0x007f, 0x2800, 0x027f, 0x2800, /*  ae8 */
  0x017f, 0x2800, 0x037f, 0x2800, 0x00ff, 0x2c00, 0x04ff, 0x2c00, /*  af0 */
  0x02ff, 0x2c00, 0x06ff, 0x2c00, 0x01ff, 0x3000, 0x09ff, 0x3000, /*  af8 */
  0x05ff, 0x3000, 0x0dff, 0x3000, 0x03ff, 0x3400, 0x13ff, 0x3400, /*  b00 */
  0x0bff, 0x3400, 0x1bff, 0x3400, 0x07ff, 0x3800, 0x27ff, 0x3800, /*  b08 */
  0x17ff, 0x3800, 0x37ff, 0x3800, 0x0fff, 0x3c00, 0x4fff, 0x3c00, /*  b10 */
  0x2fff, 0x3c00, 0x6fff, 0x3c00, 0x1fff, 0x4000, 0x9fff, 0x4000, /*  b18 */
  0x5fff, 0x4000, 0xdfff, 0x4000, 0x3fff, 0x4400, 0x3fff, 0x4401, /*  b20 */
  0xbfff, 0x4400, 0xbfff, 0x4401, 0x7fff, 0x4400, 0x7fff, 0x4401, /*  b28 */
  0xffff, 0x4400, 0xffff, 0x4401, 0x0000, 0x0c00, 0x0004, 0x0c00, /*  b30 */
  0x0002, 0x0c00, 0x0006, 0x0c00, 0x0001, 0x1000, 0x0009, 0x1000, /*  b38 */
  0x0005, 0x1000, 0x000d, 0x1000, 0x0003, 0x1400, 0x0013, 0x1400, /*  b40 */
  0x000b, 0x1400, 0x001b, 0x1400, 0x0007, 0x1800, 0x0027, 0x1800, /*  b48 */
  0x0017, 0x1800, 0x0037, 0x1800, 0x000f, 0x1c00, 0x004f, 0x1c00, /*  b50 */
  0x002f, 0x1c00, 0x006f, 0x1c00, 0x001f, 0x2000, 0x009f, 0x2000, /*  b58 */
  0x005f, 0x2000, 0x00df, 0x2000, 0x003f, 0x2400, 0x013f, 0x2400, /*  b60 */
  0x00bf, 0x2400, 0x01bf, 0x2400, 0x007f, 0x2800, 0x027f, 0x2800, /*  b68 */
  0x017f, 0x2800, 0x037f, 0x2800, 0x00ff, 0x2c00, 0x04ff, 0x2c00, /*  b70 */
  0x02ff, 0x2c00, 0x06ff, 0x2c00, 0x01ff, 0x3000, 0x09ff, 0x3000, /*  b78 */
  0x05ff, 0x3000, 0x0dff, 0x3000, 0x03ff, 0x3400, 0x13ff, 0x3400, /*  b80 */
  0x0bff, 0x3400, 0x1bff, 0x3400, 0x07ff, 0x3800, 0x27ff, 0x3800, /*  b88 */
  0x17ff, 0x3800, 0x37ff, 0x3800, 0x0fff, 0x3c00, 0x4fff, 0x3c00, /*  b90 */
  0x2fff, 0x3c00, 0x6fff, 0x3c00, 0x1fff, 0x4000, 0x9fff, 0x4000, /*  b98 */
  0x5fff, 0x4000, 0xdfff, 0x4000, 0x3fff, 0x4400, 0x3fff, 0x4401, /*  ba0 */
  0xbfff, 0x4400, 0xbfff, 0x4401, 0x7fff, 0x4400, 0x7fff, 0x4401, /*  ba8 */
  0xffff, 0x4400, 0xffff, 0x4401, 0x0000, 0x2000, 0x0080, 0x2000, /*  bb0 */
  0x0040, 0x2000, 0x00c0, 0x2000, 0x0020, 0x1800, 0x0010, 0x2000, /*  bb8 */
  0x0090, 0x2000, 0x0050, 0x2000, 0x00d0, 0x2000, 0x0030, 0x2000, /*  bc0 */
  0x0008, 0x1800, 0x00b0, 0x2000, 0x0028, 0x1800, 0x0004, 0x1000, /*  bc8 */
  0x0018, 0x1800, 0x0070, 0x2000, 0x0038, 0x1800, 0x00f0, 0x2000, /*  bd0 */
  0x000c, 0x2000, 0x008c, 0x2000, 0x004c, 0x2000, 0x00cc, 0x2000, /*  bd8 */
  0x002c, 0x1800, 0x001c, 0x2000, 0x009c, 0x2000, 0x005c, 0x2000, /*  be0 */
  0x00dc, 0x2000, 0x003c, 0x2000, 0x0002, 0x1800, 0x00bc, 0x2000, /*  be8 */
  0x0022, 0x1800, 0x000a, 0x1000, 0x0012, 0x1800, 0x007c, 0x2000, /*  bf0 */
  0x0032, 0x1800, 0x00fc, 0x2000, 0x0006, 0x1800, 0x000e, 0x1000, /*  bf8 */
  0x0026, 0x1800, 0x0001, 0x1000, 0x0003, 0x0800, 0x0016, 0x1800, /*  c00 */
  0x0036, 0x1c00, 0x0009, 0x1800, 0x0076, 0x1c00, 0x0029, 0x2000, /*  c08 */
  0x0069, 0x1c00, 0x00a9, 0x2000, 0x0019, 0x1c00, 0x0039, 0x1800, /*  c10 */
  0x0059, 0x2000, 0x00d9, 0x2000, 0x0005, 0x2000, 0x0085, 0x2000, /*  c18 */
  0x0045, 0x2000, 0x00c5, 0x2000, 0x0025, 0x2000, 0x00a5, 0x2000, /*  c20 */
  0x0065, 0x2000, 0x00e5, 0x2000, 0x0015, 0x2000, 0x0095, 0x2000, /*  c28 */
  0x0055, 0x2000, 0x00d5, 0x2000, 0x0035, 0x2000, 0x00b5, 0x2000, /*  c30 */
  0x0075, 0x2000, 0x000d, 0x1800, 0x00f5, 0x2000, 0x002d, 0x2000, /*  c38 */
  0x00ad, 0x2000, 0x006d, 0x2000, 0x00ed, 0x2000, 0x001d, 0x2000, /*  c40 */
  0x009d, 0x2000, 0x005d, 0x2000, 0x00dd, 0x2000, 0x003d, 0x2000, /*  c48 */
  0x00bd, 0x2000, 0x007d, 0x2000, 0x00fd, 0x2000, 0x0000, 0x1c00, /*  c50 */
  0x0020, 0x1800, 0x0008, 0x1000, 0x0010, 0x1800, 0x0040, 0x1c00, /*  c58 */
  0x0030, 0x1800, 0x0004, 0x1000, 0x0002, 0x0c00, 0x000c, 0x1000, /*  c60 */
  0x0006, 0x1c00, 0x0016, 0x1400, 0x0001, 0x0c00, 0x0005, 0x0c00, /*  c68 */
  0x0003, 0x0c00, 0x000e, 0x1400, 0x0046, 0x1c00, 0x001e, 0x1400, /*  c70 */
  0x0007, 0x1000, 0x000f, 0x1400, 0x0026, 0x1c00, 0x0066, 0x2000, /*  c78 */
  0x001f, 0x1c00, 0x003f, 0x1800, 0x005f, 0x1c00, 0x00e6, 0x2000, /*  c80 */
  0x0000, 0x1c00, 0x0020, 0x1800, 0x0010, 0x1800, 0x0030, 0x1800, /*  c88 */
  0x0008, 0x1800, 0x0028, 0x1800, 0x0040, 0x1c00, 0x0018, 0x1c00, /*  c90 */
  0x0038, 0x1800, 0x0004, 0x1800, 0x0014, 0x1400, 0x0024, 0x1800, /*  c98 */
  0x000c, 0x1800, 0x0058, 0x1c00, 0x002c, 0x1800, 0x001c, 0x1800, /*  ca0 */
  0x0002, 0x1400, 0x000a, 0x1000, 0x0012, 0x1400, 0x003c, 0x1800, /*  ca8 */
  0x0006, 0x1800, 0x0026, 0x1800, 0x0016, 0x1400, 0x000e, 0x1000, /*  cb0 */
  0x0001, 0x1000, 0x0009, 0x1000, 0x0005, 0x1400, 0x0015, 0x1800, /*  cb8 */
  0x0035, 0x1800, 0x000d, 0x1800, 0x001d, 0x1400, 0x0003, 0x1400, /*  cc0 */
  0x0013, 0x1400, 0x002d, 0x1800, 0x000b, 0x1800, 0x002b, 0x1c00, /*  cc8 */
  0x001b, 0x1800, 0x003b, 0x1800, 0x0007, 0x1800, 0x0027, 0x1800, /*  cd0 */
  0x0017, 0x1800, 0x006b, 0x1c00, 0x0037, 0x1c00, 0x0077, 0x1c00, /*  cd8 */
  0x000f, 0x1800, 0x002f, 0x1800, 0x001f, 0x1800, 0x003f, 0x1c00, /*  ce0 */
  0x007f, 0x1c00, 0x0000, 0x2000, 0x0040, 0x1c00, 0x0020, 0x1800, /*  ce8 */
  0x0010, 0x1400, 0x0008, 0x1000, 0x0004, 0x0c00, 0x0002, 0x0800, /*  cf0 */
  0x0001, 0x0800, 0x0003, 0x0c00, 0x0007, 0x1000, 0x000f, 0x1400, /*  cf8 */
  0x001f, 0x1800, 0x003f, 0x1c00, 0x007f, 0x1c00, 0x0080, 0x2000, /*  d00 */
  0x0000, 0x4400, 0x0000, 0x4401, 0x8000, 0x4400, 0x4000, 0x4000, /*  d08 */
  0xc000, 0x4000, 0x2000, 0x3c00, 0x6000, 0x3c00, 0x1000, 0x3800, /*  d10 */
  0x3000, 0x3800, 0x0800, 0x3400, 0x1800, 0x3400, 0x0400, 0x3000, /*  d18 */
  0x0c00, 0x3000, 0x0200, 0x2c00, 0x0600, 0x2c00, 0x0100, 0x2800, /*  d20 */
  0x0300, 0x2800, 0x0080, 0x2400, 0x0180, 0x2400, 0x0040, 0x2000, /*  d28 */
  0x00c0, 0x2000, 0x0020, 0x1c00, 0x0060, 0x1c00, 0x0010, 0x1800, /*  d30 */
  0x0030, 0x1800, 0x0008, 0x1400, 0x0018, 0x1400, 0x0004, 0x1000, /*  d38 */
  0x000c, 0x1000, 0x0002, 0x0c00, 0x0006, 0x0c00, 0x0001, 0x0c00, /*  d40 */
  0x0005, 0x0c00, 0x0003, 0x1000, 0x000b, 0x1000, 0x0007, 0x1400, /*  d48 */
  0x0017, 0x1400, 0x000f, 0x1800, 0x002f, 0x1800, 0x001f, 0x1c00, /*  d50 */
  0x005f, 0x1c00, 0x003f, 0x2000, 0x00bf, 0x2000, 0x007f, 0x2400, /*  d58 */
  0x017f, 0x2400, 0x00ff, 0x2800, 0x02ff, 0x2800, 0x01ff, 0x2c00, /*  d60 */
  0x05ff, 0x2c00, 0x03ff, 0x3000, 0x0bff, 0x3000, 0x07ff, 0x3400, /*  d68 */
  0x17ff, 0x3400, 0x0fff, 0x3800, 0x2fff, 0x3800, 0x1fff, 0x3c00, /*  d70 */
  0x5fff, 0x3c00, 0x3fff, 0x4000, 0xbfff, 0x4000, 0x7fff, 0x4000, /*  d78 */
  0x8000, 0x4401, 0xffff, 0x4400, 0xffff, 0x4401, 0x0000, 0x2800, /*  d80 */
  0x0200, 0x2800, 0x0100, 0x2800, 0x0300, 0x2800, 0x0080, 0x2800, /*  d88 */
  0x0280, 0x2800, 0x0180, 0x2800, 0x0380, 0x2800, 0x0040, 0x2800, /*  d90 */
  0x0240, 0x2800, 0x0140, 0x2800, 0x0340, 0x2800, 0x00c0, 0x2800, /*  d98 */
  0x02c0, 0x2800, 0x01c0, 0x2800, 0x03c0, 0x2800, 0x0020, 0x2800, /*  da0 */
  0x0220, 0x2800, 0x0120, 0x2800, 0x0320, 0x2800, 0x00a0, 0x2800, /*  da8 */
  0x02a0, 0x2800, 0x01a0, 0x2400, 0x0060, 0x2800, 0x0260, 0x2800, /*  db0 */
  0x0160, 0x2800, 0x0360, 0x2800, 0x00e0, 0x2800, 0x02e0, 0x2800, /*  db8 */
  0x01e0, 0x2800, 0x03e0, 0x2800, 0x0010, 0x2800, 0x0210, 0x2800, /*  dc0 */
  0x0110, 0x2800, 0x0310, 0x2800, 0x0090, 0x2800, 0x0190, 0x2400, /*  dc8 */
  0x0050, 0x2400, 0x0150, 0x2400, 0x0290, 0x2800, 0x00d0, 0x2800, /*  dd0 */
  0x02d0, 0x2800, 0x01d0, 0x2800, 0x03d0, 0x2800, 0x0030, 0x2800, /*  dd8 */
  0x0230, 0x2800, 0x0130, 0x2800, 0x0330, 0x2800, 0x00b0, 0x2800, /*  de0 */
  0x02b0, 0x2800, 0x01b0, 0x2400, 0x0070, 0x2400, 0x0170, 0x2400, /*  de8 */
  0x00f0, 0x2400, 0x01f0, 0x2800, 0x03f0, 0x2800, 0x0008, 0x2800, /*  df0 */
  0x0208, 0x2800, 0x0108, 0x2800, 0x0308, 0x2800, 0x0088, 0x2800, /*  df8 */
  0x0288, 0x2800, 0x0188, 0x2800, 0x0388, 0x2800, 0x0048, 0x2800, /*  e00 */
  0x0148, 0x2400, 0x00c8, 0x2400, 0x0028, 0x1800, 0x01c8, 0x2400, /*  e08 */
  0x0018, 0x2400, 0x0248, 0x2800, 0x0118, 0x2800, 0x0318, 0x2800, /*  e10 */
  0x0098, 0x2800, 0x0298, 0x2800, 0x0198, 0x2800, 0x0398, 0x2800, /*  e18 */
  0x0058, 0x2800, 0x0258, 0x2800, 0x0158, 0x2400, 0x00d8, 0x2400, /*  e20 */
  0x0038, 0x1800, 0x0004, 0x1800, 0x0024, 0x1800, 0x01d8, 0x2400, /*  e28 */
  0x0014, 0x2400, 0x0114, 0x2800, 0x0314, 0x2800, 0x0094, 0x2800, /*  e30 */
  0x0294, 0x2800, 0x0194, 0x2800, 0x0394, 0x2800, 0x0054, 0x2800, /*  e38 */
  0x0154, 0x2400, 0x00d4, 0x2400, 0x0034, 0x1800, 0x000c, 0x1800, /*  e40 */
  0x002c, 0x1800, 0x001c, 0x1800, 0x01d4, 0x2400, 0x003c, 0x2400, /*  e48 */
  0x013c, 0x2400, 0x0254, 0x2800, 0x00bc, 0x2800, 0x02bc, 0x2800, /*  e50 */
  0x01bc, 0x2800, 0x03bc, 0x2800, 0x007c, 0x2400, 0x017c, 0x2400, /*  e58 */
  0x00fc, 0x2400, 0x0002, 0x1800, 0x0022, 0x1800, 0x0001, 0x0400, /*  e60 */
  0x0012, 0x1800, 0x0032, 0x1800, 0x01fc, 0x2400, 0x000a, 0x2400, /*  e68 */
  0x010a, 0x2400, 0x008a, 0x2800, 0x028a, 0x2800, 0x018a, 0x2800, /*  e70 */
  0x038a, 0x2800, 0x004a, 0x2800, 0x014a, 0x2400, 0x00ca, 0x2400, /*  e78 */
  0x01ca, 0x2400, 0x002a, 0x1800, 0x001a, 0x1800, 0x003a, 0x1800, /*  e80 */
  0x0006, 0x2400, 0x0106, 0x2400, 0x0086, 0x2400, 0x024a, 0x2800, /*  e88 */
  0x0186, 0x2800, 0x0386, 0x2800, 0x0046, 0x2800, 0x0246, 0x2800, /*  e90 */
  0x0146, 0x2800, 0x0346, 0x2800, 0x00c6, 0x2400, 0x01c6, 0x2400, /*  e98 */
  0x0026, 0x2400, 0x0016, 0x1800, 0x0126, 0x2400, 0x00a6, 0x2400, /*  ea0 */
  0x01a6, 0x2400, 0x0066, 0x2800, 0x0266, 0x2800, 0x0166, 0x2800, /*  ea8 */
  0x0366, 0x2800, 0x00e6, 0x2800, 0x02e6, 0x2800, 0x01e6, 0x2800, /*  eb0 */
  0x03e6, 0x2800, 0x0036, 0x2800, 0x0136, 0x2400, 0x00b6, 0x2400, /*  eb8 */
  0x01b6, 0x2400, 0x0076, 0x2400, 0x0176, 0x2400, 0x0236, 0x2800, /*  ec0 */
  0x00f6, 0x2800, 0x02f6, 0x2800, 0x01f6, 0x2800, 0x03f6, 0x2800, /*  ec8 */
  0x000e, 0x2800, 0x020e, 0x2800, 0x010e, 0x2800, 0x030e, 0x2800, /*  ed0 */
  0x008e, 0x2800, 0x028e, 0x2800, 0x018e, 0x2400, 0x004e, 0x2400, /*  ed8 */
  0x014e, 0x2400, 0x00ce, 0x2800, 0x02ce, 0x2800, 0x01ce, 0x2800, /*  ee0 */
  0x03ce, 0x2800, 0x002e, 0x2800, 0x022e, 0x2800, 0x012e, 0x2800, /*  ee8 */
  0x032e, 0x2800, 0x00ae, 0x2800, 0x02ae, 0x2800, 0x01ae, 0x2800, /*  ef0 */
  0x03ae, 0x2800, 0x006e, 0x2800, 0x016e, 0x2400, 0x026e, 0x2800, /*  ef8 */
  0x00ee, 0x2800, 0x02ee, 0x2800, 0x01ee, 0x2800, 0x03ee, 0x2800, /*  f00 */
  0x001e, 0x2800, 0x021e, 0x2800, 0x011e, 0x2800, 0x031e, 0x2800, /*  f08 */
  0x009e, 0x2800, 0x029e, 0x2800, 0x019e, 0x2800, 0x039e, 0x2800, /*  f10 */
  0x005e, 0x2800, 0x025e, 0x2800, 0x015e, 0x2800, 0x035e, 0x2800, /*  f18 */
  0x00de, 0x2800, 0x02de, 0x2800, 0x01de, 0x2800, 0x03de, 0x2800, /*  f20 */
  0x003e, 0x2800, 0x023e, 0x2800, 0x013e, 0x2800, 0x033e, 0x2800, /*  f28 */
  0x00be, 0x2800, 0x02be, 0x2800, 0x01be, 0x2800, 0x03be, 0x2800, /*  f30 */
  0x007e, 0x2800, 0x027e, 0x2800, 0x017e, 0x2800, 0x037e, 0x2800, /*  f38 */
  0x00fe, 0x2800, 0x02fe, 0x2800, 0x01fe, 0x2800, 0x03fe, 0x2800, /*  f40 */
  0x0000, 0x3000, 0x0800, 0x3000, 0x0400, 0x3000, 0x0200, 0x2c00, /*  f48 */
  0x0600, 0x2c00, 0x0100, 0x2c00, 0x0500, 0x2c00, 0x0300, 0x2c00, /*  f50 */
  0x0700, 0x2c00, 0x0080, 0x2c00, 0x0480, 0x2c00, 0x0280, 0x2c00, /*  f58 */
  0x0c00, 0x3000, 0x0680, 0x3000, 0x0e80, 0x3000, 0x0180, 0x3000, /*  f60 */
  0x0980, 0x3000, 0x0580, 0x2c00, 0x0380, 0x2c00, 0x0780, 0x2c00, /*  f68 */
  0x0040, 0x2c00, 0x0440, 0x2c00, 0x0240, 0x2800, 0x0140, 0x2c00, /*  f70 */
  0x0540, 0x2c00, 0x0340, 0x2c00, 0x0740, 0x2c00, 0x00c0, 0x2c00, /*  f78 */
  0x04c0, 0x3000, 0x0cc0, 0x3000, 0x02c0, 0x3000, 0x06c0, 0x2c00, /*  f80 */
  0x01c0, 0x2c00, 0x05c0, 0x2c00, 0x03c0, 0x2c00, 0x07c0, 0x2c00, /*  f88 */
  0x0020, 0x2800, 0x0220, 0x2800, 0x0120, 0x2800, 0x0320, 0x2c00, /*  f90 */
  0x0720, 0x2c00, 0x00a0, 0x2c00, 0x04a0, 0x2c00, 0x02a0, 0x2c00, /*  f98 */
  0x0ac0, 0x3000, 0x06a0, 0x2c00, 0x01a0, 0x2c00, 0x05a0, 0x2c00, /*  fa0 */
  0x03a0, 0x2c00, 0x07a0, 0x2c00, 0x0060, 0x2800, 0x0260, 0x2800, /*  fa8 */
  0x0160, 0x2800, 0x0360, 0x2800, 0x00e0, 0x2800, 0x02e0, 0x2c00, /*  fb0 */
  0x06e0, 0x2c00, 0x01e0, 0x2c00, 0x05e0, 0x2c00, 0x03e0, 0x2c00, /*  fb8 */
  0x07e0, 0x2c00, 0x0010, 0x2c00, 0x0410, 0x2c00, 0x0210, 0x2c00, /*  fc0 */
  0x0110, 0x2800, 0x0310, 0x2800, 0x0090, 0x2800, 0x0050, 0x1c00, /*  fc8 */
  0x0290, 0x2800, 0x0190, 0x2800, 0x0390, 0x2800, 0x0610, 0x2c00, /*  fd0 */
  0x0030, 0x2c00, 0x0430, 0x2c00, 0x0230, 0x2c00, 0x0630, 0x2c00, /*  fd8 */
  0x0130, 0x2c00, 0x0530, 0x2c00, 0x0330, 0x2800, 0x00b0, 0x2800, /*  fe0 */
  0x02b0, 0x2800, 0x0070, 0x1c00, 0x0008, 0x1c00, 0x0048, 0x1c00, /*  fe8 */
  0x01b0, 0x2800, 0x03b0, 0x2800, 0x0028, 0x2800, 0x0228, 0x2c00, /*  ff0 */
  0x0628, 0x2c00, 0x0128, 0x2c00, 0x0528, 0x2c00, 0x0328, 0x2c00, /*  ff8 */
  0x00a8, 0x2800, 0x02a8, 0x2800, 0x01a8, 0x2800, 0x0068, 0x1c00, /* 1000 */
  0x0018, 0x1c00, 0x0004, 0x1000, 0x0058, 0x1c00, 0x0038, 0x1c00, /* 1008 */
  0x03a8, 0x2800, 0x0078, 0x2800, 0x0278, 0x2800, 0x0728, 0x2c00, /* 1010 */
  0x0178, 0x2c00, 0x0578, 0x2c00, 0x0378, 0x2800, 0x00f8, 0x2800, /* 1018 */
  0x02f8, 0x2800, 0x000c, 0x1c00, 0x004c, 0x1c00, 0x0002, 0x1000, /* 1020 */
  0x0001, 0x0400, 0x000a, 0x1000, 0x002c, 0x1c00, 0x006c, 0x1c00, /* 1028 */
  0x01f8, 0x2800, 0x03f8, 0x2800, 0x001c, 0x2800, 0x021c, 0x2c00, /* 1030 */
  0x061c, 0x2c00, 0x011c, 0x2c00, 0x031c, 0x2800, 0x009c, 0x2800, /* 1038 */
  0x029c, 0x2800, 0x005c, 0x1c00, 0x003c, 0x1c00, 0x0006, 0x1000, /* 1040 */
  0x007c, 0x1c00, 0x019c, 0x2800, 0x039c, 0x2800, 0x000e, 0x2800, /* 1048 */
  0x020e, 0x2800, 0x051c, 0x2c00, 0x010e, 0x2c00, 0x050e, 0x2c00, /* 1050 */
  0x030e, 0x2c00, 0x070e, 0x2c00, 0x008e, 0x2800, 0x028e, 0x2800, /* 1058 */
  0x018e, 0x2800, 0x038e, 0x2800, 0x004e, 0x1c00, 0x002e, 0x2800, /* 1060 */
  0x022e, 0x2800, 0x012e, 0x2800, 0x032e, 0x2800, 0x00ae, 0x2c00, /* 1068 */
  0x04ae, 0x2c00, 0x02ae, 0x2c00, 0x06ae, 0x2c00, 0x01ae, 0x2c00, /* 1070 */
  0x05ae, 0x2c00, 0x03ae, 0x2c00, 0x006e, 0x2800, 0x026e, 0x2800, /* 1078 */
  0x016e, 0x2800, 0x036e, 0x2800, 0x00ee, 0x2800, 0x02ee, 0x2800, /* 1080 */
  0x01ee, 0x2800, 0x07ae, 0x2c00, 0x03ee, 0x2c00, 0x07ee, 0x2c00, /* 1088 */
  0x001e, 0x2c00, 0x041e, 0x2c00, 0x021e, 0x2c00, 0x061e, 0x2c00, /* 1090 */
  0x011e, 0x2c00, 0x051e, 0x2c00, 0x031e, 0x2800, 0x009e, 0x2800, /* 1098 */
  0x029e, 0x2800, 0x019e, 0x2800, 0x039e, 0x2800, 0x005e, 0x2c00, /* 10a0 */
  0x045e, 0x2c00, 0x025e, 0x2c00, 0x065e, 0x2c00, 0x015e, 0x2c00, /* 10a8 */
  0x055e, 0x3000, 0x035e, 0x2c00, 0x075e, 0x2c00, 0x00de, 0x2c00, /* 10b0 */
  0x04de, 0x2c00, 0x02de, 0x2c00, 0x01de, 0x2800, 0x03de, 0x2800, /* 10b8 */
  0x003e, 0x2800, 0x06de, 0x2c00, 0x023e, 0x2c00, 0x063e, 0x2c00, /* 10c0 */
  0x013e, 0x2c00, 0x053e, 0x2c00, 0x0d5e, 0x3000, 0x033e, 0x3000, /* 10c8 */
  0x0b3e, 0x3000, 0x073e, 0x2c00, 0x00be, 0x2c00, 0x04be, 0x2c00, /* 10d0 */
  0x02be, 0x2c00, 0x06be, 0x2c00, 0x01be, 0x2800, 0x03be, 0x2c00, /* 10d8 */
  0x07be, 0x2c00, 0x007e, 0x2c00, 0x047e, 0x2c00, 0x027e, 0x2c00, /* 10e0 */
  0x067e, 0x3000, 0x0e7e, 0x3000, 0x017e, 0x3000, 0x097e, 0x3000, /* 10e8 */
  0x057e, 0x3000, 0x037e, 0x2c00, 0x077e, 0x2c00, 0x00fe, 0x2c00, /* 10f0 */
  0x04fe, 0x2c00, 0x02fe, 0x2c00, 0x06fe, 0x2c00, 0x01fe, 0x2c00, /* 10f8 */
  0x05fe, 0x2c00, 0x03fe, 0x2c00, 0x0d7e, 0x3000, 0x07fe, 0x3000, /* 1100 */
  0x0ffe, 0x3000, 0x0000, 0x1000, 0x0008, 0x1000, 0x0004, 0x1000, /* 1108 */
  0x000c, 0x1000, 0x0002, 0x1000, 0x000a, 0x1000, 0x0006, 0x1000, /* 1110 */
  0x0001, 0x0c00, 0x000e, 0x1000, 0x0005, 0x1000, 0x000d, 0x1000, /* 1118 */
  0x0003, 0x1000, 0x000b, 0x1000, 0x0007, 0x1000, 0x000f, 0x1000, /* 1120 */
  0x0000, 0x0c00, 0x0004, 0x2800, 0x0204, 0x3000, 0x0a04, 0x3400, /* 1128 */
  0x1a04, 0x3400, 0x0604, 0x3400, 0x1604, 0x3800, 0x0104, 0x2800, /* 1130 */
  0x0002, 0x0c00, 0x000c, 0x1000, 0x0014, 0x1400, 0x0044, 0x1c00, /* 1138 */
  0x0304, 0x2c00, 0x0e04, 0x3000, 0x0704, 0x3400, 0x0006, 0x1000, /* 1140 */
  0x0001, 0x0c00, 0x000e, 0x1000, 0x0024, 0x1800, 0x0084, 0x2400, /* 1148 */
  0x0184, 0x2c00, 0x1704, 0x3400, 0x0005, 0x1400, 0x000d, 0x1000, /* 1150 */
  0x0015, 0x1400, 0x0003, 0x1400, 0x0013, 0x2000, 0x0384, 0x2800, /* 1158 */
  0x0f04, 0x3400, 0x0093, 0x2000, 0x0033, 0x1800, 0x000b, 0x1800, /* 1160 */
  0x002b, 0x1800, 0x0053, 0x1c00, 0x001b, 0x2400, 0x1f04, 0x3400, /* 1168 */
  0x0584, 0x2c00, 0x0007, 0x0c00, 0x009b, 0x2000, 0x005b, 0x1c00, /* 1170 */
  0x003b, 0x1c00, 0x007b, 0x2000, 0x3604, 0x3800, 0x011b, 0x3000, /* 1178 */
  0x091b, 0x3000, 0x051b, 0x2c00, 0x031b, 0x2800, 0x00fb, 0x2400, /* 1180 */
  0x01fb, 0x2400, 0x0007, 0x0001, 0x81bd, 0x0006, 0x0034, 0x003f, /* 1188 */
  0xffc0, 0x3613, 0x0024, 0x3e12, 0x0024, 0x3e05, 0xb814, 0x3615, /* 1190 */
  0x0024, 0x3e10, 0x7810, 0x0002, 0x1f10, 0x003f, 0xffc1, 0x3810, /* 1198 */
  0x138c, 0x38f0, 0x4024, 0x0002, 0x1710, 0x3420, 0x0024, 0x3800, /* 11a0 */
  0x0024, 0x2900, 0x75c0, 0x0002, 0x1610, 0x0002, 0x1610, 0x2900, /* 11a8 */
  0x6740, 0x6890, 0x184c, 0x0002, 0x2010, 0x3800, 0x1810, 0x36f0, /* 11b0 */
  0x4024, 0x3405, 0x9014, 0x36f3, 0x0024, 0x36f2, 0x0024, 0x2000, /* 11b8 */
  0x0000, 0x0002, 0x1600, 0x0007, 0x0001, 0x81d7, 0x0006, 0x007e, /* 11c0 */
  0x3e12, 0x0024, 0x3e05, 0xb814, 0x3635, 0x0024, 0x3e00, 0x7842, /* 11c8 */
  0x0000, 0x08c2, 0x3e00, 0xf844, 0x3e01, 0x7846, 0x689a, 0x4406, /* 11d0 */
  0x3e01, 0xf812, 0x0002, 0x9352, 0x4624, 0x104c, 0xf400, 0x4090, /* 11d8 */
  0x0002, 0x9342, 0x3c00, 0x3001, 0x3800, 0x8024, 0x0000, 0x04c2, /* 11e0 */
  0x4624, 0x0024, 0xf400, 0x4090, 0x3010, 0x8024, 0x3000, 0xc024, /* 11e8 */
  0x0002, 0x9390, 0x6328, 0x0024, 0xa548, 0x0024, 0x4294, 0xa084, /* 11f0 */
  0xa528, 0x0024, 0x0003, 0x0002, 0xa53e, 0xa804, 0x0000, 0x0143, /* 11f8 */
  0xfe3e, 0xa142, 0x003f, 0xffc3, 0x48b2, 0x4087, 0xa036, 0x0024, /* 1200 */
  0x6236, 0x0024, 0x4480, 0xa003, 0x2914, 0xba00, 0x3009, 0x13c1, /* 1208 */
  0x0002, 0x9550, 0x0002, 0x94d2, 0x4384, 0xa800, 0x2914, 0xb200, /* 1210 */
  0x4480, 0x0024, 0x0038, 0x0001, 0x3009, 0x2000, 0x0002, 0x9510, /* 1218 */
  0x003f, 0xda80, 0x3009, 0x22c0, 0x3009, 0x2005, 0x0000, 0x05d0, /* 1220 */
  0xf400, 0x4400, 0x4600, 0x0024, 0xb880, 0x4010, 0x3800, 0x0024, /* 1228 */
  0x003e, 0x0010, 0x3009, 0x2001, 0x36f1, 0xd812, 0x36f1, 0x5806, /* 1230 */
  0x36f0, 0xd804, 0x36f0, 0x5802, 0x3405, 0x9014, 0x36f3, 0x0024, /* 1238 */
  0x36f2, 0x0024, 0x2000, 0x0000, 0x0000, 0x0024, 0x0007, 0x0001, /* 1240 */
  0x8216, 0x0006, 0x02e2, 0x3e12, 0x0024, 0x3e05, 0xb814, 0x3675, /* 1248 */
  0x0024, 0x3613, 0x138c, 0x3e00, 0x7842, 0x0000, 0x08c1, 0x3e00, /* 1250 */
  0xf844, 0x3e01, 0x7846, 0x3e01, 0xf850, 0x3e04, 0x7852, 0x3e04, /* 1258 */
  0xf84d, 0x3e03, 0xb80f, 0x3434, 0x0024, 0xf400, 0x4400, 0x4010, /* 1260 */
  0x0024, 0xf400, 0x4010, 0x003f, 0xffc0, 0x3004, 0xc024, 0x003e, /* 1268 */
  0x0010, 0x3cf0, 0x0024, 0x0038, 0x0000, 0x3343, 0x0001, 0x6102, /* 1270 */
  0x8f00, 0x6102, 0x0024, 0x6182, 0x0024, 0x0000, 0x0024, 0x2800, /* 1278 */
  0x8d18, 0x0000, 0x0024, 0x0003, 0x0000, 0x4102, 0x0024, 0x2910, /* 1280 */
  0x0180, 0x3613, 0x0024, 0x3009, 0x0c00, 0x6102, 0x0024, 0x0038, /* 1288 */
  0x0000, 0x2800, 0x8ad1, 0x003e, 0x0010, 0x0000, 0x004d, 0x2400, /* 1290 */
  0x9a0d, 0x0000, 0x0006, 0x3463, 0x184c, 0xbc82, 0x44d2, 0x3c10, /* 1298 */
  0x090c, 0x3cf0, 0x4024, 0x3009, 0x3040, 0x3009, 0x3241, 0x0003, /* 12a0 */
  0x0001, 0xfe1c, 0x8c00, 0x0038, 0x0001, 0x48b6, 0x0024, 0x4124, /* 12a8 */
  0x8801, 0x4212, 0x0024, 0x2902, 0x7400, 0xf400, 0x4050, 0xf400, /* 12b0 */
  0x4052, 0x3463, 0x0c00, 0xf400, 0x4510, 0xf400, 0x4511, 0x2902, /* 12b8 */
  0x8280, 0x34a3, 0x184c, 0xb880, 0x118c, 0x6892, 0x9042, 0x3613, /* 12c0 */
  0x13c3, 0x6dc2, 0x0024, 0x0000, 0x0024, 0x2800, 0xdfc1, 0x0000, /* 12c8 */
  0x0024, 0x3411, 0x0024, 0x2938, 0xd5c0, 0x3491, 0x4024, 0xf400, /* 12d0 */
  0x4004, 0x0000, 0x0005, 0x0000, 0x3000, 0xfe0c, 0x44c2, 0x48b2, /* 12d8 */
  0x0d4c, 0x0000, 0x0241, 0x4212, 0x0024, 0x4102, 0x8ec0, 0x4000, /* 12e0 */
  0x0024, 0x4100, 0x0024, 0x669c, 0x4010, 0x3009, 0x2044, 0x3009, /* 12e8 */
  0x23c5, 0xf400, 0x44d2, 0x3253, 0x0024, 0x3009, 0x0840, 0x6090, /* 12f0 */
  0x8bc1, 0x6012, 0xa800, 0x0000, 0x0000, 0x2800, 0x9c91, 0x0000, /* 12f8 */
  0x0024, 0x3009, 0x2800, 0xf400, 0x44d2, 0x3243, 0x0dc1, 0x3009, /* 1300 */
  0x0bc0, 0x4010, 0x8841, 0x6012, 0xa800, 0x0000, 0x0000, 0x2800, /* 1308 */
  0x9ed1, 0x0000, 0x0024, 0x3009, 0x2800, 0x3413, 0x0e40, 0x6080, /* 1310 */
  0x44d0, 0x3373, 0x010c, 0x2800, 0xa4d8, 0x3009, 0x0c00, 0x34f3, /* 1318 */
  0x0e4c, 0x3413, 0x0dcc, 0x6090, 0x0024, 0x34f0, 0x2c00, 0x36f3, /* 1320 */
  0x980f, 0x36f4, 0xd80d, 0x36f4, 0x5812, 0x36f1, 0xd810, 0x36f1, /* 1328 */
  0x5806, 0x36f0, 0xd804, 0x36f0, 0x5802, 0x3405, 0x9014, 0x36f3, /* 1330 */
  0x0024, 0x36f2, 0x0024, 0x2000, 0x0000, 0x0000, 0x0024, 0xf400, /* 1338 */
  0x44d0, 0x3373, 0x104c, 0x3009, 0x010c, 0x3393, 0x0102, 0x3413, /* 1340 */
  0x02c1, 0x3009, 0x0c00, 0xfe82, 0x44d2, 0x4db6, 0x088c, 0x3009, /* 1348 */
  0x3002, 0x3009, 0x0001, 0x621c, 0x9000, 0x0000, 0x0024, 0x2800, /* 1350 */
  0xa811, 0x0000, 0x0024, 0x6010, 0x44d2, 0x3223, 0x3000, 0x34c3, /* 1358 */
  0x0800, 0x6080, 0x0024, 0x0000, 0x05c0, 0x2800, 0xbe45, 0x0000, /* 1360 */
  0x0024, 0x4082, 0x1390, 0xf400, 0x4400, 0x4010, 0x8d4c, 0xb880, /* 1368 */
  0x4010, 0x3800, 0x0800, 0x4090, 0x0024, 0x3470, 0x2800, 0x34d3, /* 1370 */
  0x0ecc, 0x6080, 0x0024, 0x0038, 0x0004, 0x2800, 0xae05, 0x0000, /* 1378 */
  0x03c2, 0x0000, 0x05c1, 0x34e3, 0x0024, 0x3424, 0x0024, 0xf400, /* 1380 */
  0x4400, 0x4010, 0x0024, 0xb880, 0x4010, 0x3800, 0x0024, 0x0002, /* 1388 */
  0x0007, 0x0003, 0x0003, 0x0000, 0x0581, 0x34e3, 0x0dcc, 0xb88c, /* 1390 */
  0x10d2, 0xf400, 0x4480, 0x4010, 0x0024, 0x2b01, 0x0480, 0x4020, /* 1398 */
  0x0041, 0x4012, 0x0024, 0xf400, 0x4052, 0x3200, 0x8024, 0x3000, /* 13a0 */
  0x4024, 0x4010, 0x0024, 0xf400, 0x4010, 0x3000, 0x0024, 0x4200, /* 13a8 */
  0x0024, 0xf200, 0x0024, 0x6702, 0x3300, 0x3430, 0x0024, 0x4014, /* 13b0 */
  0x0024, 0x0000, 0x0000, 0x3009, 0x2e40, 0x3413, 0x0dcc, 0x34f0, /* 13b8 */
  0x0024, 0x6602, 0x8e40, 0x0000, 0x004d, 0x2800, 0xa058, 0x0000, /* 13c0 */
  0x0024, 0x2400, 0xb94d, 0x0000, 0x0001, 0xfe32, 0x10cc, 0x3c01, /* 13c8 */
  0x3385, 0x48ba, 0xb0c6, 0x4481, 0xc236, 0xfe72, 0xb3c3, 0x48b6, /* 13d0 */
  0x13c4, 0x4400, 0x9085, 0x4050, 0x9003, 0x428a, 0x4011, 0x34d0, /* 13d8 */
  0x8024, 0x425a, 0x0024, 0x4680, 0x4150, 0x2903, 0xe7c0, 0x3009, /* 13e0 */
  0x13c6, 0x6192, 0x0024, 0x3423, 0x0cc1, 0x3009, 0x1000, 0x4010, /* 13e8 */
  0x0024, 0x3009, 0x3000, 0x3009, 0x0f41, 0x6012, 0x0024, 0x0000, /* 13f0 */
  0x0000, 0x2800, 0xbc11, 0x0000, 0x0024, 0x3009, 0x3000, 0x34e3, /* 13f8 */
  0x0c00, 0x4204, 0x44d0, 0x3073, 0x0024, 0x3009, 0x0000, 0x4090, /* 1400 */
  0x0024, 0x3009, 0x2000, 0x3009, 0x0c00, 0x2800, 0xb3c0, 0x460c, /* 1408 */
  0x0024, 0x3434, 0x0024, 0xf400, 0x4401, 0x4100, 0x0024, 0x6890, /* 1410 */
  0x4010, 0xb880, 0x2000, 0x3c00, 0x0d4c, 0x0000, 0x0080, 0x34b0, /* 1418 */
  0x4024, 0x6102, 0x1080, 0x0000, 0x0581, 0x2800, 0xab18, 0xbd86, /* 1420 */
  0x1150, 0xf400, 0x4400, 0x4010, 0x3002, 0xf400, 0x4010, 0x3000, /* 1428 */
  0x3383, 0x6080, 0x8cc1, 0x3009, 0x0e40, 0x2800, 0xde85, 0x0000, /* 1430 */
  0x0024, 0x4102, 0x8fc0, 0x4004, 0x0024, 0x4026, 0x0024, 0x003f, /* 1438 */
  0xffc2, 0xa324, 0x0024, 0x4122, 0x0024, 0x419c, 0x0024, 0x4002, /* 1440 */
  0x0024, 0x0000, 0x0080, 0x4102, 0x0d8c, 0x3009, 0x33c1, 0x3009, /* 1448 */
  0x0e80, 0x660e, 0x0024, 0x0000, 0x0024, 0x2800, 0xc788, 0x0000, /* 1450 */
  0x0024, 0x660c, 0x0024, 0x0000, 0x3000, 0xb88e, 0x104c, 0x3430, /* 1458 */
  0x4024, 0xfe02, 0x44c2, 0x48b2, 0x0024, 0x0000, 0x0241, 0x4212, /* 1460 */
  0x0024, 0x4100, 0x0024, 0x4662, 0x0024, 0x4010, 0x0024, 0xf400, /* 1468 */
  0x4010, 0x3009, 0x0040, 0x3009, 0x03c1, 0x3009, 0x3040, 0x3009, /* 1470 */
  0x3301, 0x3009, 0x13c0, 0x6070, 0x0024, 0x0000, 0x0024, 0x2800, /* 1478 */
  0xdc49, 0x4090, 0x0024, 0x2400, 0xdc00, 0x0000, 0x0024, 0x0000, /* 1480 */
  0x3000, 0x3413, 0x0024, 0x3440, 0x4024, 0xfe02, 0x44c2, 0x48b2, /* 1488 */
  0x0024, 0x0000, 0x0241, 0x4212, 0x0024, 0x4102, 0x0024, 0x4660, /* 1490 */
  0x0024, 0x4100, 0x93c1, 0xf400, 0x4010, 0x3009, 0x0044, 0x3009, /* 1498 */
  0x03c5, 0x3009, 0x1000, 0x6ce2, 0x0024, 0x0000, 0x2580, 0x2800, /* 14a0 */
  0xddc1, 0x0000, 0x0024, 0xb882, 0x128c, 0x2914, 0xa580, 0x4e86, /* 14a8 */
  0x0024, 0x4c86, 0x1190, 0x3073, 0x0024, 0x3013, 0x0024, 0x3000, /* 14b0 */
  0x0024, 0xff80, 0x0024, 0x48b2, 0x0024, 0xffb0, 0x4057, 0x48b6, /* 14b8 */
  0x4081, 0xff90, 0x9040, 0x42b6, 0x92c1, 0x6cd2, 0x0024, 0x0000, /* 14c0 */
  0x05c0, 0x2800, 0xd881, 0x0000, 0x0024, 0x34e3, 0x0024, 0x3424, /* 14c8 */
  0x0024, 0xf400, 0x4401, 0x4100, 0x44d2, 0xb880, 0x4010, 0x3800, /* 14d0 */
  0x088c, 0x6790, 0x8801, 0x6104, 0x0024, 0x0000, 0x0024, 0x2800, /* 14d8 */
  0xdd48, 0x0000, 0x0024, 0x3433, 0x0024, 0x3400, 0x1001, 0x6ce2, /* 14e0 */
  0x0024, 0x0000, 0x0024, 0x2800, 0xda41, 0x0000, 0x0024, 0x3c01, /* 14e8 */
  0x3005, 0x34d3, 0x0d8c, 0x669c, 0x8e80, 0x6600, 0x0024, 0x0000, /* 14f0 */
  0x0024, 0x2800, 0xdc08, 0x0000, 0x0024, 0x0000, 0x0006, 0x679e, /* 14f8 */
  0x0024, 0x3413, 0x0024, 0x3400, 0x0024, 0x2800, 0xbf80, 0x6090, /* 1500 */
  0x0024, 0x2800, 0xd880, 0x3009, 0x2800, 0x3009, 0x3044, 0x2800, /* 1508 */
  0xd880, 0x3009, 0x32c5, 0x4100, 0x0024, 0x609c, 0x8fc0, 0x4002, /* 1510 */
  0x0024, 0x2800, 0xc580, 0x0000, 0x00c0, 0x3009, 0x1044, 0x2938, /* 1518 */
  0xd5c0, 0x3009, 0x1245, 0xf400, 0x4002, 0x0000, 0x0003, 0x0000, /* 1520 */
  0x0100, 0x2800, 0x9780, 0xad0a, 0x0024, 0x0007, 0x0001, 0x4a4d, /* 1528 */
  0x0006, 0x8189, 0x0000, 0x0007, 0x0001, 0x8387, 0x0006, 0x0004, /* 1530 */
  0x2000, 0x0000, 0x0000, 0x0024, 0x0007, 0x0001, 0x8389, 0x0006, /* 1538 */
  0x03a2, 0xb880, 0x184c, 0x3e12, 0x0024, 0x3e05, 0xb814, 0x3675, /* 1540 */
  0x0024, 0x3643, 0x138c, 0x3e00, 0x7842, 0x3e00, 0xf844, 0x3e01, /* 1548 */
  0x7846, 0x0000, 0x0086, 0x0008, 0x0005, 0x3e01, 0xf850, 0x3e04, /* 1550 */
  0x7852, 0x0002, 0x1b92, 0x3e04, 0xf84d, 0x0000, 0x0653, 0x3e03, /* 1558 */
  0xb80f, 0xb88e, 0x11d0, 0x3433, 0x010c, 0x6898, 0x0010, 0x3cf4, /* 1560 */
  0x0024, 0x0002, 0x1ed0, 0x6890, 0xb280, 0x3009, 0x3080, 0x000a, /* 1568 */
  0x0000, 0x3009, 0x3390, 0x0002, 0x1bd0, 0x3c54, 0x0024, 0x0002, /* 1570 */
  0x1b50, 0x3009, 0x3390, 0x0000, 0x0690, 0x3c34, 0x0024, 0x0000, /* 1578 */
  0x0610, 0x3cf4, 0x0024, 0x0002, 0x1c90, 0x3cc0, 0x0024, 0x0002, /* 1580 */
  0x2080, 0x3c00, 0x0024, 0x0000, 0x04c0, 0x4660, 0xb180, 0x3009, /* 1588 */
  0x32c0, 0x2801, 0x1f80, 0x3cd4, 0x0024, 0x0000, 0x004d, 0x2400, /* 1590 */
  0xf08d, 0x0000, 0x0002, 0x0002, 0x0000, 0x0008, 0x0005, 0xfe04, /* 1598 */
  0x184c, 0x48b2, 0x0024, 0x4500, 0x0024, 0x3e10, 0x0024, 0x0002, /* 15a0 */
  0x1600, 0x3e10, 0x8024, 0x2902, 0x8a80, 0x3e10, 0x0024, 0x4086, /* 15a8 */
  0x1b4c, 0x6294, 0x0024, 0x6898, 0x0024, 0x0000, 0x004d, 0x2400, /* 15b0 */
  0xf70d, 0x0000, 0x0002, 0x0002, 0x0001, 0x4330, 0x184c, 0xfe14, /* 15b8 */
  0x0024, 0x0008, 0x0001, 0x48ba, 0x0024, 0x414e, 0x0024, 0x0000, /* 15c0 */
  0x01c1, 0x2902, 0xbe00, 0x2b1d, 0x01d2, 0x0002, 0x1b92, 0x0002, /* 15c8 */
  0x1ac0, 0x0008, 0x0005, 0x0002, 0x1b51, 0x3200, 0x518c, 0x4010, /* 15d0 */
  0x184c, 0xf400, 0x4010, 0x3000, 0x3311, 0x408e, 0x41d0, 0x0000, /* 15d8 */
  0x04c0, 0x2902, 0xc540, 0x3009, 0x3380, 0x6294, 0x0024, 0x6898, /* 15e0 */
  0x0024, 0x3473, 0x184c, 0x3009, 0x13c0, 0x3e10, 0x0024, 0x34a0, /* 15e8 */
  0x0024, 0x3e10, 0x0024, 0x3e11, 0x4024, 0x2902, 0xcf80, 0x0002, /* 15f0 */
  0x1610, 0x0000, 0x004d, 0x2400, 0xff4d, 0xb882, 0x1b4c, 0x0008, /* 15f8 */
  0x0005, 0x0002, 0x1b92, 0x0002, 0x1b51, 0x3473, 0x184c, 0x3009, /* 1600 */
  0x12c0, 0x3e10, 0x0024, 0x0002, 0x0000, 0xfe02, 0x3841, 0x48be, /* 1608 */
  0x0024, 0x4560, 0x0024, 0x3e10, 0x0024, 0x0002, 0x2080, 0x3200, /* 1610 */
  0x8024, 0x3c40, 0x0024, 0x4020, 0xb291, 0xf400, 0x4010, 0x0002, /* 1618 */
  0x1600, 0x3004, 0x0024, 0x2903, 0x8bc0, 0x3e10, 0x0024, 0x6192, /* 1620 */
  0x1b0c, 0x6898, 0x0024, 0x000a, 0x0011, 0x3200, 0x110c, 0x3613, /* 1628 */
  0x3393, 0x438e, 0x10c1, 0x4100, 0x0024, 0xf400, 0x4010, 0x0000, /* 1630 */
  0x3b41, 0x3004, 0xc024, 0xf400, 0x44c0, 0x0008, 0x0010, 0x3009, /* 1638 */
  0x33d3, 0x4010, 0x9053, 0x2903, 0x0b40, 0x3cb0, 0x0024, 0xb88e, /* 1640 */
  0x114c, 0x3009, 0x1050, 0x34a0, 0x014c, 0x3000, 0x4024, 0x4010, /* 1648 */
  0x0024, 0x6314, 0x4010, 0x6270, 0x0024, 0x0000, 0x0024, 0x2801, /* 1650 */
  0x0889, 0x4090, 0x0024, 0x2401, 0x0840, 0x0000, 0x0024, 0x0000, /* 1658 */
  0x0086, 0x3000, 0x0024, 0xf000, 0x0024, 0x6060, 0x0024, 0x0000, /* 1660 */
  0x0000, 0x2801, 0x0818, 0x0000, 0x0024, 0x3800, 0x0024, 0x679e, /* 1668 */
  0x004c, 0x6898, 0x0024, 0x0000, 0x0007, 0x4780, 0x41c2, 0x6372, /* 1670 */
  0x0024, 0x0008, 0x0011, 0x2801, 0x0e09, 0x000a, 0x0010, 0x4192, /* 1678 */
  0x0024, 0x2401, 0x0dc1, 0x0000, 0x0024, 0x3110, 0x4024, 0x6182, /* 1680 */
  0x0024, 0x0000, 0x0024, 0x2801, 0x0c45, 0x0000, 0x0024, 0xf400, /* 1688 */
  0x41c0, 0x3010, 0x4024, 0x6182, 0x0024, 0x0000, 0x0024, 0x2801, /* 1690 */
  0x0dc5, 0x0000, 0x0024, 0xf400, 0x41c2, 0x679e, 0x0024, 0x3453, /* 1698 */
  0x184c, 0x6090, 0x1050, 0x6290, 0x2040, 0x3800, 0x0024, 0x34a0, /* 16a0 */
  0x0024, 0x3e10, 0x0024, 0x3e11, 0x4024, 0x3e10, 0xc024, 0x2902, /* 16a8 */
  0x0700, 0x0002, 0x1610, 0x0002, 0x1f90, 0x3443, 0x1b4c, 0x4084, /* 16b0 */
  0xb012, 0x0002, 0x1752, 0xb386, 0x0000, 0x4020, 0x0024, 0x3800, /* 16b8 */
  0x0024, 0x0002, 0x1710, 0x3004, 0x0024, 0xf400, 0x4411, 0x3163, /* 16c0 */
  0x0024, 0x3110, 0x0024, 0x31f0, 0x4024, 0x4cd2, 0x0024, 0x3910, /* 16c8 */
  0x0024, 0x39f0, 0x4024, 0x3210, 0x8024, 0x32f0, 0xc024, 0x6dc6, /* 16d0 */
  0x9312, 0x0000, 0x0024, 0x2801, 0x1b81, 0x4dc6, 0x0024, 0x6cd2, /* 16d8 */
  0x810c, 0x3910, 0x0024, 0x39f0, 0x4024, 0x0002, 0x2011, 0x3010, /* 16e0 */
  0x0024, 0x30f0, 0x4024, 0x6c92, 0x0024, 0x3810, 0x0024, 0x38b0, /* 16e8 */
  0x4024, 0x3104, 0x4024, 0x3104, 0x4024, 0x3173, 0x0024, 0x3173, /* 16f0 */
  0x0024, 0x3153, 0x0024, 0x3110, 0x8024, 0x2914, 0xa580, 0x31f0, /* 16f8 */
  0xc024, 0x4c86, 0x01cc, 0x0000, 0x00c0, 0xad02, 0x004c, 0x3810, /* 1700 */
  0x0024, 0x38f0, 0x4024, 0x3433, 0x0024, 0x34d4, 0x0024, 0x3010, /* 1708 */
  0x0024, 0x30f0, 0x4024, 0x0002, 0x1c10, 0x3010, 0x8024, 0x30f0, /* 1710 */
  0xc024, 0x6cd6, 0x0024, 0x6892, 0x0024, 0x0000, 0x0021, 0x0000, /* 1718 */
  0x0000, 0x0000, 0x0020, 0x6cd6, 0x0024, 0x0000, 0x0007, 0x2801, /* 1720 */
  0x5611, 0x0000, 0x0024, 0x3473, 0x0024, 0x3413, 0x0024, 0x3404, /* 1728 */
  0x0024, 0x3033, 0x0024, 0x30d0, 0x0024, 0x6080, 0x3250, 0x0000, /* 1730 */
  0x0024, 0x2801, 0x4f95, 0x34f3, 0x0024, 0x6766, 0x0024, 0x0030, /* 1738 */
  0x0050, 0x2801, 0x4f85, 0x0000, 0x0024, 0x3000, 0x504c, 0x3613, /* 1740 */
  0x13c0, 0x2908, 0xc840, 0xb106, 0x0024, 0x0030, 0x0050, 0x3000, /* 1748 */
  0x11cc, 0xc030, 0x0024, 0x3800, 0x0024, 0x3300, 0x0024, 0x34d4, /* 1750 */
  0x0024, 0x3800, 0x0024, 0x3424, 0x0024, 0x3000, 0x12d0, 0x3b00, /* 1758 */
  0x0024, 0x3200, 0x0024, 0x3800, 0x0024, 0x3424, 0x0024, 0x3000, /* 1760 */
  0x1350, 0x3a00, 0x0024, 0x3004, 0x0024, 0x3009, 0x0003, 0x0002, /* 1768 */
  0x1f10, 0x3010, 0x0024, 0x30f0, 0x4024, 0x6c92, 0x0024, 0x3810, /* 1770 */
  0x0024, 0x2801, 0x3500, 0x38f0, 0x4024, 0x3009, 0x1240, 0x3e10, /* 1778 */
  0x0024, 0x0002, 0x1600, 0x3e11, 0x4024, 0x2900, 0x8580, 0x3e10, /* 1780 */
  0x0024, 0x6080, 0x1b4c, 0x0000, 0x0024, 0x2801, 0x3508, 0x0000, /* 1788 */
  0x0024, 0x0002, 0x1bd0, 0x0002, 0x1ac1, 0x3413, 0x0024, 0x3c14, /* 1790 */
  0x0024, 0x3000, 0x0024, 0x4100, 0x0024, 0xf400, 0x4010, 0x0000, /* 1798 */
  0x04c0, 0x3000, 0xf380, 0x0000, 0x0690, 0x38f0, 0xc024, 0x3000, /* 17a0 */
  0x4024, 0x6182, 0x0024, 0x0000, 0x0650, 0x2801, 0x3295, 0x0000, /* 17a8 */
  0x0653, 0x0002, 0x1b92, 0x3800, 0xd04c, 0x0000, 0x0610, 0x3800, /* 17b0 */
  0xc024, 0x34f4, 0x0024, 0x3000, 0x0024, 0x0002, 0x1b50, 0x3a00, /* 17b8 */
  0x0024, 0x3800, 0x0024, 0x0002, 0x1b50, 0x3310, 0x118c, 0x689e, /* 17c0 */
  0xb390, 0x0000, 0x0690, 0x6898, 0x30d0, 0x0000, 0x0610, 0xa402, /* 17c8 */
  0x0fc0, 0xa400, 0x3250, 0x4100, 0x0024, 0xf106, 0x0024, 0x678e, /* 17d0 */
  0x0024, 0x0000, 0x0024, 0x2800, 0xecd5, 0x0000, 0x0024, 0x0002, /* 17d8 */
  0xf611, 0x3473, 0x0440, 0xb884, 0x108c, 0x3c10, 0x0440, 0x3cd0, /* 17e0 */
  0x0024, 0x3009, 0x1240, 0x6080, 0x0024, 0x0000, 0x0024, 0x2801, /* 17e8 */
  0x4a15, 0x0000, 0x0024, 0x0000, 0x0001, 0x0008, 0x0010, 0x2914, /* 17f0 */
  0xbec0, 0x4380, 0x40c2, 0x000a, 0x0010, 0xb882, 0x118c, 0x4280, /* 17f8 */
  0x0024, 0x000a, 0x0002, 0x2914, 0xbec0, 0x3ca0, 0x8024, 0x0002, /* 1800 */
  0x1c90, 0x0030, 0x06d1, 0x6890, 0x91cc, 0xfe06, 0x0040, 0x30f0, /* 1808 */
  0x504c, 0x4cb2, 0x40c2, 0x6890, 0x2040, 0x3870, 0x4024, 0x3900, /* 1810 */
  0x004c, 0x003e, 0x0011, 0x0038, 0x0000, 0x3004, 0x0401, 0x6102, /* 1818 */
  0x010c, 0x0000, 0x0100, 0x3009, 0x32c0, 0x3009, 0x0000, 0x0002, /* 1820 */
  0x1ed0, 0x6100, 0xb090, 0x6080, 0x0024, 0x0002, 0x1c90, 0x2801, /* 1828 */
  0x4158, 0x6898, 0x0024, 0x0003, 0x0001, 0x6898, 0x0024, 0x4010, /* 1830 */
  0x0024, 0x3c00, 0xb383, 0xfe40, 0x3090, 0x3010, 0x8024, 0x30f0, /* 1838 */
  0xc024, 0x0006, 0x0010, 0x4db2, 0x9303, 0x6890, 0x2040, 0x38f0, /* 1840 */
  0x4024, 0x0030, 0x0710, 0x3800, 0x3100, 0x34b0, 0x8024, 0x6284, /* 1848 */
  0x0024, 0x0000, 0x0024, 0x2801, 0x4a05, 0x0000, 0x0024, 0x0008, /* 1850 */
  0x0001, 0x4290, 0x104c, 0x4102, 0x0024, 0xf400, 0x4050, 0x3000, /* 1858 */
  0x4024, 0x0002, 0xf590, 0x3009, 0x2001, 0x0002, 0x17d0, 0x3001, /* 1860 */
  0x53c1, 0x6152, 0x0024, 0x000a, 0x0005, 0x2801, 0x4941, 0x4500, /* 1868 */
  0x0024, 0xf400, 0x4010, 0x3000, 0x0024, 0x0002, 0xf5d0, 0x3009, /* 1870 */
  0x2000, 0x000a, 0x0000, 0x3463, 0x0024, 0x3ca0, 0x0024, 0x6230, /* 1878 */
  0x11cc, 0x0008, 0x0005, 0x2801, 0x29d8, 0x3009, 0x184c, 0x0000, /* 1880 */
  0x004d, 0x6892, 0x9bcc, 0x2401, 0x4e8d, 0xb880, 0xb241, 0x0002, /* 1888 */
  0xf581, 0x4102, 0x0024, 0xf400, 0x4050, 0x0002, 0x0001, 0xfe10, /* 1890 */
  0x8006, 0x0008, 0x0001, 0x48ba, 0x0024, 0x4142, 0x0024, 0x4122, /* 1898 */
  0x0024, 0x6090, 0x4050, 0x3801, 0x8024, 0x6294, 0x0024, 0x2801, /* 18a0 */
  0x4a00, 0x6898, 0x0024, 0x0002, 0x2010, 0x3000, 0x8024, 0x6284, /* 18a8 */
  0x0024, 0x0000, 0x06c0, 0x2801, 0x5245, 0x0002, 0x1c90, 0x3010, /* 18b0 */
  0x184c, 0x30f0, 0x4024, 0x2902, 0x03c0, 0xf400, 0x4090, 0x0000, /* 18b8 */
  0x06c0, 0x34d3, 0x180f, 0x3434, 0x0024, 0x3800, 0x0024, 0x36f3, /* 18c0 */
  0x8024, 0x36f4, 0xd80d, 0x36f4, 0x5812, 0x36f1, 0xd810, 0x36f1, /* 18c8 */
  0x5806, 0x36f0, 0xd804, 0x36f0, 0x5802, 0x3405, 0x9014, 0x36f3, /* 18d0 */
  0x0024, 0x36f2, 0x0024, 0x2000, 0x0000, 0x003f, 0xffc0, 0x2801, /* 18d8 */
  0x1f80, 0x0000, 0x0087, 0x0007, 0x0001, 0x0018, 0x0006, 0x8003, /* 18e0 */
  0x0000, 0x0007, 0x0001, 0x4bd8, 0x0006, 0x0002, 0x2000, 0x2800, /* 18e8 */
  0x0007, 0x0001, 0x001b, 0x0006, 0x0001, 0x0000, 0x0007, 0x0001, /* 18f0 */
  0x855a, 0x0006, 0x004a, 0x3e12, 0x0024, 0x3e05, 0xb814, 0x3615, /* 18f8 */
  0x0024, 0x3e01, 0xb847, 0x4c8e, 0x3852, 0x0002, 0x4112, 0x0019, /* 1900 */
  0xd4c1, 0x0013, 0xd9c0, 0x3a10, 0x0024, 0x2903, 0xe540, 0x3af0, /* 1908 */
  0x4024, 0x0002, 0x42d2, 0x6284, 0x2840, 0x3af0, 0x4024, 0x2801, /* 1910 */
  0x5ec5, 0x0000, 0x00c0, 0x0002, 0x4192, 0x4090, 0x0024, 0x3a00, /* 1918 */
  0x0024, 0x0002, 0x8800, 0x0002, 0x4812, 0xbc82, 0x2a40, 0x3a14, /* 1920 */
  0x0024, 0x3a10, 0x0024, 0x3af0, 0x4024, 0x36f4, 0x8024, 0x36f1, /* 1928 */
  0x9807, 0x3405, 0x9014, 0x36f3, 0x0024, 0x36f2, 0x0024, 0x2000, /* 1930 */
  0x0000, 0x0002, 0x4100, 0x0000, 0x00c0, 0x0002, 0x4792, 0xb882, /* 1938 */
  0x2840, 0x2801, 0x5b40, 0x3af0, 0x4024, 0x0007, 0x0001, 0x857f, /* 1940 */
  0x0006, 0x0028, 0x0000, 0x0020, 0x3e00, 0xf844, 0x003f, 0xfa03, /* 1948 */
  0x3e01, 0x7810, 0xac3a, 0x0024, 0x0000, 0x3fc3, 0xd424, 0x0024, /* 1950 */
  0xb234, 0x0024, 0x0002, 0xfc83, 0x4224, 0x0024, 0x4324, 0x0024, /* 1958 */
  0xf400, 0x4090, 0x0000, 0x0202, 0x3009, 0x0044, 0x3009, 0x03c5, /* 1960 */
  0xac22, 0x9810, 0xdec2, 0x1bc5, 0x36f0, 0xd804, 0x2000, 0x0000, /* 1968 */
  0x0000, 0x0024, 0x0007, 0x0001, 0x8593, 0x0006, 0x00d2, 0x3e12, /* 1970 */
  0x0024, 0x3e05, 0xb814, 0x3645, 0x0024, 0x3e00, 0x3841, 0x3e00, /* 1978 */
  0xb843, 0x3e01, 0x3845, 0x3e01, 0xb847, 0x3e04, 0x7852, 0xbc82, /* 1980 */
  0x4412, 0x3e03, 0x784e, 0x0000, 0x030d, 0x3e03, 0xc9cc, 0x3243, /* 1988 */
  0x0024, 0x3a10, 0x0024, 0x3af0, 0x4024, 0x2401, 0x6b4d, 0xf400, /* 1990 */
  0x4412, 0x003f, 0xfe02, 0xb58a, 0x0843, 0x4388, 0x984c, 0xae2a, /* 1998 */
  0x0024, 0x2901, 0x5fc0, 0x4484, 0x0024, 0x0000, 0x3fc2, 0x2901, /* 19a0 */
  0x5fc0, 0xb324, 0x184c, 0x0000, 0x0024, 0xf400, 0x4412, 0x0000, /* 19a8 */
  0x0744, 0x3273, 0x184c, 0x3263, 0x0024, 0x2901, 0x5fc0, 0x3200, /* 19b0 */
  0x8024, 0xb886, 0x4402, 0x4244, 0x0024, 0xf400, 0x4092, 0xf400, /* 19b8 */
  0x4411, 0x3173, 0x0024, 0x3163, 0x0024, 0x3100, 0x8024, 0x6328, /* 19c0 */
  0x0024, 0x0000, 0x0024, 0x2801, 0x70c1, 0x0000, 0x0024, 0x2901, /* 19c8 */
  0x5fc0, 0x3210, 0x984c, 0x2801, 0x6dc0, 0x6396, 0x0024, 0x0000, /* 19d0 */
  0x3fc6, 0x003f, 0xfe05, 0x0000, 0x4703, 0xb888, 0x4402, 0x4234, /* 19d8 */
  0x0024, 0xf400, 0x4092, 0xf400, 0x4411, 0x3173, 0x0024, 0x3173, /* 19e0 */
  0x0024, 0x3113, 0x0024, 0x3100, 0x8024, 0x6426, 0x4411, 0x3173, /* 19e8 */
  0x0024, 0x2801, 0x7801, 0x3173, 0x0024, 0x3413, 0x184c, 0x3c01, /* 19f0 */
  0xb047, 0xb78f, 0xc0c1, 0x3210, 0xc024, 0xf400, 0x40c6, 0xaf52, /* 19f8 */
  0x0024, 0x4084, 0x1000, 0x3009, 0x13c1, 0x2901, 0x5fc0, 0x3401, /* 1a00 */
  0x93c7, 0x2901, 0x5fc0, 0xb364, 0x184c, 0x2801, 0x7240, 0x6498, /* 1a08 */
  0x0024, 0x3123, 0x0024, 0x3100, 0x8024, 0x6284, 0x0024, 0x0000, /* 1a10 */
  0x0024, 0x2801, 0x7a85, 0x0000, 0x0024, 0x003f, 0xfe02, 0xb58a, /* 1a18 */
  0x0804, 0x2901, 0x5fc0, 0xae26, 0x984c, 0x2903, 0xe540, 0x4c8e, /* 1a20 */
  0x184c, 0x3073, 0x0024, 0x3043, 0x0024, 0x3810, 0x0024, 0x38f0, /* 1a28 */
  0x4024, 0x36f3, 0xc024, 0x36f3, 0x580e, 0x36f4, 0x5812, 0x36f1, /* 1a30 */
  0x9807, 0x36f1, 0x1805, 0x36f0, 0x9803, 0x36f0, 0x1801, 0x3405, /* 1a38 */
  0x9014, 0x36f3, 0x0024, 0x36f2, 0x0024, 0x2000, 0x0000, 0x0000, /* 1a40 */
  0x0024, 0x0007, 0x0001, 0x85fc, 0x0006, 0x014c, 0x3e12, 0x0024, /* 1a48 */
  0x3e05, 0xb814, 0x3635, 0x0024, 0x3e00, 0x3841, 0x0000, 0x0540, /* 1a50 */
  0x3e00, 0xb843, 0x3e01, 0x3845, 0xf400, 0x4405, 0x3e01, 0xb847, /* 1a58 */
  0x3e14, 0x7812, 0x4500, 0x0024, 0xf400, 0x4010, 0x0000, 0x0580, /* 1a60 */
  0x4500, 0x0052, 0x3011, 0x8024, 0x30f1, 0xc024, 0xf400, 0x4010, /* 1a68 */
  0x0000, 0x00c0, 0x4500, 0x008c, 0x2903, 0xe540, 0xf400, 0x4011, /* 1a70 */
  0x3910, 0x184c, 0x3910, 0x4024, 0x3011, 0x8024, 0x2903, 0xe540, /* 1a78 */
  0x30f1, 0xc024, 0x3910, 0x184c, 0x0000, 0x02c0, 0x4500, 0x27c1, /* 1a80 */
  0xf400, 0x4011, 0x3111, 0x8024, 0x2903, 0xe500, 0x31f1, 0xc024, /* 1a88 */
  0x3910, 0x184c, 0x0000, 0x0680, 0x4500, 0x27c1, 0xf400, 0x4011, /* 1a90 */
  0x3111, 0x8024, 0x2903, 0xe540, 0x31f1, 0xc024, 0x4c86, 0x984c, /* 1a98 */
  0x0000, 0x0240, 0x4500, 0x0024, 0xf400, 0x4010, 0x3810, 0x8024, /* 1aa0 */
  0x38f0, 0xc024, 0x2901, 0x64c0, 0xf400, 0x4150, 0xf400, 0x4490, /* 1aa8 */
  0x0000, 0x0680, 0x3613, 0x008c, 0x3e10, 0x0024, 0x3e11, 0x4024, /* 1ab0 */
  0x3e04, 0x8024, 0x3000, 0x0024, 0xf400, 0x4008, 0x2000, 0x0000, /* 1ab8 */
  0x0001, 0x8d88, 0x3110, 0x1b8c, 0x31f0, 0x504c, 0x6c92, 0x0024, /* 1ac0 */
  0x3910, 0x0024, 0x0000, 0x0340, 0x4500, 0x27c1, 0xf400, 0x4011, /* 1ac8 */
  0x0000, 0x0200, 0x3100, 0x4024, 0xa100, 0x0024, 0x6890, 0x3000, /* 1ad0 */
  0x3e10, 0x0024, 0x3e15, 0x13cc, 0x3e04, 0x8024, 0x3000, 0x0024, /* 1ad8 */
  0xf400, 0x4008, 0x2000, 0x0000, 0x0001, 0x9208, 0x0000, 0x0203, /* 1ae0 */
  0x0000, 0x0342, 0x0000, 0x0740, 0xb882, 0x908c, 0x4500, 0x4506, /* 1ae8 */
  0x6898, 0x4011, 0x34e3, 0x1b4c, 0x4520, 0x908c, 0xf400, 0x4010, /* 1af0 */
  0x3000, 0x184c, 0x6100, 0x0024, 0x0000, 0x03c0, 0x2801, 0x9881, /* 1af8 */
  0x0000, 0x0024, 0x3110, 0x0024, 0xa030, 0x0024, 0x3ce0, 0x0024, /* 1b00 */
  0x3e11, 0x0024, 0x3e11, 0x8024, 0x3e04, 0x888c, 0x32e0, 0x0024, /* 1b08 */
  0xf400, 0x4008, 0x2000, 0x0000, 0x0001, 0x9808, 0x2801, 0x93c0, /* 1b10 */
  0x6192, 0x1b4c, 0x0000, 0x06c2, 0x4500, 0x938c, 0xb78e, 0x4010, /* 1b18 */
  0x3010, 0x0024, 0x4002, 0x0340, 0x4100, 0x0181, 0x4212, 0x0042, /* 1b20 */
  0x410c, 0x03c3, 0x0000, 0x0341, 0x4df6, 0x0024, 0x3810, 0x8024, /* 1b28 */
  0x38f0, 0xc024, 0x3e10, 0x0024, 0x0000, 0x4700, 0x4500, 0x0024, /* 1b30 */
  0x3e10, 0x0024, 0x3e04, 0x888c, 0x3200, 0x0024, 0x4512, 0x4008, /* 1b38 */
  0xf400, 0x4052, 0x2000, 0x0000, 0x0001, 0x9e08, 0x3200, 0x5b4c, /* 1b40 */
  0x6890, 0x0024, 0x6182, 0x0024, 0x0000, 0x0381, 0x2801, 0xa805, /* 1b48 */
  0x4512, 0x0024, 0xf400, 0x4050, 0x0000, 0x3fc1, 0x3000, 0x8024, /* 1b50 */
  0x6212, 0x0024, 0x0000, 0x0024, 0x2801, 0xa815, 0x0000, 0x0024, /* 1b58 */
  0x0000, 0x0081, 0x4512, 0x9812, 0xf400, 0x4050, 0x3800, 0x0024, /* 1b60 */
  0x0000, 0x0400, 0x4500, 0x0024, 0xb880, 0x4010, 0x38f0, 0x0024, /* 1b68 */
  0x38f0, 0x0024, 0x38f0, 0x0024, 0x3800, 0x0024, 0x0000, 0x0700, /* 1b70 */
  0x4500, 0x0024, 0xf400, 0x4010, 0x0000, 0x4700, 0x4500, 0x0024, /* 1b78 */
  0x3800, 0x0024, 0x36f4, 0x4024, 0x36f1, 0x9807, 0x36f1, 0x1805, /* 1b80 */
  0x36f0, 0x9803, 0x36f0, 0x1801, 0x3405, 0x9014, 0x36f3, 0x0024, /* 1b88 */
  0x36f2, 0x0024, 0x2000, 0x0000, 0x0000, 0x0024, 0x2801, 0xa140, /* 1b90 */
  0xb880, 0x0024, 0x0007, 0x0001, 0x86a2, 0x0006, 0x00b8, 0x3e12, /* 1b98 */
  0x0024, 0x3e05, 0xb814, 0x3615, 0x0024, 0x3e00, 0x7842, 0x3e00, /* 1ba0 */
  0xf844, 0x3e04, 0x7852, 0x4082, 0x4412, 0xf400, 0x4490, 0x0000, /* 1ba8 */
  0x3fc0, 0x3e04, 0xc1cc, 0x3073, 0x0024, 0x3000, 0x8024, 0x6204, /* 1bb0 */
  0x4490, 0x3073, 0x0024, 0x2801, 0xb785, 0x3063, 0x0024, 0x6894, /* 1bb8 */
  0x4490, 0x3073, 0x0024, 0x3073, 0x0024, 0x3023, 0x0024, 0x3000, /* 1bc0 */
  0x0024, 0x6200, 0x4482, 0x6080, 0x2000, 0x0000, 0x0700, 0x2801, /* 1bc8 */
  0xb485, 0x0000, 0x0024, 0x0000, 0x0200, 0xa100, 0x4482, 0x0000, /* 1bd0 */
  0x0701, 0x4212, 0x0024, 0xf400, 0x4050, 0x3004, 0x0024, 0x3800, /* 1bd8 */
  0x09cc, 0x3273, 0x0024, 0x3200, 0x0024, 0x6090, 0x0024, 0x3a00, /* 1be0 */
  0x0024, 0x36f4, 0xc024, 0x36f4, 0x5812, 0x36f0, 0xd804, 0x36f0, /* 1be8 */
  0x5802, 0x3405, 0x9014, 0x36f3, 0x0024, 0x36f2, 0x0024, 0x2000, /* 1bf0 */
  0x0000, 0x0000, 0x0024, 0xf400, 0x4482, 0x0000, 0x0700, 0x4200, /* 1bf8 */
  0x0024, 0xf400, 0x4010, 0x3004, 0x4024, 0xf400, 0x4453, 0x3313, /* 1c00 */
  0x0024, 0x3894, 0xc024, 0x3100, 0x028c, 0xc010, 0x0024, 0x3900, /* 1c08 */
  0x0024, 0x3000, 0x0024, 0x2801, 0xb080, 0x6090, 0x0024, 0x3000, /* 1c10 */
  0x8024, 0x6296, 0x4484, 0x3820, 0xc024, 0x0000, 0x0743, 0x4436, /* 1c18 */
  0x0024, 0x4324, 0x0024, 0xf400, 0x4091, 0x3900, 0x0024, 0x0001, /* 1c20 */
  0xe000, 0x30e0, 0x8024, 0x6200, 0x0002, 0x0000, 0x3f80, 0x2801, /* 1c28 */
  0xbd41, 0x0000, 0x0024, 0x6200, 0x0024, 0x0000, 0x0024, 0x2801, /* 1c30 */
  0xbd41, 0x0000, 0x0024, 0xb880, 0x4490, 0x3073, 0x0024, 0x3073, /* 1c38 */
  0x0024, 0x2801, 0xac80, 0x3800, 0x0024, 0xf400, 0x4490, 0x2901, /* 1c40 */
  0x7f00, 0x3613, 0x0024, 0x6890, 0x4490, 0x3073, 0x0024, 0x3073, /* 1c48 */
  0x0024, 0x3033, 0x0024, 0x2801, 0xbc00, 0x3800, 0x0024, 0x0007, /* 1c50 */
  0x0001, 0x86fe, 0x0006, 0x00ce, 0x3e12, 0x0024, 0x3e05, 0xb814, /* 1c58 */
  0x3615, 0x0024, 0x3e00, 0xb843, 0x3e01, 0x3851, 0x0000, 0x0744, /* 1c60 */
  0x3e04, 0xb813, 0xf400, 0x4412, 0xf400, 0x4490, 0x3073, 0x0024, /* 1c68 */
  0x3063, 0x0024, 0x3000, 0x8024, 0x6296, 0x4493, 0x3810, 0xcdcc, /* 1c70 */
  0xf400, 0x4483, 0x4346, 0x8dcc, 0x4324, 0x0003, 0xf400, 0x4091, /* 1c78 */
  0x3910, 0xc024, 0x0000, 0x3fc3, 0x30f0, 0x8024, 0x6234, 0x0024, /* 1c80 */
  0xf400, 0x4482, 0x2801, 0xc755, 0x0000, 0x0583, 0x3000, 0x8024, /* 1c88 */
  0x6294, 0x0024, 0xb884, 0x2002, 0x3900, 0x8024, 0x3b00, 0x8024, /* 1c90 */
  0xf400, 0x4482, 0x4234, 0x0024, 0xf400, 0x4090, 0x3010, 0x8024, /* 1c98 */
  0x30f0, 0xc024, 0x6cd6, 0x0024, 0x0000, 0x0024, 0x2801, 0xcac1, /* 1ca0 */
  0x0000, 0x0024, 0x3023, 0x0024, 0x3010, 0x8024, 0x30f0, 0xc024, /* 1ca8 */
  0x6d96, 0x0024, 0x3810, 0x8024, 0x38d0, 0xc024, 0x3810, 0x138c, /* 1cb0 */
  0x0001, 0xe000, 0x38f0, 0x4024, 0xf400, 0x4490, 0x3073, 0x0024, /* 1cb8 */
  0x3073, 0x0024, 0x3013, 0x0024, 0x3000, 0x4024, 0x6100, 0x4490, /* 1cc0 */
  0x0000, 0x3f81, 0x2801, 0xd8c1, 0x3073, 0x0024, 0x3063, 0x0024, /* 1cc8 */
  0x3000, 0x0024, 0x6010, 0x0024, 0x0000, 0x0024, 0x2801, 0xd501, /* 1cd0 */
  0x0000, 0x0024, 0x3420, 0x0024, 0x6080, 0x0024, 0x0002, 0x1f90, /* 1cd8 */
  0x2801, 0xd555, 0x0000, 0x0024, 0x3010, 0x8024, 0x3000, 0x4024, /* 1ce0 */
  0x6124, 0x0024, 0x0000, 0x0024, 0x2801, 0xd551, 0x0000, 0x0024, /* 1ce8 */
  0x3273, 0x1813, 0xb880, 0x09cc, 0x3a00, 0x0024, 0x36f4, 0x8024, /* 1cf0 */
  0x36f1, 0x1811, 0x36f0, 0x9803, 0x3405, 0x9014, 0x36f3, 0x0024, /* 1cf8 */
  0x36f2, 0x0024, 0x2000, 0x0000, 0x0000, 0x0024, 0x34e3, 0x0024, /* 1d00 */
  0x3420, 0x0024, 0x0000, 0x0001, 0x0002, 0x1f90, 0x6080, 0x2001, /* 1d08 */
  0xf400, 0x4490, 0x2801, 0xd845, 0x3613, 0x0024, 0x0000, 0x0101, /* 1d10 */
  0x3223, 0x0024, 0x3200, 0x0024, 0xc010, 0x0024, 0x3ae0, 0x0024, /* 1d18 */
  0xf400, 0x4490, 0x2901, 0x7f00, 0x0001, 0xd208, 0x2801, 0xd540, /* 1d20 */
  0x3420, 0x0024, 0x0007, 0x0001, 0x0904, 0x0006, 0x891c, 0x0000, /* 1d28 */
  0x0007, 0x0001, 0x8765, 0x0006, 0x0032, 0x3e12, 0x0024, 0x3e05, /* 1d30 */
  0xb814, 0x3615, 0x0024, 0x3e00, 0xb844, 0x3e11, 0x7812, 0x4c8a, /* 1d38 */
  0x4412, 0xbc82, 0x4490, 0x2901, 0xdf80, 0x0000, 0x01c2, 0xb880, /* 1d40 */
  0x4490, 0x3023, 0x138c, 0x38f0, 0x184c, 0x3800, 0x0024, 0x3420, /* 1d48 */
  0x0024, 0x4e82, 0x3840, 0x2901, 0xbf80, 0x3204, 0x0024, 0x36f3, /* 1d50 */
  0x0024, 0x36f1, 0x5812, 0x36f0, 0x9804, 0x3405, 0x9014, 0x36f3, /* 1d58 */
  0x0024, 0x36f2, 0x0024, 0x2000, 0x0000, 0x0000, 0x0024, 0x0007, /* 1d60 */
  0x0001, 0x877e, 0x0006, 0x0066, 0x3e12, 0x0024, 0x3e05, 0xb814, /* 1d68 */
  0x3625, 0x0024, 0x3e00, 0xf844, 0x3e01, 0x7846, 0x0000, 0x0206, /* 1d70 */
  0x3e01, 0xf812, 0x4286, 0x4412, 0x4c8a, 0x084c, 0x3210, 0x0024, /* 1d78 */
  0x32f0, 0x8024, 0x660e, 0x0bcc, 0x6372, 0x0024, 0x0000, 0x0024, /* 1d80 */
  0x2801, 0xe3d1, 0x4172, 0x0024, 0xf400, 0x41c1, 0x0000, 0x07c7, /* 1d88 */
  0x471e, 0x104c, 0xf400, 0x41d0, 0x3cf0, 0x0024, 0x3001, 0xc024, /* 1d90 */
  0xb47e, 0x0024, 0xa70e, 0x0024, 0x4010, 0x0024, 0xc274, 0x0024, /* 1d98 */
  0x606e, 0x0024, 0x0000, 0x0024, 0x2801, 0xe851, 0x0000, 0x0024, /* 1da0 */
  0x3204, 0x184c, 0x2901, 0xa880, 0x4280, 0x0024, 0x0000, 0x0002, /* 1da8 */
  0xf400, 0x4080, 0x681e, 0x084c, 0xae7a, 0x0024, 0x6316, 0x0024, /* 1db0 */
  0x0000, 0x0024, 0x2801, 0xe255, 0x0000, 0x0024, 0x3a10, 0x0024, /* 1db8 */
  0x3a00, 0x9812, 0x36f1, 0xc024, 0x36f1, 0x5806, 0x36f0, 0xd804, /* 1dc0 */
  0x3405, 0x9014, 0x36f3, 0x0024, 0x36f2, 0x0024, 0x2000, 0x0000, /* 1dc8 */
  0x0000, 0x0024, 0x0007, 0x0001, 0x87b1, 0x0006, 0x00bc, 0x3e12, /* 1dd0 */
  0x0024, 0x3e05, 0xb814, 0x3625, 0x0024, 0x3e00, 0xb843, 0x3e01, /* 1dd8 */
  0x3845, 0x3e01, 0xb847, 0x3e04, 0x7852, 0xb888, 0x3813, 0x418a, /* 1de0 */
  0x4412, 0x0000, 0x03c1, 0xfe10, 0x0024, 0x48b2, 0x0024, 0x0000, /* 1de8 */
  0x4941, 0x4100, 0x0024, 0xf400, 0x4010, 0xf400, 0x4411, 0x3173, /* 1df0 */
  0x0024, 0x3133, 0x0024, 0x3009, 0x0403, 0x4390, 0x0024, 0x0000, /* 1df8 */
  0x0024, 0x2801, 0xf649, 0x0000, 0x0024, 0x6898, 0x0024, 0x658a, /* 1e00 */
  0x0024, 0xfe4a, 0x0024, 0x2801, 0xf418, 0xf134, 0x0024, 0x003f, /* 1e08 */
  0xffc4, 0xf134, 0x0024, 0xfe4a, 0x0024, 0x48be, 0x0024, 0x4624, /* 1e10 */
  0x0024, 0x2914, 0xb200, 0x4380, 0x0024, 0xfe40, 0x0024, 0x48b2, /* 1e18 */
  0x0024, 0xfe30, 0x0024, 0x48b6, 0x0024, 0x6528, 0x4005, 0x6896, /* 1e20 */
  0x4411, 0x3413, 0x05cc, 0x3c04, 0x848c, 0x3009, 0x0680, 0x6500, /* 1e28 */
  0x4413, 0x3373, 0x05c1, 0x6010, 0x4412, 0x3143, 0x09cc, 0x3273, /* 1e30 */
  0x0781, 0xfe90, 0x8400, 0x4cb2, 0x8d8c, 0x3009, 0x27c0, 0x3009, /* 1e38 */
  0x04c1, 0x3009, 0x0400, 0xff90, 0x0024, 0x48b2, 0x0024, 0x3009, /* 1e40 */
  0x27c0, 0x3009, 0x0400, 0x6090, 0x0024, 0x3009, 0x2640, 0x31b3, /* 1e48 */
  0x3012, 0x34f4, 0x8401, 0x601a, 0x4411, 0x3173, 0x0024, 0x3153, /* 1e50 */
  0x0024, 0x2802, 0x0151, 0x003f, 0xffc6, 0x0000, 0xffc7, 0x003f, /* 1e58 */
  0xf982, 0x3413, 0x0400, 0xb882, 0x01cc, 0x3613, 0x2c01, 0x4000, /* 1e60 */
  0xa401, 0x3009, 0x13d1, 0x3009, 0x2403, 0x3009, 0x0001, 0x4100, /* 1e68 */
  0x0024, 0xf400, 0x4010, 0x3009, 0x0040, 0x3009, 0x03c1, 0x0000, /* 1e70 */
  0x0020, 0xac26, 0x4490, 0x2901, 0xdf80, 0xbcf2, 0x0024, 0x4480, /* 1e78 */
  0x1bd3, 0x36f4, 0x5812, 0x36f1, 0x9807, 0x36f1, 0x1805, 0x36f0, /* 1e80 */
  0x9803, 0x3405, 0x9014, 0x36f3, 0x0024, 0x36f2, 0x0024, 0x2000, /* 1e88 */
  0x0000, 0x0000, 0x0024, 0x0007, 0x0001, 0x880f, 0x0006, 0x001a, /* 1e90 */
  0x3e12, 0x0024, 0x3e05, 0xb814, 0x3615, 0x0024, 0x6894, 0x3842, /* 1e98 */
  0x2901, 0xd940, 0x3e10, 0x8024, 0x36f3, 0x0024, 0x36f0, 0x8024, /* 1ea0 */
  0x3405, 0x9014, 0x36f3, 0x0024, 0x36f2, 0x0024, 0x2000, 0x0000, /* 1ea8 */
  0x0000, 0x0024, 0x0007, 0x0001, 0x881c, 0x0006, 0x0368, 0x3e12, /* 1eb0 */
  0x0024, 0x3e05, 0xb814, 0x3675, 0x0024, 0x3613, 0x104c, 0x3e00, /* 1eb8 */
  0x7842, 0x0000, 0x0581, 0x3e00, 0xf844, 0x3e01, 0x7846, 0x3e01, /* 1ec0 */
  0xf851, 0xf400, 0x4407, 0xf400, 0x41d0, 0xf400, 0x4400, 0x3e04, /* 1ec8 */
  0xb853, 0x3e03, 0x784e, 0x4010, 0x384f, 0xf400, 0x4010, 0x0000, /* 1ed0 */
  0x0a81, 0x4712, 0x0000, 0x4100, 0x3300, 0xf400, 0x4010, 0x3004, /* 1ed8 */
  0x4024, 0x3470, 0x0024, 0x3423, 0x0024, 0x3c90, 0x0024, 0x34d3, /* 1ee0 */
  0x0024, 0x3470, 0x0024, 0x3443, 0x0024, 0x3c90, 0x0024, 0x0000, /* 1ee8 */
  0x0900, 0x4700, 0x0024, 0xf400, 0x4010, 0x3010, 0x0024, 0x30f0, /* 1ef0 */
  0x4024, 0xf400, 0x4041, 0x6c82, 0x0024, 0x0000, 0x0000, 0x2802, /* 1ef8 */
  0x7155, 0x0000, 0x0024, 0x0000, 0x0082, 0x6896, 0x904c, 0x3400, /* 1f00 */
  0x0024, 0x4000, 0x0024, 0xfe30, 0x0024, 0x0000, 0x0a00, 0x4700, /* 1f08 */
  0x0024, 0x48b2, 0x4012, 0x2901, 0xdf80, 0x3204, 0x0024, 0x3410, /* 1f10 */
  0x0024, 0x6080, 0x0024, 0x0000, 0x0000, 0x2802, 0x1745, 0x0000, /* 1f18 */
  0x0082, 0x0000, 0x0540, 0x34e3, 0x184c, 0x4700, 0x0024, 0xf400, /* 1f20 */
  0x4010, 0x3020, 0x4024, 0x3000, 0x0024, 0x4000, 0x0810, 0x4100, /* 1f28 */
  0x0024, 0xfe30, 0x0024, 0x2901, 0xdf80, 0x48b2, 0x0024, 0xb880, /* 1f30 */
  0x108c, 0x3009, 0x3300, 0x2802, 0x1880, 0x3421, 0x8024, 0x6090, /* 1f38 */
  0x0024, 0x3009, 0x3380, 0x0000, 0x0081, 0x3423, 0x0024, 0x3009, /* 1f40 */
  0x13c0, 0x6016, 0x0400, 0x0000, 0x0801, 0x2802, 0x2d58, 0x0000, /* 1f48 */
  0x0205, 0x3613, 0x3040, 0x3009, 0x1380, 0xfe10, 0x0024, 0x48b2, /* 1f50 */
  0x0024, 0x0000, 0x4441, 0x4086, 0x4440, 0x4010, 0x0024, 0x4038, /* 1f58 */
  0x0024, 0x0000, 0x0a00, 0x4700, 0x4113, 0x6890, 0x4012, 0xb882, /* 1f60 */
  0x0810, 0x2901, 0xdf80, 0x6894, 0x0024, 0x0000, 0x0b01, 0x6898, /* 1f68 */
  0x4450, 0x3423, 0x018c, 0x3ce4, 0x184c, 0x4712, 0x0000, 0x4136, /* 1f70 */
  0x0024, 0x6504, 0x40d0, 0x3000, 0x4024, 0x6800, 0x0810, 0xa100, /* 1f78 */
  0x0024, 0xfe40, 0x0024, 0x2901, 0xdf80, 0x48b2, 0x0024, 0x3423, /* 1f80 */
  0x184c, 0x34f4, 0x0024, 0x3000, 0x13c1, 0x4192, 0x0024, 0x4312, /* 1f88 */
  0x0024, 0x6504, 0x4050, 0x3000, 0x4024, 0x6800, 0x0810, 0xa100, /* 1f90 */
  0x0024, 0xfe40, 0x0024, 0x0000, 0x0004, 0x2901, 0xdf80, 0x48b2, /* 1f98 */
  0x0024, 0x3173, 0x108c, 0x3190, 0x0024, 0x6406, 0x9000, 0x0000, /* 1fa0 */
  0x1a42, 0x2802, 0x1801, 0x0000, 0x0024, 0x4440, 0x938c, 0x4002, /* 1fa8 */
  0x4440, 0x4020, 0x0024, 0x4010, 0x0024, 0xb884, 0x4010, 0x0000, /* 1fb0 */
  0x0780, 0x4700, 0x00cc, 0x3004, 0x0024, 0xf400, 0x4412, 0x3213, /* 1fb8 */
  0x0024, 0x3201, 0x4024, 0xf400, 0x4012, 0x3200, 0x4024, 0x3000, /* 1fc0 */
  0x0024, 0x4106, 0x0024, 0x6520, 0x0024, 0x0000, 0x0024, 0x2802, /* 1fc8 */
  0x2cc9, 0x4090, 0x0024, 0x2402, 0x2c80, 0x0000, 0x0024, 0x0000, /* 1fd0 */
  0x0a00, 0x3310, 0x584c, 0x4700, 0x0024, 0x4380, 0x4010, 0x2901, /* 1fd8 */
  0xec40, 0x3004, 0x0024, 0x6294, 0x0024, 0x2802, 0x2440, 0x6498, /* 1fe0 */
  0x0024, 0x0000, 0x004d, 0x34f3, 0x0024, 0x2402, 0x344d, 0x0000, /* 1fe8 */
  0x0002, 0xf400, 0x4440, 0x0000, 0x3b41, 0x4010, 0x048c, 0x4020, /* 1ff0 */
  0x0784, 0xf400, 0x4010, 0x3000, 0x0024, 0x4096, 0x0024, 0x643a, /* 1ff8 */
  0x0024, 0x0000, 0x0024, 0x2802, 0x3158, 0x6630, 0x0024, 0x6640, /* 2000 */
  0x4103, 0x6080, 0x118c, 0x3009, 0x184c, 0x2802, 0x3409, 0xf400, /* 2008 */
  0x4501, 0x4122, 0x928c, 0xf400, 0x4050, 0x3000, 0x4024, 0x4132, /* 2010 */
  0x0024, 0x2902, 0xc240, 0xf400, 0x4050, 0x3463, 0x184c, 0x34a3, /* 2018 */
  0x1bcc, 0x6294, 0x0024, 0x0000, 0x0700, 0x0000, 0x004d, 0xb88a, /* 2020 */
  0x104c, 0x4702, 0x1000, 0x4100, 0x0024, 0xf400, 0x4010, 0x3000, /* 2028 */
  0x0024, 0x2402, 0x454d, 0x3009, 0x33c0, 0x0000, 0x0800, 0xfe0a, /* 2030 */
  0x118c, 0x48b2, 0x0024, 0x0000, 0x1b01, 0x4712, 0x0024, 0x4100, /* 2038 */
  0x4501, 0xb888, 0x928c, 0x4152, 0x4012, 0xf400, 0x4050, 0x2802, /* 2040 */
  0x3a40, 0x3004, 0xc024, 0x3a10, 0x904c, 0x3009, 0x13c0, 0x4408, /* 2048 */
  0x0024, 0x3133, 0x0024, 0x31d0, 0x0024, 0x6406, 0x0024, 0x0000, /* 2050 */
  0x0000, 0x2802, 0x4558, 0x0000, 0x0024, 0xf400, 0x4003, 0x3413, /* 2058 */
  0x0024, 0x3009, 0x13c1, 0x601c, 0x0024, 0x0000, 0x0002, 0x2802, /* 2060 */
  0x3fd8, 0x0000, 0x0024, 0x3310, 0x8024, 0xf024, 0x0024, 0x6232, /* 2068 */
  0x0024, 0x0000, 0x0024, 0x2802, 0x3f49, 0x0000, 0x0024, 0xf400, /* 2070 */
  0x4083, 0x2802, 0x3c00, 0x6090, 0x0024, 0x0000, 0x0840, 0x4700, /* 2078 */
  0x904c, 0xf400, 0x4010, 0x3000, 0x0024, 0x620c, 0x0024, 0x0000, /* 2080 */
  0x0880, 0x2802, 0x39c1, 0x0000, 0x0024, 0x0000, 0x0141, 0x4700, /* 2088 */
  0x104c, 0xfe14, 0x4010, 0x3ce1, 0x3005, 0x3000, 0x0024, 0x4cb2, /* 2090 */
  0x0024, 0xf400, 0x4010, 0x3000, 0x0024, 0x630c, 0x0024, 0x0000, /* 2098 */
  0x0024, 0x2802, 0x3989, 0x0000, 0x0024, 0x2802, 0x3fc0, 0x6294, /* 20a0 */
  0x0024, 0x659a, 0x0024, 0xb88c, 0x104c, 0x3009, 0x10c0, 0x3cf0, /* 20a8 */
  0x0024, 0x0000, 0x0a00, 0x6890, 0xb080, 0x3cf0, 0x0024, 0x0000, /* 20b0 */
  0x0080, 0x3009, 0x33c0, 0x0000, 0x0800, 0x3cf0, 0x0024, 0x0000, /* 20b8 */
  0x1b00, 0x2802, 0x4900, 0x3ce0, 0x0024, 0x669c, 0x0024, 0x0000, /* 20c0 */
  0x00c0, 0x6604, 0x0024, 0x0000, 0x0900, 0x2802, 0x6798, 0x0000, /* 20c8 */
  0x0024, 0xb880, 0x108c, 0x2802, 0x4c00, 0xb88a, 0xb380, 0x659a, /* 20d0 */
  0x93c0, 0x3009, 0x1041, 0x4010, 0x0024, 0x3009, 0x3380, 0x3423, /* 20d8 */
  0x04cc, 0x31d0, 0x5380, 0x6014, 0x0024, 0x0000, 0x0024, 0x2802, /* 20e0 */
  0x48d8, 0x0000, 0x0024, 0x668c, 0x0024, 0x0000, 0x0024, 0x2802, /* 20e8 */
  0x5915, 0x0000, 0x0024, 0x3453, 0x0024, 0x34b0, 0x0024, 0xb500, /* 20f0 */
  0x0024, 0x0000, 0x0024, 0x2802, 0x5915, 0x0000, 0x0024, 0x0000, /* 20f8 */
  0x004d, 0x2402, 0x58cd, 0x0000, 0x0003, 0x0000, 0x0a04, 0x0000, /* 2100 */
  0x0080, 0x3443, 0x184c, 0x3009, 0x33c0, 0x0000, 0x0800, 0xfe06, /* 2108 */
  0x33c0, 0x48b2, 0x0024, 0xf400, 0x4001, 0x0000, 0x1b00, 0x3c10, /* 2110 */
  0x0024, 0x4700, 0xb344, 0x4014, 0x0024, 0x6590, 0x0024, 0x4200, /* 2118 */
  0x0024, 0xf400, 0x4010, 0x0000, 0x0800, 0x4700, 0x0001, 0x4748, /* 2120 */
  0x4012, 0x3270, 0x0024, 0x3213, 0x0024, 0x3204, 0x0024, 0x2901, /* 2128 */
  0xec40, 0xf400, 0x4113, 0x3293, 0x184c, 0x4250, 0x0bcc, 0xf400, /* 2130 */
  0x4010, 0x3000, 0x4024, 0x3200, 0x0024, 0x2901, 0xec40, 0x3304, /* 2138 */
  0x0024, 0x6396, 0x114c, 0x6890, 0x0024, 0x3cb0, 0x0024, 0x0000, /* 2140 */
  0x0004, 0x3443, 0x0024, 0x3009, 0x1380, 0x6404, 0x0024, 0x0000, /* 2148 */
  0x0880, 0x2802, 0x4b18, 0x0000, 0x0024, 0x4700, 0x904c, 0xf400, /* 2150 */
  0x4010, 0x3000, 0x8024, 0x34f0, 0x0024, 0xfe08, 0x0024, 0x48b2, /* 2158 */
  0x0024, 0x34e0, 0x4024, 0x4712, 0x0024, 0x4100, 0x0024, 0x0000, /* 2160 */
  0x0141, 0x4050, 0x0024, 0xf400, 0x4010, 0x3000, 0x0024, 0xff90, /* 2168 */
  0x0024, 0x48b2, 0x0024, 0x0000, 0x0081, 0x4200, 0x0024, 0x4010, /* 2170 */
  0x0024, 0x4060, 0x0024, 0xf400, 0x4010, 0x3000, 0x8024, 0x6284, /* 2178 */
  0x0024, 0x0000, 0x0024, 0x2802, 0x6708, 0x0000, 0x0024, 0xb886, /* 2180 */
  0x118c, 0xf400, 0x4500, 0x34c3, 0x0024, 0x4040, 0x9081, 0xf400, /* 2188 */
  0x4010, 0x3000, 0x0024, 0x4010, 0x0024, 0xf400, 0x4012, 0x34c0, /* 2190 */
  0x0024, 0x6030, 0x0024, 0x0000, 0x0024, 0x2802, 0x6709, 0x4090, /* 2198 */
  0x0024, 0x3200, 0x50cc, 0x2402, 0x6680, 0x3613, 0x1340, 0x4700, /* 21a0 */
  0x0024, 0x4280, 0x4010, 0x2901, 0xec40, 0x3004, 0x0024, 0x6396, /* 21a8 */
  0x2840, 0x3200, 0x50cc, 0x3613, 0x1340, 0x36f3, 0x0024, 0x2802, /* 21b0 */
  0x5940, 0x6498, 0x0024, 0x4700, 0x0024, 0xf400, 0x4010, 0x3010, /* 21b8 */
  0x0024, 0x30f0, 0x4024, 0xf400, 0x4041, 0x6c82, 0x0024, 0x0000, /* 21c0 */
  0x03c1, 0x2802, 0x70c5, 0x0000, 0x0540, 0x4700, 0x904c, 0x4712, /* 21c8 */
  0x4010, 0xb58a, 0x00c0, 0x4100, 0x0024, 0xf400, 0x4012, 0x3200, /* 21d0 */
  0x8024, 0x34f0, 0x0024, 0x4100, 0x0024, 0xf400, 0x4012, 0x3200, /* 21d8 */
  0x0024, 0x4200, 0x0042, 0xf200, 0x03c3, 0xf400, 0x4004, 0x4de6, /* 21e0 */
  0x0024, 0x3810, 0x8024, 0x38f0, 0xc024, 0x36f3, 0xc024, 0x36f3, /* 21e8 */
  0x580e, 0x36f4, 0x9813, 0x36f1, 0xd811, 0x36f1, 0x5806, 0x36f0, /* 21f0 */
  0xd804, 0x36f0, 0x5802, 0x3405, 0x9014, 0x36f3, 0x0024, 0x36f2, /* 21f8 */
  0x0024, 0x2000, 0x0000, 0x0000, 0x0024, 0x2802, 0x6dc0, 0xb880, /* 2200 */
  0x0024, 0x3e10, 0x0024, 0x0000, 0x0600, 0x4700, 0x0024, 0xf400, /* 2208 */
  0x4010, 0x0000, 0x0a00, 0x4700, 0x0042, 0x30f0, 0xc024, 0x4d82, /* 2210 */
  0x4010, 0x3004, 0x0024, 0x2901, 0xd940, 0x0002, 0x1088, 0x0007, /* 2218 */
  0x0001, 0x001c, 0x0006, 0x8003, 0x0000, 0x0007, 0x0001, 0x001f, /* 2220 */
  0x0006, 0x0009, 0x0000, 0x0001, 0x0003, 0x0007, 0x000f, 0x001f, /* 2228 */
  0x003f, 0x007f, 0x00ff, 0x0007, 0x0001, 0x89d0, 0x0006, 0x0028, /* 2230 */
  0x3e10, 0xb803, 0x3e13, 0xf80e, 0x3e13, 0x780a, 0x0001, 0x800a, /* 2238 */
  0x4094, 0xb811, 0x0030, 0x0311, 0x3009, 0x0043, 0xf036, 0x0400, /* 2240 */
  0x2402, 0x7782, 0x6306, 0x40c2, 0x3009, 0x0043, 0x2802, 0x7791, /* 2248 */
  0xf036, 0x0024, 0x4280, 0x0024, 0x6306, 0x40c2, 0x3900, 0x1bd1, /* 2250 */
  0x36f3, 0x580a, 0x36f3, 0xd80e, 0x2000, 0x0000, 0x36f0, 0x9803, /* 2258 */
  0x0007, 0x0001, 0x89e4, 0x0006, 0x0028, 0x3e15, 0x3811, 0x3e10, /* 2260 */
  0x3801, 0x3e10, 0xb803, 0x3e11, 0x3805, 0x3e13, 0xf80e, 0x0000, /* 2268 */
  0x0051, 0x4091, 0x0a2b, 0xfeb4, 0x4054, 0xb182, 0x380d, 0x2402, /* 2270 */
  0x7c00, 0x0020, 0x0000, 0x4cbb, 0x0a2b, 0xfeb4, 0x3045, 0x36f3, /* 2278 */
  0x4024, 0x36f3, 0xd80e, 0x36f1, 0x1805, 0x36f0, 0x9803, 0x36f0, /* 2280 */
  0x1801, 0x2000, 0x0000, 0x36f5, 0x1811, 0x0007, 0x0001, 0x89f8, /* 2288 */
  0x0006, 0x0024, 0x3e14, 0x3811, 0x3e10, 0xb803, 0x3e13, 0x7805, /* 2290 */
  0x3e03, 0xf80e, 0xf248, 0x4110, 0xf400, 0x44d1, 0x4498, 0x060c, /* 2298 */
  0x2402, 0x8104, 0x31f3, 0x0024, 0x3301, 0x0c05, 0x3100, 0x8403, /* 22a0 */
  0x39f1, 0x2405, 0x3b10, 0xac03, 0x36f3, 0xd80e, 0x36f3, 0x5805, /* 22a8 */
  0x36f0, 0x9803, 0x2000, 0x0000, 0x36f4, 0x1811, 0x0007, 0x0001, /* 22b0 */
  0x8a0a, 0x0006, 0x0040, 0x3e10, 0x3813, 0x3e10, 0xb803, 0x3e11, /* 22b8 */
  0x3805, 0x3e11, 0xb807, 0x3e13, 0xf80e, 0x3e13, 0x4024, 0xb68c, /* 22c0 */
  0x0024, 0x3811, 0xa446, 0x38f1, 0xa7c6, 0x3e01, 0xb806, 0x0fff, /* 22c8 */
  0xff07, 0x3009, 0x0801, 0x4090, 0x0024, 0x2402, 0x8800, 0xa170, /* 22d0 */
  0x8846, 0x661a, 0x0044, 0xfe5a, 0x0005, 0x4eba, 0x4183, 0xa374, /* 22d8 */
  0x23c5, 0x6208, 0x2004, 0xfe49, 0x6465, 0x4eba, 0x8846, 0x4d83, /* 22e0 */
  0xe4e5, 0x3009, 0x2444, 0x36f3, 0x2405, 0x36f3, 0x4024, 0x36f3, /* 22e8 */
  0xd80e, 0x36f1, 0x9807, 0x36f1, 0x1805, 0x36f0, 0x9803, 0x2000, /* 22f0 */
  0x0000, 0x36f0, 0x1813, 0x0007, 0x0001, 0x8a2a, 0x0006, 0x0186, /* 22f8 */
  0x0000, 0x0580, 0x3e12, 0x0024, 0x3e05, 0xb814, 0x3675, 0x0024, /* 2300 */
  0x3e00, 0x7842, 0x3e00, 0xf844, 0x3e01, 0x7846, 0x3e01, 0xf850, /* 2308 */
  0x3e04, 0x7852, 0x3e04, 0xd38c, 0x34e4, 0x0024, 0xf400, 0x4401, /* 2310 */
  0x4100, 0x01cc, 0xf400, 0x4012, 0x3210, 0x81cc, 0x3200, 0x404c, /* 2318 */
  0x2b40, 0x0403, 0x4020, 0x1144, 0x4316, 0x4011, 0xf400, 0x40d2, /* 2320 */
  0x4224, 0x0405, 0x3060, 0x0024, 0x3200, 0xc024, 0x4536, 0x0024, /* 2328 */
  0xf236, 0x0024, 0x3000, 0xf003, 0x4336, 0x0024, 0x4336, 0x0024, /* 2330 */
  0xc326, 0x0024, 0x0002, 0xf682, 0xc316, 0x0024, 0x4332, 0x3043, /* 2338 */
  0x4312, 0x3084, 0x4214, 0x0024, 0x0000, 0x0181, 0xb312, 0xb302, /* 2340 */
  0x0000, 0x0082, 0x6124, 0x0024, 0x0000, 0x0024, 0x2802, 0xba85, /* 2348 */
  0x6502, 0x0024, 0xf400, 0x4147, 0x0000, 0x0002, 0x0000, 0x00c3, /* 2350 */
  0x3413, 0x0024, 0x3420, 0x4024, 0xb136, 0x0024, 0x0000, 0x0081, /* 2358 */
  0x6312, 0x0024, 0x0000, 0x0024, 0x2802, 0xb905, 0x4552, 0x0024, /* 2360 */
  0x4550, 0x13cc, 0x3009, 0x3040, 0x3009, 0x3345, 0x6284, 0x4110, /* 2368 */
  0x0000, 0x0001, 0x2802, 0x9a05, 0x0000, 0x0024, 0x2914, 0xbec0, /* 2370 */
  0x4280, 0x0024, 0x4428, 0x0024, 0x0000, 0x0443, 0x3443, 0x184c, /* 2378 */
  0x6724, 0x9291, 0x34f4, 0x044c, 0xf400, 0x4400, 0x3009, 0x07c1, /* 2380 */
  0x4030, 0x11c3, 0x4010, 0xb311, 0xf400, 0x4010, 0x0002, 0x0000, /* 2388 */
  0xfe06, 0x0012, 0x48b2, 0x0024, 0x000c, 0x0001, 0x410c, 0x0024, /* 2390 */
  0x4482, 0x4190, 0x4280, 0x0024, 0x2902, 0x7900, 0x0000, 0x0053, /* 2398 */
  0x4428, 0x0024, 0x6570, 0x4110, 0x0000, 0x0024, 0x2802, 0xa0c9, /* 23a0 */
  0x657e, 0x0024, 0x4620, 0x0024, 0x293e, 0xd480, 0x4780, 0x4011, /* 23a8 */
  0x4478, 0x0024, 0x0002, 0x0002, 0xfe26, 0x104c, 0x3009, 0x1040, /* 23b0 */
  0x620c, 0x1381, 0x000c, 0x0002, 0x4162, 0x0024, 0x48be, 0x4051, /* 23b8 */
  0x426e, 0x0024, 0x293e, 0xd480, 0xf400, 0x41d0, 0x3433, 0x184c, /* 23c0 */
  0x3009, 0x1080, 0x6050, 0x0024, 0x0000, 0x0440, 0x2802, 0xa709, /* 23c8 */
  0x0000, 0x0024, 0x34e3, 0x1bcc, 0x2b1d, 0x1110, 0x3009, 0x1340, /* 23d0 */
  0x6054, 0x0024, 0x293e, 0xd480, 0x4280, 0x0024, 0x0000, 0x0440, /* 23d8 */
  0x4428, 0x114c, 0x3009, 0x184c, 0x3c01, 0x33c5, 0x3009, 0x1291, /* 23e0 */
  0x3444, 0x048c, 0xf400, 0x4402, 0x4200, 0x8781, 0x4010, 0x9041, /* 23e8 */
  0xf400, 0x4010, 0x3000, 0x0024, 0x4014, 0x9080, 0x620e, 0x0024, /* 23f0 */
  0x0002, 0x0002, 0xfe26, 0x0024, 0x000c, 0x0002, 0x48ba, 0x0024, /* 23f8 */
  0x424c, 0x1004, 0x3009, 0x13c5, 0x6054, 0xb011, 0x462c, 0x0024, /* 2400 */
  0x6104, 0x4190, 0x4790, 0x0024, 0x4482, 0x4012, 0x4280, 0x0024, /* 2408 */
  0x2902, 0x7900, 0x003f, 0xffd3, 0x4420, 0x9390, 0x3009, 0x0001, /* 2410 */
  0xfe52, 0x4010, 0x48be, 0x9380, 0x6608, 0x4182, 0x0000, 0x0024, /* 2418 */
  0x2802, 0xaf89, 0x6600, 0x0024, 0x2914, 0xbec0, 0xb882, 0x0024, /* 2420 */
  0x0000, 0x0082, 0x6292, 0x104c, 0x34f0, 0x0024, 0xb010, 0x0024, /* 2428 */
  0x6028, 0x0024, 0x0000, 0x05c0, 0x2802, 0xb615, 0x0000, 0x0024, /* 2430 */
  0x34e3, 0x0024, 0x3434, 0x0024, 0x2b40, 0x1402, 0x4100, 0x0024, /* 2438 */
  0xf400, 0x4012, 0x0000, 0x03c1, 0x4212, 0x0800, 0x4100, 0x0024, /* 2440 */
  0xf400, 0x4010, 0x0002, 0x0001, 0xfe16, 0x0000, 0x000c, 0x0001, /* 2448 */
  0x48b6, 0x0024, 0x4122, 0x93c2, 0x4124, 0x4050, 0x6204, 0x0024, /* 2450 */
  0x293e, 0xd480, 0xf400, 0x4091, 0x4580, 0x1bd3, 0x36f4, 0x5812, /* 2458 */
  0x36f1, 0xd810, 0x36f1, 0x5806, 0x36f0, 0xd804, 0x36f0, 0x5802, /* 2460 */
  0x3405, 0x9014, 0x36f3, 0x0024, 0x36f2, 0x0024, 0x2000, 0x0000, /* 2468 */
  0x0000, 0x0024, 0x4552, 0x10cc, 0x4152, 0x0024, 0x6102, 0x0024, /* 2470 */
  0xf112, 0x0024, 0x4102, 0xb3c1, 0x2802, 0x9840, 0x3009, 0x3381, /* 2478 */
  0xf114, 0x0024, 0x2802, 0x9540, 0x420e, 0x0024, 0x0007, 0x0001, /* 2480 */
  0x3000, 0x0006, 0x9000, 0x0000, 0x0007, 0x0001, 0x4bda, 0x0006, /* 2488 */
  0x8006, 0x0000, 0x0006, 0x0006, 0x0002, 0x0000, 0x0000, 0x0000, /* 2490 */
  0x0000, 0x0001, 0x0006, 0x8006, 0x0000, 0x0006, 0x0006, 0x0002, /* 2498 */
  0x0001, 0x0000, 0x0000, 0x0001, 0x0001, 0x0007, 0x0001, 0x8aed, /* 24a0 */
  0x0006, 0x0016, 0x4090, 0x0024, 0x3e13, 0x7801, 0x2802, 0xbd44, /* 24a8 */
  0x3e03, 0xf80e, 0x2402, 0xbd00, 0x0000, 0x0024, 0x3210, 0x0801, /* 24b0 */
  0x3810, 0x2001, 0x36f3, 0xd80e, 0x2000, 0x0000, 0x36f3, 0x5801, /* 24b8 */
  0x0007, 0x0001, 0x8af8, 0x0006, 0x0022, 0x3e10, 0xb803, 0x3e11, /* 24c0 */
  0x3805, 0x3e13, 0x7811, 0x0000, 0x0402, 0x6122, 0x380f, 0x4090, /* 24c8 */
  0xb80e, 0xb284, 0x0843, 0xad1a, 0x0024, 0x2402, 0xc0c0, 0x0000, /* 24d0 */
  0x0051, 0xb284, 0x0843, 0xad1b, 0x8c85, 0x36f3, 0xd80e, 0x36f3, /* 24d8 */
  0x5811, 0x36f1, 0x1805, 0x2000, 0x0000, 0x36f0, 0x9803, 0x0007, /* 24e0 */
  0x0001, 0x8b09, 0x0006, 0x0014, 0x3e13, 0xf80e, 0x3e03, 0x4024, /* 24e8 */
  0x4090, 0x0024, 0x2402, 0xc380, 0xb080, 0x0024, 0x3810, 0x2000, /* 24f0 */
  0x36f3, 0x4024, 0x36f3, 0xd80e, 0x2000, 0x0000, 0x0000, 0x0024, /* 24f8 */
  0x0007, 0x0001, 0x8b13, 0x0006, 0x0004, 0x2000, 0x0000, 0xf400, /* 2500 */
  0x4580, 0x0007, 0x0001, 0x8b15, 0x0006, 0x0052, 0x3e12, 0x0024, /* 2508 */
  0x3e05, 0xb814, 0x3615, 0x0024, 0x3e00, 0x3841, 0x6890, 0x3802, /* 2510 */
  0x4792, 0xb843, 0xa012, 0x4403, 0x3e01, 0x3845, 0x431a, 0xb813, /* 2518 */
  0x4114, 0x3852, 0x2902, 0x7e00, 0x4288, 0x4153, 0x4320, 0x40d2, /* 2520 */
  0x4180, 0x4010, 0x2903, 0xc300, 0x3613, 0x0024, 0x4110, 0x4150, /* 2528 */
  0x4010, 0x184c, 0x4300, 0x0024, 0x2903, 0xbec0, 0x4180, 0x4012, /* 2530 */
  0x2b0d, 0x0152, 0x2902, 0xbb40, 0x4280, 0x184c, 0x4110, 0x184c, /* 2538 */
  0x3e10, 0x0024, 0x291b, 0x7280, 0x3e00, 0xc024, 0x003f, 0xfe81, /* 2540 */
  0x4174, 0x1bcc, 0x2903, 0xc740, 0xf400, 0x40d0, 0x36f4, 0x9813, /* 2548 */
  0x36f1, 0x1805, 0x36f0, 0x9803, 0x36f0, 0x1801, 0x3405, 0x9014, /* 2550 */
  0x36f3, 0x0024, 0x36f2, 0x0024, 0x2000, 0x0000, 0x0000, 0x0024, /* 2558 */
  0x0007, 0x0001, 0x8b3e, 0x0006, 0x01de, 0x3e12, 0x0024, 0x3e05, /* 2560 */
  0xb814, 0x3675, 0x0024, 0x3613, 0x104c, 0x3e00, 0x7842, 0x0000, /* 2568 */
  0x01c1, 0x3e00, 0xf844, 0x3e01, 0x7846, 0x3e01, 0xf851, 0x3e04, /* 2570 */
  0xb84d, 0x3e03, 0xb80f, 0x3009, 0x3010, 0x3009, 0x13c0, 0x4010, /* 2578 */
  0x0024, 0xf400, 0x4010, 0x0000, 0x0080, 0x3000, 0x4024, 0x6102, /* 2580 */
  0x0024, 0x0000, 0x0024, 0x2802, 0xd785, 0xb880, 0x0024, 0x36f3, /* 2588 */
  0x980f, 0x36f4, 0x980d, 0x36f1, 0xd811, 0x36f1, 0x5806, 0x36f0, /* 2590 */
  0xd804, 0x36f0, 0x5802, 0x3405, 0x9014, 0x36f3, 0x0024, 0x36f2, /* 2598 */
  0x0024, 0x2000, 0x0000, 0x0000, 0x0024, 0x0000, 0x0590, 0xf400, /* 25a0 */
  0x4401, 0x3413, 0x0024, 0x3009, 0x1040, 0x4012, 0x0024, 0xf400, /* 25a8 */
  0x4050, 0x0000, 0x0a81, 0x4010, 0x0002, 0x0000, 0x0141, 0x4020, /* 25b0 */
  0x0024, 0xf400, 0x4010, 0x3000, 0x0024, 0x4010, 0x3000, 0xb882, /* 25b8 */
  0x4010, 0x3000, 0x0024, 0x3009, 0x3280, 0x3440, 0x8024, 0x0000, /* 25c0 */
  0x01c3, 0x3413, 0x0024, 0x3009, 0x1100, 0x4030, 0x0024, 0xf400, /* 25c8 */
  0x4010, 0x3000, 0x0024, 0x6100, 0x0024, 0x0000, 0x0040, 0x2802, /* 25d0 */
  0xe281, 0x0000, 0x0024, 0x3493, 0x184c, 0xb880, 0x93cc, 0x3e10, /* 25d8 */
  0x8024, 0x3e10, 0x0024, 0x6182, 0x3841, 0x3440, 0x0024, 0x2802, /* 25e0 */
  0xe0d5, 0x0000, 0x0024, 0x34d3, 0x0024, 0x3430, 0x0024, 0x3e10, /* 25e8 */
  0x1040, 0x3e10, 0x0024, 0x34e0, 0x0024, 0x2903, 0x1fc0, 0xf400, /* 25f0 */
  0x4010, 0x2802, 0xdbc0, 0x6192, 0x1acc, 0x3cd0, 0x0024, 0x3430, /* 25f8 */
  0x0024, 0xf400, 0x4010, 0x3000, 0x4024, 0x34d0, 0x0024, 0x6014, /* 2600 */
  0x10c1, 0x0000, 0x0a40, 0x2803, 0x0ad8, 0x0000, 0x0024, 0x4100, /* 2608 */
  0x1341, 0x4012, 0x0024, 0xf400, 0x4050, 0x3000, 0x9381, 0x6214, /* 2610 */
  0x0024, 0x0000, 0x0024, 0x2803, 0x0509, 0x0000, 0x0024, 0x3453, /* 2618 */
  0x0024, 0x34d0, 0x4024, 0x4192, 0x0024, 0x4010, 0x93c1, 0xf400, /* 2620 */
  0x4010, 0x3000, 0x0024, 0x6014, 0x9041, 0x0000, 0x0b02, 0x2802, /* 2628 */
  0xe9d9, 0x0000, 0x0024, 0x3009, 0x13c0, 0x3009, 0x1041, 0x4124, /* 2630 */
  0x10cc, 0x0000, 0x0801, 0x4216, 0x1241, 0x4316, 0x0024, 0xf400, /* 2638 */
  0x40d0, 0x3000, 0xc024, 0x4212, 0x13c2, 0x4208, 0x4050, 0x3000, /* 2640 */
  0x4024, 0x6312, 0x10c2, 0x4206, 0x4112, 0xf014, 0x40d0, 0x0000, /* 2648 */
  0x2003, 0x6234, 0x0024, 0x0000, 0x0024, 0x2803, 0x0998, 0x6182, /* 2650 */
  0x0024, 0x0005, 0x0002, 0x2803, 0x0899, 0x0000, 0x0024, 0x6812, /* 2658 */
  0x114c, 0x4212, 0x0024, 0xf400, 0x4051, 0x0020, 0x0001, 0x3009, /* 2660 */
  0x0402, 0x6122, 0x0024, 0x0020, 0x0002, 0x6214, 0xb3c1, 0x0000, /* 2668 */
  0x0a41, 0x3ce0, 0x8024, 0x3430, 0x8024, 0x4214, 0x1301, 0x4212, /* 2670 */
  0x0024, 0xf400, 0x4051, 0x3100, 0x4024, 0x6102, 0x0024, 0xb880, /* 2678 */
  0x30c1, 0x3009, 0x3340, 0x34f0, 0x4024, 0x6100, 0x0024, 0x0000, /* 2680 */
  0x0024, 0x2803, 0x0509, 0x4090, 0x0024, 0x2403, 0x04c0, 0x0000, /* 2688 */
  0x0024, 0xb387, 0x2220, 0xb58a, 0x4001, 0x0000, 0x0000, 0xcdce, /* 2690 */
  0x90cc, 0xb8d6, 0xb006, 0x4f82, 0x3047, 0x0010, 0x0007, 0xfeec, /* 2698 */
  0x1086, 0x5206, 0x4411, 0x4dd6, 0x0024, 0x4834, 0x4843, 0x4db6, /* 26a0 */
  0x0024, 0x4db6, 0x0024, 0x3c00, 0xb3c3, 0xb8d7, 0x0400, 0xf400, /* 26a8 */
  0x4001, 0x0000, 0x0000, 0xceca, 0x9040, 0xfec0, 0x0024, 0x5a06, /* 26b0 */
  0x0024, 0x4dd6, 0x0024, 0x4834, 0x4843, 0x4db6, 0x0024, 0x4db6, /* 26b8 */
  0x0024, 0x4d82, 0x1002, 0x3009, 0x1283, 0x4dca, 0x0024, 0x4eea, /* 26c0 */
  0x0024, 0x667c, 0x0024, 0x0000, 0x0024, 0x2803, 0x0618, 0x467c, /* 26c8 */
  0x0024, 0xf0e6, 0x0024, 0xf0c2, 0x40c3, 0xf400, 0x4041, 0x6dc6, /* 26d0 */
  0x8000, 0x0000, 0x0024, 0x2802, 0xffd8, 0xb386, 0x0002, 0xf400, /* 26d8 */
  0x4001, 0x0000, 0x0000, 0xcdc2, 0x0024, 0x4cca, 0x0024, 0xb8d6, /* 26e0 */
  0x110c, 0x4e8e, 0x4411, 0x3410, 0x0024, 0xfec0, 0x0024, 0x5a06, /* 26e8 */
  0x0024, 0x4dd6, 0x0024, 0x4834, 0x4843, 0x4db6, 0x0024, 0x4db6, /* 26f0 */
  0x0024, 0x3a10, 0xa803, 0xb8d6, 0x93c0, 0xfec0, 0x0024, 0x5a06, /* 26f8 */
  0x0024, 0x4dd6, 0x0024, 0x4834, 0x4843, 0x4db6, 0x0024, 0x4db6, /* 2700 */
  0x0024, 0x3810, 0xa003, 0x3009, 0x1000, 0x6090, 0x0024, 0x3009, /* 2708 */
  0x3300, 0x3453, 0x0024, 0x3400, 0x0024, 0x2802, 0xe280, 0x6090, /* 2710 */
  0x0024, 0xf0e2, 0x10cc, 0x3401, 0xd346, 0xf0d6, 0x4041, 0xf400, /* 2718 */
  0x40c3, 0x6cd6, 0x0024, 0x0000, 0x0024, 0x2802, 0xffd8, 0x0000, /* 2720 */
  0x0024, 0x2802, 0xffc0, 0x4ffa, 0x0024, 0x4212, 0x114c, 0xf400, /* 2728 */
  0x4051, 0x2802, 0xf040, 0x3009, 0x0401, 0x001f, 0xff01, 0x2802, /* 2730 */
  0xf059, 0x3453, 0x0024, 0x2802, 0xf040, 0x0000, 0x00c1, 0x2802, /* 2738 */
  0xd4c0, 0xb880, 0x12cc, 0x0007, 0x0001, 0x8c2d, 0x0006, 0x004c, /* 2740 */
  0x3e00, 0x3841, 0xb880, 0x3802, 0x6702, 0xb843, 0x3e01, 0x384d, /* 2748 */
  0x2803, 0x10c9, 0x3e03, 0xb80f, 0x4192, 0x0024, 0x2403, 0x1081, /* 2750 */
  0x0000, 0x0024, 0x3000, 0x8024, 0xf026, 0x0401, 0xf018, 0x0024, /* 2758 */
  0x6346, 0x0024, 0x0000, 0x0024, 0x2803, 0x12c8, 0x0000, 0x0024, /* 2760 */
  0x6286, 0x004c, 0x0000, 0x0024, 0x2803, 0x1248, 0x0000, 0x0024, /* 2768 */
  0x6212, 0x0024, 0x6090, 0x2441, 0x36f3, 0x980f, 0x36f1, 0x180d, /* 2770 */
  0x36f0, 0x9803, 0x36f0, 0x1801, 0x2000, 0x0000, 0x0000, 0x0024, /* 2778 */
  0x2803, 0x1080, 0x6132, 0x0024, 0x6182, 0x2041, 0x0000, 0x0024, /* 2780 */
  0x2803, 0x1448, 0x0000, 0x0024, 0x2803, 0x1080, 0x6212, 0x0024, /* 2788 */
  0x2803, 0x1080, 0x6122, 0x0024, 0x0007, 0x0001, 0x8c53, 0x0006, /* 2790 */
  0x0058, 0x654a, 0x3848, 0x3e05, 0xb814, 0x3635, 0x0024, 0x3e00, /* 2798 */
  0x3841, 0xf400, 0x4480, 0x3e01, 0xb847, 0x404e, 0x3811, 0x632c, /* 27a0 */
  0xb813, 0xf068, 0x4083, 0x2914, 0xba00, 0x4580, 0x4102, 0x4082, /* 27a8 */
  0x41d3, 0x668c, 0x104c, 0x003f, 0xffc0, 0x2803, 0x1948, 0xff02, /* 27b0 */
  0x0024, 0x6890, 0x0024, 0xff02, 0x0024, 0x48b3, 0xc2c3, 0x4082, /* 27b8 */
  0x184c, 0xfe50, 0x0024, 0x48b6, 0x0024, 0xf020, 0x93c3, 0x6408, /* 27c0 */
  0x0024, 0x4190, 0x0024, 0x668c, 0x0024, 0x0000, 0x0024, 0x2803, /* 27c8 */
  0x1c88, 0x4334, 0x0024, 0x6190, 0x0024, 0x4334, 0x0024, 0x0004, /* 27d0 */
  0x8803, 0x4326, 0x0024, 0x4584, 0x40d1, 0x2903, 0xd340, 0x458a, /* 27d8 */
  0x0024, 0x36f4, 0x5813, 0x36f1, 0x9807, 0x36f0, 0x1801, 0x3405, /* 27e0 */
  0x9014, 0x36f3, 0x0024, 0x36f2, 0x0024, 0x2000, 0x0000, 0x0000, /* 27e8 */
  0x0024, 0x0007, 0x0001, 0x8c7f, 0x0006, 0x0360, 0xf400, 0x4400, /* 27f0 */
  0x3e12, 0x0024, 0x3e05, 0xb814, 0x3675, 0x0024, 0x3633, 0x108c, /* 27f8 */
  0x3e00, 0x7842, 0x0000, 0x3bc1, 0x0000, 0x0802, 0x3e00, 0xf844, /* 2800 */
  0x3e01, 0x7846, 0x3e01, 0xf851, 0x3e04, 0xb853, 0x3e03, 0x784e, /* 2808 */
  0x3e03, 0xc024, 0x3ca4, 0x0024, 0x4010, 0x1081, 0x4010, 0x0024, /* 2810 */
  0xfe22, 0x4010, 0x48b6, 0x0000, 0x0000, 0x0b03, 0x3450, 0x4024, /* 2818 */
  0x4132, 0x0024, 0x4124, 0x0024, 0x0010, 0x0001, 0x6014, 0xb342, /* 2820 */
  0x0000, 0x0024, 0x2803, 0x8b48, 0x0000, 0x0024, 0x001f, 0xff00, /* 2828 */
  0x3413, 0x0024, 0x0000, 0x0541, 0x3009, 0x3340, 0x3420, 0x0024, /* 2830 */
  0x4010, 0x0024, 0xf400, 0x4013, 0xf400, 0x44d0, 0x3013, 0x0024, /* 2838 */
  0x3000, 0x0024, 0x6080, 0x0024, 0x3300, 0x0024, 0x2803, 0x2b95, /* 2840 */
  0x6080, 0x0024, 0x001f, 0xff00, 0x2803, 0x2b85, 0x0000, 0x0024, /* 2848 */
  0x3413, 0x0024, 0x3009, 0x33c0, 0x0000, 0x05c1, 0x34e3, 0x0024, /* 2850 */
  0x34f0, 0x0024, 0xf400, 0x4010, 0xf400, 0x4400, 0x4010, 0x1393, /* 2858 */
  0xf400, 0x4010, 0x3000, 0x0024, 0x6080, 0x0024, 0x0000, 0x0024, /* 2860 */
  0x2803, 0x8ad5, 0x0000, 0x0024, 0x3473, 0x0024, 0xbc82, 0x1112, /* 2868 */
  0x3233, 0x184c, 0x3c10, 0x0024, 0x3cf0, 0x4024, 0x3009, 0x3040, /* 2870 */
  0x3009, 0x32c1, 0x3c44, 0x8024, 0xf400, 0x4510, 0x3200, 0x12cc, /* 2878 */
  0x3c54, 0x0024, 0xf400, 0x4511, 0x3493, 0x0024, 0x34e3, 0x0024, /* 2880 */
  0x3454, 0xc024, 0xf400, 0x44d2, 0x3404, 0x0024, 0x30d3, 0x0024, /* 2888 */
  0x3cf4, 0x0024, 0x2903, 0xcf40, 0x34f4, 0x0024, 0x0000, 0x2001, /* 2890 */
  0x0000, 0x0020, 0xb880, 0x118c, 0x3009, 0x1046, 0x3009, 0x13c7, /* 2898 */
  0x0000, 0x0023, 0x6fc2, 0x0024, 0x0000, 0x0024, 0x2803, 0x8751, /* 28a0 */
  0xb8ea, 0x0024, 0xb8d6, 0x130c, 0x3444, 0x0024, 0x3043, 0x0024, /* 28a8 */
  0x30c0, 0x0024, 0xfee0, 0x0024, 0x5e06, 0x0024, 0x0000, 0x0200, /* 28b0 */
  0x4dd6, 0x0024, 0x4834, 0x4843, 0x4db6, 0x0024, 0x4db6, 0x0024, /* 28b8 */
  0xad02, 0x0024, 0x3c10, 0x0024, 0x3cb0, 0x4024, 0x0000, 0x0581, /* 28c0 */
  0x3cc4, 0x0024, 0x3420, 0x0024, 0xf400, 0x4010, 0xf400, 0x4400, /* 28c8 */
  0x4010, 0x0024, 0xf400, 0x4010, 0x3000, 0x0024, 0x6080, 0x0024, /* 28d0 */
  0x0000, 0x3a41, 0x2803, 0x4855, 0x0000, 0x0024, 0x34c3, 0x0024, /* 28d8 */
  0x3460, 0x0024, 0x4000, 0x1110, 0xf400, 0x4402, 0x4212, 0x1042, /* 28e0 */
  0x4100, 0x13c3, 0xf400, 0x4010, 0x3010, 0x0024, 0x30f0, 0x4024, /* 28e8 */
  0x4cca, 0x3042, 0x6ede, 0x3243, 0x0000, 0x0024, 0x2803, 0x4841, /* 28f0 */
  0x0000, 0x0024, 0x2915, 0x46c0, 0x0000, 0x0024, 0x0000, 0x0086, /* 28f8 */
  0xb888, 0x0024, 0x2915, 0x9900, 0x0010, 0x0005, 0x3463, 0x184c, /* 2900 */
  0x3e10, 0x0024, 0x3e10, 0x4024, 0x3e00, 0x8024, 0x3410, 0x0024, /* 2908 */
  0x2915, 0x46c0, 0x3490, 0x4024, 0x418a, 0x4004, 0x428c, 0x1bc2, /* 2910 */
  0x36f0, 0x4024, 0x2915, 0xb780, 0x36f0, 0x0024, 0x3613, 0x0024, /* 2918 */
  0x3e10, 0x0024, 0x3e10, 0x4024, 0x291f, 0xca00, 0x3e00, 0x8024, /* 2920 */
  0x2903, 0xeac0, 0x36d3, 0x0024, 0x0003, 0xd700, 0x6104, 0x104c, /* 2928 */
  0x3009, 0x33c1, 0x2803, 0x4858, 0x0000, 0x0024, 0x3413, 0x0024, /* 2930 */
  0x3009, 0x33c0, 0x34a3, 0x0024, 0x3410, 0x0024, 0x6080, 0x1182, /* 2938 */
  0x0003, 0xd700, 0x2803, 0x4a45, 0x0000, 0x0024, 0x3009, 0x3280, /* 2940 */
  0x3460, 0x8024, 0x6284, 0x13cc, 0x0000, 0x3a41, 0x2803, 0x4dc5, /* 2948 */
  0x0000, 0x0024, 0x34c3, 0x0024, 0x3460, 0x0024, 0x4000, 0x1150, /* 2950 */
  0xf400, 0x4403, 0x4312, 0x0024, 0x4100, 0x13c1, 0xf400, 0x4010, /* 2958 */
  0x34a0, 0x0024, 0x3810, 0x0024, 0x38f0, 0x4024, 0x0000, 0x1241, /* 2960 */
  0xb888, 0x108c, 0x3404, 0x0024, 0xf400, 0x4400, 0xf400, 0x4412, /* 2968 */
  0x4010, 0x0005, 0x3273, 0x0024, 0x3223, 0x0024, 0x3009, 0x33d2, /* 2970 */
  0xb880, 0x3080, 0x6540, 0x3280, 0x3c34, 0xc024, 0x2803, 0x5a89, /* 2978 */
  0x4090, 0x0024, 0x2403, 0x5a40, 0x0000, 0x0024, 0x0000, 0x0a40, /* 2980 */
  0x3423, 0x0024, 0x3414, 0x0024, 0xf400, 0x4401, 0x4100, 0x0024, /* 2988 */
  0x4040, 0x0024, 0xf400, 0x4010, 0x3000, 0x4024, 0x34e0, 0x0024, /* 2990 */
  0x6106, 0x1050, 0x3000, 0x0024, 0x6080, 0x0024, 0x0000, 0x0024, /* 2998 */
  0x2803, 0x5785, 0x0000, 0x0024, 0x3404, 0x1012, 0x3210, 0x408c, /* 29a0 */
  0x30e0, 0x3012, 0x6100, 0x3190, 0x0000, 0x0024, 0x2803, 0x7348, /* 29a8 */
  0xbc82, 0x984c, 0x34a3, 0x1bcc, 0x3413, 0x0024, 0x6488, 0x9010, /* 29b0 */
  0x0000, 0x1000, 0x2803, 0x71d5, 0x0000, 0x0024, 0x3810, 0x0024, /* 29b8 */
  0x3009, 0x3350, 0x3433, 0x0024, 0x34e0, 0x0024, 0x4030, 0x1090, /* 29c0 */
  0x3ce0, 0x004c, 0x6498, 0x33d0, 0x0000, 0x0803, 0x3423, 0x0024, /* 29c8 */
  0x34a4, 0x0024, 0x3000, 0x0024, 0x3420, 0x4024, 0xfe32, 0x1081, /* 29d0 */
  0x0000, 0x0b03, 0x48ba, 0x0024, 0x4132, 0x0024, 0x4142, 0x0024, /* 29d8 */
  0x6892, 0x4053, 0x3311, 0x4024, 0x6106, 0x130c, 0x0000, 0x0803, /* 29e0 */
  0x2803, 0x6458, 0x0000, 0x0d04, 0x3300, 0xd10c, 0x6346, 0x0024, /* 29e8 */
  0x0000, 0x0024, 0x2803, 0x6018, 0x0000, 0x0024, 0x3b01, 0x0024, /* 29f0 */
  0x3300, 0xc024, 0x6356, 0x0024, 0x0000, 0x0503, 0x2803, 0x63d9, /* 29f8 */
  0x0000, 0x0024, 0x653a, 0x0c03, 0x6356, 0x0024, 0x0000, 0x0024, /* 2a00 */
  0x2803, 0x6348, 0x0000, 0x0024, 0x3311, 0x4024, 0x2803, 0x5d80, /* 2a08 */
  0x6192, 0x0024, 0x2803, 0x62c0, 0x3b11, 0x4024, 0x2803, 0x62c0, /* 2a10 */
  0x3311, 0x4024, 0x3420, 0x4024, 0xfe32, 0x1081, 0x0000, 0x0b03, /* 2a18 */
  0x48ba, 0x0024, 0x4132, 0x0024, 0x4142, 0x0024, 0x4102, 0x0024, /* 2a20 */
  0x4192, 0x0024, 0x6892, 0x4053, 0x6018, 0x0fc5, 0x0000, 0x0503, /* 2a28 */
  0x2803, 0x6ac9, 0x4498, 0x0024, 0x2403, 0x6a84, 0x0000, 0x0024, /* 2a30 */
  0x3301, 0x0024, 0x6458, 0x0024, 0x0000, 0x0024, 0x2803, 0x7159, /* 2a38 */
  0x653a, 0x0c04, 0x6458, 0x0024, 0x0000, 0x0024, 0x2803, 0x70c8, /* 2a40 */
  0x0000, 0x0024, 0x33f1, 0x4024, 0x6192, 0x0024, 0x6284, 0x0024, /* 2a48 */
  0x0000, 0x3bc0, 0x2803, 0x6dc5, 0x0000, 0x0024, 0x3423, 0x0024, /* 2a50 */
  0x34a4, 0x0024, 0xf400, 0x4401, 0x4100, 0x1141, 0x4010, 0x0024, /* 2a58 */
  0xf400, 0x4010, 0x3009, 0x13c0, 0x3800, 0x0024, 0xb880, 0x1bcf, /* 2a60 */
  0x36f3, 0x580e, 0x36f4, 0x9813, 0x36f1, 0xd811, 0x36f1, 0x5806, /* 2a68 */
  0x36f0, 0xd804, 0x36f0, 0x5802, 0x3405, 0x9014, 0x36f3, 0x0024, /* 2a70 */
  0x36f2, 0x0024, 0x2000, 0x0000, 0x0000, 0x0024, 0x2803, 0x6a80, /* 2a78 */
  0x3bf1, 0x4024, 0x2803, 0x6a80, 0x33f1, 0x4024, 0xf400, 0x4412, /* 2a80 */
  0x32f3, 0x0024, 0x3200, 0x0024, 0x3810, 0x0024, 0x2803, 0x5940, /* 2a88 */
  0x3009, 0x3350, 0x3c10, 0x0024, 0x3cf0, 0x4024, 0x3009, 0x3040, /* 2a90 */
  0x3009, 0x33c1, 0xf400, 0x4510, 0xf400, 0x4511, 0x3493, 0x0024, /* 2a98 */
  0x34c3, 0x0024, 0x3470, 0x0024, 0x2903, 0xcf40, 0x4380, 0x4012, /* 2aa0 */
  0x3c01, 0x3245, 0x0000, 0x2005, 0xb888, 0x1000, 0x4030, 0x0024, /* 2aa8 */
  0x3c70, 0x0024, 0x0004, 0x0000, 0x3443, 0x0024, 0x4030, 0x9046, /* 2ab0 */
  0xf400, 0x4010, 0x3009, 0x0000, 0x3009, 0x12c7, 0x6fee, 0x0024, /* 2ab8 */
  0x0000, 0x0024, 0x2803, 0x84c1, 0x4fee, 0x1004, 0x3c00, 0x9005, /* 2ac0 */
  0xb8d6, 0xb103, 0x3411, 0x8024, 0xfee0, 0x12c7, 0x5e06, 0x0024, /* 2ac8 */
  0x4dd6, 0x0024, 0x4834, 0x4843, 0x4db6, 0x0024, 0x4db6, 0x0024, /* 2ad0 */
  0x4d82, 0x1002, 0x3cd0, 0x984c, 0x4c86, 0x9000, 0xb8fe, 0x10d0, /* 2ad8 */
  0xfea0, 0x0024, 0x560e, 0x0000, 0xb8d6, 0x0024, 0x4ffe, 0x0024, /* 2ae0 */
  0x487c, 0x48c7, 0x4fbe, 0x0024, 0x4fbe, 0x0024, 0xfee0, 0x0024, /* 2ae8 */
  0x5e06, 0x0024, 0x0000, 0x0100, 0x4dd6, 0x0024, 0x4834, 0x4843, /* 2af0 */
  0x4db6, 0x0024, 0x4db6, 0x0024, 0x4d8e, 0x0024, 0xad02, 0x1002, /* 2af8 */
  0x2903, 0xdbc0, 0x3009, 0x1303, 0xb78e, 0x108c, 0x408c, 0x1052, /* 2b00 */
  0x3263, 0x1010, 0x32a0, 0x0024, 0xf202, 0x0024, 0x461c, 0x0024, /* 2b08 */
  0x6802, 0x0024, 0xaf1e, 0x0024, 0xa600, 0x0024, 0x3810, 0x0024, /* 2b10 */
  0x3009, 0x33d0, 0x2803, 0x5940, 0x3ce4, 0x8024, 0xfee1, 0xc245, /* 2b18 */
  0xb8d6, 0xb003, 0x5e06, 0x0024, 0x0000, 0x0200, 0x4dd6, 0x0024, /* 2b20 */
  0x4834, 0x4843, 0x4db6, 0x0024, 0x4db6, 0x0024, 0x2803, 0x7c40, /* 2b28 */
  0xad02, 0x1002, 0x3410, 0x8024, 0x34b0, 0xc024, 0x3444, 0x0024, /* 2b30 */
  0x3043, 0x0024, 0x30c0, 0x0024, 0xfea0, 0x0024, 0x560a, 0x0024, /* 2b38 */
  0x4eea, 0x0024, 0x4858, 0x4885, 0x4eba, 0x0024, 0x4eba, 0x0024, /* 2b40 */
  0x3c11, 0x0024, 0x2803, 0x39c0, 0x3cb1, 0x4024, 0x2803, 0x4dc0, /* 2b48 */
  0x3450, 0x8024, 0x2803, 0x2740, 0x4000, 0x104c, 0x0007, 0x0001, /* 2b50 */
  0x8e2f, 0x0006, 0x0198, 0x3e12, 0x0024, 0x3e05, 0xb814, 0x3675, /* 2b58 */
  0x0024, 0x3e00, 0x7842, 0x0000, 0x0b02, 0x0000, 0x0801, 0x3e00, /* 2b60 */
  0xf844, 0x3e01, 0x7846, 0x3e01, 0xf851, 0xf400, 0x4411, 0xf400, /* 2b68 */
  0x4450, 0x3e04, 0xb853, 0x3e03, 0x784e, 0x3e13, 0xd2cc, 0x3410, /* 2b70 */
  0x0024, 0x6890, 0x3840, 0x3e10, 0x0024, 0x3410, 0x0024, 0x3e10, /* 2b78 */
  0x0024, 0x3410, 0x0024, 0x3e10, 0x0024, 0x3420, 0x0024, 0x2903, /* 2b80 */
  0x1fc0, 0x3e10, 0x0024, 0x3443, 0x1acc, 0x3c90, 0x0024, 0x34f3, /* 2b88 */
  0x0024, 0x3420, 0x0024, 0xfe10, 0x4450, 0x48b2, 0x01cc, 0x3450, /* 2b90 */
  0x404c, 0x4122, 0x0010, 0x0000, 0x4442, 0x410c, 0x0401, 0x3073, /* 2b98 */
  0x3001, 0xf400, 0x4441, 0x4122, 0x004c, 0x4102, 0x0024, 0xf400, /* 2ba0 */
  0x4052, 0x0000, 0x0080, 0x3c00, 0x1341, 0x6102, 0x0024, 0x0000, /* 2ba8 */
  0x0024, 0x2803, 0xaec9, 0x4192, 0x0024, 0x2403, 0xae81, 0x0000, /* 2bb0 */
  0x0024, 0x3000, 0x108c, 0x3cf0, 0x3012, 0xb386, 0x4452, 0x3c04, /* 2bb8 */
  0x49cc, 0xf400, 0x4411, 0x3213, 0x044c, 0x32e0, 0x584c, 0x3110, /* 2bc0 */
  0x810c, 0x4224, 0x0024, 0x4224, 0x0024, 0x4124, 0x0024, 0xf400, /* 2bc8 */
  0x4093, 0x3301, 0x4024, 0x3100, 0x8024, 0x4224, 0x0024, 0x4224, /* 2bd0 */
  0x0024, 0x4122, 0x0024, 0x4602, 0x4053, 0x3301, 0x0024, 0xf400, /* 2bd8 */
  0x4053, 0x3300, 0x8024, 0x3200, 0x4024, 0x681e, 0x0024, 0x001f, /* 2be0 */
  0xffc1, 0xad76, 0x0024, 0xb386, 0xb102, 0x4654, 0x3004, 0xf400, /* 2be8 */
  0x4093, 0x3300, 0xb305, 0xb214, 0x1111, 0xad76, 0x0024, 0x4646, /* 2bf0 */
  0x0024, 0xb58a, 0x40d3, 0x3300, 0xc024, 0xb316, 0x0024, 0xf400, /* 2bf8 */
  0x40c4, 0x0000, 0x0243, 0xae7a, 0x4447, 0x4482, 0x1004, 0x4736, /* 2c00 */
  0x9345, 0x4300, 0x93d2, 0x435a, 0x4013, 0x4346, 0x0c00, 0xf400, /* 2c08 */
  0x4153, 0x3301, 0xc024, 0x4788, 0x40d3, 0x4186, 0x0c05, 0x293c, /* 2c10 */
  0xac40, 0x3009, 0x13c1, 0x6104, 0x058c, 0xf026, 0x0024, 0x4336, /* 2c18 */
  0x0024, 0x6284, 0x0024, 0x0000, 0x4004, 0x2803, 0xa5d8, 0x408a, /* 2c20 */
  0x0024, 0x4396, 0x4005, 0x31a0, 0x8024, 0x6824, 0x0024, 0xa424, /* 2c28 */
  0x0024, 0x6204, 0x0024, 0x620e, 0x4084, 0x0000, 0x0024, 0x2803, /* 2c30 */
  0xa808, 0x0000, 0x0024, 0xf400, 0x4144, 0x4448, 0x0024, 0x634a, /* 2c38 */
  0x0024, 0x0000, 0x0024, 0x2803, 0xab08, 0x0000, 0x0024, 0x6396, /* 2c40 */
  0x0024, 0xf136, 0x0024, 0x620a, 0x0024, 0x0000, 0x0024, 0x2803, /* 2c48 */
  0xbe59, 0x0000, 0x0024, 0x4326, 0x0024, 0x6386, 0x2843, 0x3423, /* 2c50 */
  0x058c, 0x2803, 0xbcd5, 0x0000, 0x0024, 0x31a0, 0x0024, 0xa102, /* 2c58 */
  0x0024, 0x0020, 0x0000, 0xc012, 0x1380, 0x4600, 0x0024, 0xf400, /* 2c60 */
  0x4013, 0x3b00, 0x4024, 0x3433, 0x0024, 0x3400, 0x0024, 0x6090, /* 2c68 */
  0x0024, 0x3cd0, 0x0024, 0x0000, 0x0800, 0x34c3, 0x0024, 0x3420, /* 2c70 */
  0x4024, 0xfe02, 0x4450, 0x48b2, 0x1082, 0x0000, 0x0b01, 0x4212, /* 2c78 */
  0x01cc, 0x4100, 0x008c, 0x0020, 0x0001, 0x6890, 0x4013, 0x3011, /* 2c80 */
  0x0024, 0x3310, 0x8024, 0x3110, 0xc024, 0x603c, 0x0024, 0x0000, /* 2c88 */
  0x0024, 0x2803, 0xb698, 0x0000, 0x0024, 0x3300, 0xc7cc, 0xb31a, /* 2c90 */
  0x0024, 0x0000, 0x0024, 0x2803, 0xb5d5, 0x0000, 0x0024, 0x3001, /* 2c98 */
  0x534c, 0x3431, 0x984c, 0x2903, 0x14c0, 0xf400, 0x4192, 0x3001, /* 2ca0 */
  0x0024, 0x3300, 0x8024, 0x6090, 0x8c4c, 0x2803, 0xb1c0, 0x3013, /* 2ca8 */
  0x0024, 0x3121, 0x8024, 0x3100, 0x4024, 0x661e, 0x0024, 0x0000, /* 2cb0 */
  0x0024, 0x2803, 0xb949, 0x0000, 0x0024, 0x34d3, 0x184c, 0x6614, /* 2cb8 */
  0x10c0, 0x4010, 0x0024, 0x2902, 0xc240, 0x4280, 0x4010, 0x36f3, /* 2cc0 */
  0xd10c, 0x34c0, 0x180e, 0x36f3, 0x4024, 0x36f4, 0x9813, 0x36f1, /* 2cc8 */
  0xd811, 0x36f1, 0x5806, 0x36f0, 0xd804, 0x36f0, 0x5802, 0x3405, /* 2cd0 */
  0x9014, 0x36f3, 0x0024, 0x36f2, 0x0024, 0x2000, 0x0000, 0x0000, /* 2cd8 */
  0x0024, 0x3423, 0x058c, 0x31a0, 0x0024, 0xa100, 0x1381, 0x4612, /* 2ce0 */
  0x0024, 0xf400, 0x4053, 0x2803, 0xadc0, 0x3b00, 0x0024, 0x2803, /* 2ce8 */
  0xab00, 0x4306, 0x0024, 0x0007, 0x0001, 0x4bf2, 0x0006, 0x0200, /* 2cf0 */
  0x0000, 0x0000, 0x1db7, 0x04c1, 0x3b6e, 0x0982, 0x26d9, 0x0d43, /* 2cf8 */
  0x76dc, 0x1304, 0x6b6b, 0x17c5, 0x4db2, 0x1a86, 0x5005, 0x1e47, /* 2d00 */
  0xedb8, 0x2608, 0xf00f, 0x22c9, 0xd6d6, 0x2f8a, 0xcb61, 0x2b4b, /* 2d08 */
  0x9b64, 0x350c, 0x86d3, 0x31cd, 0xa00a, 0x3c8e, 0xbdbd, 0x384f, /* 2d10 */
  0xdb70, 0x4c11, 0xc6c7, 0x48d0, 0xe01e, 0x4593, 0xfda9, 0x4152, /* 2d18 */
  0xadac, 0x5f15, 0xb01b, 0x5bd4, 0x96c2, 0x5697, 0x8b75, 0x5256, /* 2d20 */
  0x36c8, 0x6a19, 0x2b7f, 0x6ed8, 0x0da6, 0x639b, 0x1011, 0x675a, /* 2d28 */
  0x4014, 0x791d, 0x5da3, 0x7ddc, 0x7b7a, 0x709f, 0x66cd, 0x745e, /* 2d30 */
  0xb6e0, 0x9823, 0xab57, 0x9ce2, 0x8d8e, 0x91a1, 0x9039, 0x9560, /* 2d38 */
  0xc03c, 0x8b27, 0xdd8b, 0x8fe6, 0xfb52, 0x82a5, 0xe6e5, 0x8664, /* 2d40 */
  0x5b58, 0xbe2b, 0x46ef, 0xbaea, 0x6036, 0xb7a9, 0x7d81, 0xb368, /* 2d48 */
  0x2d84, 0xad2f, 0x3033, 0xa9ee, 0x16ea, 0xa4ad, 0x0b5d, 0xa06c, /* 2d50 */
  0x6d90, 0xd432, 0x7027, 0xd0f3, 0x56fe, 0xddb0, 0x4b49, 0xd971, /* 2d58 */
  0x1b4c, 0xc736, 0x06fb, 0xc3f7, 0x2022, 0xceb4, 0x3d95, 0xca75, /* 2d60 */
  0x8028, 0xf23a, 0x9d9f, 0xf6fb, 0xbb46, 0xfbb8, 0xa6f1, 0xff79, /* 2d68 */
  0xf6f4, 0xe13e, 0xeb43, 0xe5ff, 0xcd9a, 0xe8bc, 0xd02d, 0xec7d, /* 2d70 */
  0x7077, 0x3486, 0x6dc0, 0x3047, 0x4b19, 0x3d04, 0x56ae, 0x39c5, /* 2d78 */
  0x06ab, 0x2782, 0x1b1c, 0x2343, 0x3dc5, 0x2e00, 0x2072, 0x2ac1, /* 2d80 */
  0x9dcf, 0x128e, 0x8078, 0x164f, 0xa6a1, 0x1b0c, 0xbb16, 0x1fcd, /* 2d88 */
  0xeb13, 0x018a, 0xf6a4, 0x054b, 0xd07d, 0x0808, 0xcdca, 0x0cc9, /* 2d90 */
  0xab07, 0x7897, 0xb6b0, 0x7c56, 0x9069, 0x7115, 0x8dde, 0x75d4, /* 2d98 */
  0xdddb, 0x6b93, 0xc06c, 0x6f52, 0xe6b5, 0x6211, 0xfb02, 0x66d0, /* 2da0 */
  0x46bf, 0x5e9f, 0x5b08, 0x5a5e, 0x7dd1, 0x571d, 0x6066, 0x53dc, /* 2da8 */
  0x3063, 0x4d9b, 0x2dd4, 0x495a, 0x0b0d, 0x4419, 0x16ba, 0x40d8, /* 2db0 */
  0xc697, 0xaca5, 0xdb20, 0xa864, 0xfdf9, 0xa527, 0xe04e, 0xa1e6, /* 2db8 */
  0xb04b, 0xbfa1, 0xadfc, 0xbb60, 0x8b25, 0xb623, 0x9692, 0xb2e2, /* 2dc0 */
  0x2b2f, 0x8aad, 0x3698, 0x8e6c, 0x1041, 0x832f, 0x0df6, 0x87ee, /* 2dc8 */
  0x5df3, 0x99a9, 0x4044, 0x9d68, 0x669d, 0x902b, 0x7b2a, 0x94ea, /* 2dd0 */
  0x1de7, 0xe0b4, 0x0050, 0xe475, 0x2689, 0xe936, 0x3b3e, 0xedf7, /* 2dd8 */
  0x6b3b, 0xf3b0, 0x768c, 0xf771, 0x5055, 0xfa32, 0x4de2, 0xfef3, /* 2de0 */
  0xf05f, 0xc6bc, 0xede8, 0xc27d, 0xcb31, 0xcf3e, 0xd686, 0xcbff, /* 2de8 */
  0x8683, 0xd5b8, 0x9b34, 0xd179, 0xbded, 0xdc3a, 0xa05a, 0xd8fb, /* 2df0 */
  0xe0ee, 0x690c, 0xfd59, 0x6dcd, 0xdb80, 0x608e, 0xc637, 0x644f, /* 2df8 */
  0x9632, 0x7a08, 0x8b85, 0x7ec9, 0xad5c, 0x738a, 0xb0eb, 0x774b, /* 2e00 */
  0x0d56, 0x4f04, 0x10e1, 0x4bc5, 0x3638, 0x4686, 0x2b8f, 0x4247, /* 2e08 */
  0x7b8a, 0x5c00, 0x663d, 0x58c1, 0x40e4, 0x5582, 0x5d53, 0x5143, /* 2e10 */
  0x3b9e, 0x251d, 0x2629, 0x21dc, 0x00f0, 0x2c9f, 0x1d47, 0x285e, /* 2e18 */
  0x4d42, 0x3619, 0x50f5, 0x32d8, 0x762c, 0x3f9b, 0x6b9b, 0x3b5a, /* 2e20 */
  0xd626, 0x0315, 0xcb91, 0x07d4, 0xed48, 0x0a97, 0xf0ff, 0x0e56, /* 2e28 */
  0xa0fa, 0x1011, 0xbd4d, 0x14d0, 0x9b94, 0x1993, 0x8623, 0x1d52, /* 2e30 */
  0x560e, 0xf12f, 0x4bb9, 0xf5ee, 0x6d60, 0xf8ad, 0x70d7, 0xfc6c, /* 2e38 */
  0x20d2, 0xe22b, 0x3d65, 0xe6ea, 0x1bbc, 0xeba9, 0x060b, 0xef68, /* 2e40 */
  0xbbb6, 0xd727, 0xa601, 0xd3e6, 0x80d8, 0xdea5, 0x9d6f, 0xda64, /* 2e48 */
  0xcd6a, 0xc423, 0xd0dd, 0xc0e2, 0xf604, 0xcda1, 0xebb3, 0xc960, /* 2e50 */
  0x8d7e, 0xbd3e, 0x90c9, 0xb9ff, 0xb610, 0xb4bc, 0xaba7, 0xb07d, /* 2e58 */
  0xfba2, 0xae3a, 0xe615, 0xaafb, 0xc0cc, 0xa7b8, 0xdd7b, 0xa379, /* 2e60 */
  0x60c6, 0x9b36, 0x7d71, 0x9ff7, 0x5ba8, 0x92b4, 0x461f, 0x9675, /* 2e68 */
  0x161a, 0x8832, 0x0bad, 0x8cf3, 0x2d74, 0x81b0, 0x30c3, 0x8571, /* 2e70 */
  0x9099, 0x5d8a, 0x8d2e, 0x594b, 0xabf7, 0x5408, 0xb640, 0x50c9, /* 2e78 */
  0xe645, 0x4e8e, 0xfbf2, 0x4a4f, 0xdd2b, 0x470c, 0xc09c, 0x43cd, /* 2e80 */
  0x7d21, 0x7b82, 0x6096, 0x7f43, 0x464f, 0x7200, 0x5bf8, 0x76c1, /* 2e88 */
  0x0bfd, 0x6886, 0x164a, 0x6c47, 0x3093, 0x6104, 0x2d24, 0x65c5, /* 2e90 */
  0x4be9, 0x119b, 0x565e, 0x155a, 0x7087, 0x1819, 0x6d30, 0x1cd8, /* 2e98 */
  0x3d35, 0x029f, 0x2082, 0x065e, 0x065b, 0x0b1d, 0x1bec, 0x0fdc, /* 2ea0 */
  0xa651, 0x3793, 0xbbe6, 0x3352, 0x9d3f, 0x3e11, 0x8088, 0x3ad0, /* 2ea8 */
  0xd08d, 0x2497, 0xcd3a, 0x2056, 0xebe3, 0x2d15, 0xf654, 0x29d4, /* 2eb0 */
  0x2679, 0xc5a9, 0x3bce, 0xc168, 0x1d17, 0xcc2b, 0x00a0, 0xc8ea, /* 2eb8 */
  0x50a5, 0xd6ad, 0x4d12, 0xd26c, 0x6bcb, 0xdf2f, 0x767c, 0xdbee, /* 2ec0 */
  0xcbc1, 0xe3a1, 0xd676, 0xe760, 0xf0af, 0xea23, 0xed18, 0xeee2, /* 2ec8 */
  0xbd1d, 0xf0a5, 0xa0aa, 0xf464, 0x8673, 0xf927, 0x9bc4, 0xfde6, /* 2ed0 */
  0xfd09, 0x89b8, 0xe0be, 0x8d79, 0xc667, 0x803a, 0xdbd0, 0x84fb, /* 2ed8 */
  0x8bd5, 0x9abc, 0x9662, 0x9e7d, 0xb0bb, 0x933e, 0xad0c, 0x97ff, /* 2ee0 */
  0x10b1, 0xafb0, 0x0d06, 0xab71, 0x2bdf, 0xa632, 0x3668, 0xa2f3, /* 2ee8 */
  0x666d, 0xbcb4, 0x7bda, 0xb875, 0x5d03, 0xb536, 0x40b4, 0xb1f7, /* 2ef0 */
  0x0007, 0x0001, 0x8efb, 0x0006, 0x0022, 0x3e14, 0x7813, 0x3e13, /* 2ef8 */
  0x7801, 0x3e10, 0xb803, 0x3e03, 0xf80e, 0x0000, 0x0051, 0x0000, /* 2f00 */
  0x0053, 0x4090, 0x0024, 0x2403, 0xc180, 0x3200, 0x8a03, 0x3000, /* 2f08 */
  0x0001, 0x4cd3, 0x222b, 0x3800, 0x2201, 0x36f3, 0xd80e, 0x36f0, /* 2f10 */
  0x9803, 0x36f3, 0x5801, 0x2000, 0x0000, 0x36f4, 0x5813, 0x0007, /* 2f18 */
  0x0001, 0x8f0c, 0x0006, 0x0022, 0x3e14, 0x7813, 0x3e13, 0x7801, /* 2f20 */
  0x3e10, 0xb803, 0x3e03, 0xf80e, 0x0000, 0x0051, 0x0000, 0x0053, /* 2f28 */
  0x4090, 0x0024, 0x2403, 0xc5c0, 0x3200, 0x8a03, 0x3000, 0x0001, /* 2f30 */
  0x6cd3, 0x222b, 0x3800, 0x2201, 0x36f3, 0xd80e, 0x36f0, 0x9803, /* 2f38 */
  0x36f3, 0x5801, 0x2000, 0x0000, 0x36f4, 0x5813, 0x0007, 0x0001, /* 2f40 */
  0x8f1d, 0x0006, 0x0040, 0x3e14, 0x7801, 0x3e11, 0x3805, 0x3e11, /* 2f48 */
  0xb807, 0x3e13, 0xf80e, 0x3e12, 0xb80d, 0x0000, 0x800a, 0x6824, /* 2f50 */
  0x0024, 0xf108, 0x4015, 0x0030, 0x0001, 0xc142, 0x4417, 0x4090, /* 2f58 */
  0x17cc, 0x2403, 0xcac0, 0xf400, 0x4051, 0x3000, 0x1c01, 0x3880, /* 2f60 */
  0x7c40, 0x3e05, 0x0024, 0x0000, 0x0051, 0xf400, 0x4414, 0xbf8f, /* 2f68 */
  0x0900, 0xac2a, 0x0024, 0x2403, 0xcd55, 0x0000, 0x0055, 0x8e8a, /* 2f70 */
  0x0024, 0x68eb, 0x0900, 0xac2b, 0xccc5, 0xb080, 0x1bd4, 0x36f2, /* 2f78 */
  0x980d, 0x36f3, 0xd80e, 0x36f1, 0x9807, 0x36f1, 0x1805, 0x2000, /* 2f80 */
  0x0000, 0x36f4, 0x5801, 0x0007, 0x0001, 0x1220, 0x0006, 0x0200, /* 2f88 */
  0x8f47, 0x0002, 0x8689, 0x0002, 0xfca6, 0x0003, 0xed3c, 0x0003, /* 2f90 */
  0xdec2, 0x0003, 0xd12a, 0x0003, 0xc467, 0x0003, 0xb86b, 0x0003, /* 2f98 */
  0xad2a, 0x0003, 0xa299, 0x0003, 0x98ad, 0x0003, 0x8f5c, 0x0003, /* 2fa0 */
  0x869c, 0x0003, 0xfccb, 0x0004, 0xed5e, 0x0004, 0xdee2, 0x0004, /* 2fa8 */
  0xd149, 0x0004, 0xc483, 0x0004, 0xb886, 0x0004, 0xad43, 0x0004, /* 2fb0 */
  0xa2b1, 0x0004, 0x98c3, 0x0004, 0x8f71, 0x0004, 0x86b0, 0x0004, /* 2fb8 */
  0xfcf0, 0x0005, 0xed81, 0x0005, 0xdf03, 0x0005, 0xd167, 0x0005, /* 2fc0 */
  0xc4a0, 0x0005, 0xb8a1, 0x0005, 0xad5d, 0x0005, 0xa2c9, 0x0005, /* 2fc8 */
  0x98da, 0x0005, 0x8f86, 0x0005, 0x86c4, 0x0005, 0xfd16, 0x0006, /* 2fd0 */
  0xeda4, 0x0006, 0xdf24, 0x0006, 0xd186, 0x0006, 0xc4bd, 0x0006, /* 2fd8 */
  0xb8bc, 0x0006, 0xad76, 0x0006, 0xa2e0, 0x0006, 0x98f0, 0x0006, /* 2fe0 */
  0x8f9b, 0x0006, 0x86d8, 0x0006, 0xfd3b, 0x0007, 0xedc7, 0x0007, /* 2fe8 */
  0xdf45, 0x0007, 0xd1a5, 0x0007, 0xc4da, 0x0007, 0xb8d7, 0x0007, /* 2ff0 */
  0xad90, 0x0007, 0xa2f8, 0x0007, 0x9907, 0x0007, 0x8fb0, 0x0007, /* 2ff8 */
  0x86eb, 0x0007, 0xfd60, 0x0008, 0xedea, 0x0008, 0xdf65, 0x0008, /* 3000 */
  0xd1c4, 0x0008, 0xc4f7, 0x0008, 0xb8f2, 0x0008, 0xada9, 0x0008, /* 3008 */
  0xa310, 0x0008, 0x991d, 0x0008, 0x8fc5, 0x0008, 0x86ff, 0x0008, /* 3010 */
  0xfd85, 0x0009, 0xee0d, 0x0009, 0xdf86, 0x0009, 0xd1e2, 0x0009, /* 3018 */
  0xc514, 0x0009, 0xb90d, 0x0009, 0xadc2, 0x0009, 0xa328, 0x0009, /* 3020 */
  0x9933, 0x0009, 0x8fda, 0x0009, 0x8713, 0x0009, 0xfdaa, 0x000a, /* 3028 */
  0xee30, 0x000a, 0xdfa7, 0x000a, 0xd201, 0x000a, 0xc531, 0x000a, /* 3030 */
  0xb928, 0x000a, 0xaddc, 0x000a, 0xa340, 0x000a, 0x994a, 0x000a, /* 3038 */
  0x8fef, 0x000a, 0x8727, 0x000a, 0xfdcf, 0x000b, 0xee53, 0x000b, /* 3040 */
  0xdfc8, 0x000b, 0xd220, 0x000b, 0xc54e, 0x000b, 0xb943, 0x000b, /* 3048 */
  0xadf5, 0x000b, 0xa358, 0x000b, 0x9960, 0x000b, 0x9004, 0x000b, /* 3050 */
  0x873b, 0x000b, 0xfdf5, 0x000c, 0xee75, 0x000c, 0xdfe8, 0x000c, /* 3058 */
  0xd23f, 0x000c, 0xc56a, 0x000c, 0xb95f, 0x000c, 0xae0f, 0x000c, /* 3060 */
  0xa370, 0x000c, 0x9977, 0x000c, 0x901a, 0x000c, 0x874f, 0x000c, /* 3068 */
  0xfe1a, 0x000d, 0xee98, 0x000d, 0xe009, 0x000d, 0xd25e, 0x000d, /* 3070 */
  0xc587, 0x000d, 0xb97a, 0x000d, 0xae28, 0x000d, 0xa388, 0x000d, /* 3078 */
  0x998d, 0x000d, 0x902f, 0x000d, 0x8762, 0x000d, 0xfe3f, 0x000e, /* 3080 */
  0xeebb, 0x000e, 0xe02a, 0x000e, 0xd27c, 0x000e, 0xc5a4, 0x000e, /* 3088 */
  0xb995, 0x000e, 0xae42, 0x000e, 0xa3a0, 0x000e, 0x99a4, 0x000e, /* 3090 */
  0x9044, 0x000e, 0x8776, 0x000e, 0xfe64, 0x000f, 0xeede, 0x000f, /* 3098 */
  0xe04b, 0x000f, 0xd29b, 0x000f, 0xc5c1, 0x000f, 0xb9b0, 0x000f, /* 30a0 */
  0xae5c, 0x000f, 0xa3b8, 0x000f, 0x99ba, 0x000f, 0x9059, 0x000f, /* 30a8 */
  0x878a, 0x000f, 0xfe8a, 0x0010, 0xef02, 0x0010, 0xe06c, 0x0010, /* 30b0 */
  0xd2ba, 0x0010, 0xc5de, 0x0010, 0xb9cb, 0x0010, 0xae75, 0x0010, /* 30b8 */
  0xa3d0, 0x0010, 0x99d1, 0x0010, 0x906e, 0x0010, 0x879e, 0x0010, /* 30c0 */
  0xfeaf, 0x0011, 0xef25, 0x0011, 0xe08d, 0x0011, 0xd2d9, 0x0011, /* 30c8 */
  0xc5fb, 0x0011, 0xb9e7, 0x0011, 0xae8f, 0x0011, 0xa3e8, 0x0011, /* 30d0 */
  0x99e8, 0x0011, 0x9083, 0x0011, 0x87b2, 0x0011, 0xfed4, 0x0012, /* 30d8 */
  0xef48, 0x0012, 0xe0ae, 0x0012, 0xd2f8, 0x0012, 0xc618, 0x0012, /* 30e0 */
  0xba02, 0x0012, 0xaea8, 0x0012, 0xa400, 0x0012, 0x99fe, 0x0012, /* 30e8 */
  0x9099, 0x0012, 0x87c6, 0x0012, 0xfefa, 0x0013, 0xef6b, 0x0013, /* 30f0 */
  0xe0cf, 0x0013, 0xd317, 0x0013, 0xc636, 0x0013, 0xba1d, 0x0013, /* 30f8 */
  0xaec2, 0x0013, 0xa418, 0x0013, 0x9a15, 0x0013, 0x90ae, 0x0013, /* 3100 */
  0x87da, 0x0013, 0xff1f, 0x0014, 0xef8e, 0x0014, 0xe0f0, 0x0014, /* 3108 */
  0xd336, 0x0014, 0xc653, 0x0014, 0xba39, 0x0014, 0xaedc, 0x0014, /* 3110 */
  0xa430, 0x0014, 0x9a2b, 0x0014, 0x90c3, 0x0014, 0x87ee, 0x0014, /* 3118 */
  0xff45, 0x0015, 0xefb1, 0x0015, 0xe111, 0x0015, 0xd355, 0x0015, /* 3120 */
  0xc670, 0x0015, 0xba54, 0x0015, 0xaef5, 0x0015, 0xa448, 0x0015, /* 3128 */
  0x9a42, 0x0015, 0x90d8, 0x0015, 0x8802, 0x0015, 0xff6a, 0x0016, /* 3130 */
  0xefd4, 0x0016, 0xe132, 0x0016, 0xd374, 0x0016, 0xc68d, 0x0016, /* 3138 */
  0xba6f, 0x0016, 0xaf0f, 0x0016, 0xa460, 0x0016, 0x9a59, 0x0016, /* 3140 */
  0x90ed, 0x0016, 0x8816, 0x0016, 0xff8f, 0x0017, 0xeff7, 0x0017, /* 3148 */
  0xe153, 0x0017, 0xd393, 0x0017, 0xc6aa, 0x0017, 0xba8b, 0x0017, /* 3150 */
  0xaf29, 0x0017, 0xa478, 0x0017, 0x9a6f, 0x0017, 0x9103, 0x0017, /* 3158 */
  0x8829, 0x0017, 0xffb5, 0x0018, 0xf01b, 0x0018, 0xe174, 0x0018, /* 3160 */
  0xd3b2, 0x0018, 0xc6c7, 0x0018, 0xbaa6, 0x0018, 0xaf42, 0x0018, /* 3168 */
  0xa491, 0x0018, 0x9a86, 0x0018, 0x9118, 0x0018, 0x883d, 0x0018, /* 3170 */
  0xffda, 0x0019, 0xf03e, 0x0019, 0xe195, 0x0019, 0xd3d1, 0x0019, /* 3178 */
  0xc6e4, 0x0019, 0xbac1, 0x0019, 0xaf5c, 0x0019, 0xa4a9, 0x0019, /* 3180 */
  0x9a9c, 0x0019, 0x912d, 0x0019, 0x8851, 0x0019, 0x8000, 0x0019, /* 3188 */
  0x0007, 0x0001, 0x5000, 0x0006, 0x0199, 0x7ffc, 0x7ffc, 0x4000, /* 3190 */
  0x2aaa, 0x2000, 0x1999, 0x1555, 0x1249, 0x1000, 0x0e38, 0x0ccc, /* 3198 */
  0x0ba2, 0x0aaa, 0x09d8, 0x0924, 0x0888, 0x0800, 0x0787, 0x071c, /* 31a0 */
  0x06bc, 0x0666, 0x0618, 0x05d1, 0x0590, 0x0555, 0x051e, 0x04ec, /* 31a8 */
  0x04bd, 0x0492, 0x0469, 0x0444, 0x0421, 0x0400, 0x03e0, 0x03c3, /* 31b0 */
  0x03a8, 0x038e, 0x0375, 0x035e, 0x0348, 0x0333, 0x031f, 0x030c, /* 31b8 */
  0x02fa, 0x02e8, 0x02d8, 0x02c8, 0x02b9, 0x02aa, 0x029c, 0x028f, /* 31c0 */
  0x0282, 0x0276, 0x026a, 0x025e, 0x0253, 0x0249, 0x023e, 0x0234, /* 31c8 */
  0x022b, 0x0222, 0x0219, 0x0210, 0x0208, 0x01ff, 0x01f7, 0x01f0, /* 31d0 */
  0x01e9, 0x01e2, 0x01da, 0x01d4, 0x01cd, 0x01c7, 0x01c0, 0x01ba, /* 31d8 */
  0x01b4, 0x01af, 0x01a9, 0x01a4, 0x019e, 0x0199, 0x0194, 0x018f, /* 31e0 */
  0x018a, 0x0185, 0x0181, 0x017d, 0x0178, 0x0174, 0x0170, 0x016c, /* 31e8 */
  0x0168, 0x0164, 0x0160, 0x015c, 0x0159, 0x0155, 0x0151, 0x014e, /* 31f0 */
  0x014a, 0x0147, 0x0144, 0x0141, 0x013e, 0x013b, 0x0137, 0x0135, /* 31f8 */
  0x0132, 0x012f, 0x012c, 0x0129, 0x0127, 0x0124, 0x0121, 0x011f, /* 3200 */
  0x011d, 0x011a, 0x0118, 0x0115, 0x0113, 0x0110, 0x010e, 0x010c, /* 3208 */
  0x010a, 0x0108, 0x0106, 0x0104, 0x0101, 0x00ff, 0x00fd, 0x00fb, /* 3210 */
  0x00fa, 0x00f8, 0x00f6, 0x00f4, 0x00f2, 0x00f0, 0x00ef, 0x00ed, /* 3218 */
  0x00eb, 0x00e9, 0x00e8, 0x00e6, 0x00e5, 0x00e3, 0x00e2, 0x00e0, /* 3220 */
  0x00de, 0x00dd, 0x00db, 0x00da, 0x00d8, 0x00d7, 0x00d6, 0x00d4, /* 3228 */
  0x00d3, 0x00d2, 0x00d0, 0x00cf, 0x00ce, 0x00cc, 0x00cb, 0x00ca, /* 3230 */
  0x00c8, 0x00c7, 0x00c6, 0x00c5, 0x00c4, 0x00c2, 0x00c1, 0x00c0, /* 3238 */
  0x00bf, 0x00be, 0x00bd, 0x00bc, 0x00bb, 0x00ba, 0x00b9, 0x00b8, /* 3240 */
  0x00b7, 0x00b6, 0x00b4, 0x00b3, 0x00b2, 0x00b1, 0x00b1, 0x00b0, /* 3248 */
  0x00af, 0x00ae, 0x00ad, 0x00ac, 0x00ab, 0x00aa, 0x00a9, 0x00a8, /* 3250 */
  0x00a8, 0x00a7, 0x00a6, 0x00a5, 0x00a4, 0x00a3, 0x00a3, 0x00a2, /* 3258 */
  0x00a1, 0x00a0, 0x009f, 0x009e, 0x009e, 0x009d, 0x009c, 0x009b, /* 3260 */
  0x009b, 0x009a, 0x0099, 0x0099, 0x0098, 0x0097, 0x0097, 0x0096, /* 3268 */
  0x0095, 0x0095, 0x0094, 0x0093, 0x0092, 0x0092, 0x0091, 0x0090, /* 3270 */
  0x0090, 0x008f, 0x008f, 0x008e, 0x008d, 0x008d, 0x008c, 0x008b, /* 3278 */
  0x008b, 0x008a, 0x008a, 0x0089, 0x0088, 0x0088, 0x0087, 0x0087, /* 3280 */
  0x0087, 0x0086, 0x0085, 0x0085, 0x0084, 0x0084, 0x0083, 0x0083, /* 3288 */
  0x0082, 0x0082, 0x0081, 0x0081, 0x0080, 0x0080, 0x007f, 0x007f, /* 3290 */
  0x007e, 0x007e, 0x007d, 0x007d, 0x007c, 0x007c, 0x007b, 0x007b, /* 3298 */
  0x007a, 0x007a, 0x0079, 0x0079, 0x0078, 0x0078, 0x0077, 0x0077, /* 32a0 */
  0x0077, 0x0076, 0x0076, 0x0075, 0x0075, 0x0074, 0x0074, 0x0074, /* 32a8 */
  0x0073, 0x0073, 0x0073, 0x0072, 0x0072, 0x0071, 0x0071, 0x0071, /* 32b0 */
  0x0070, 0x0070, 0x006f, 0x006f, 0x006f, 0x006e, 0x006e, 0x006e, /* 32b8 */
  0x006d, 0x006d, 0x006c, 0x006c, 0x006c, 0x006b, 0x006b, 0x006b, /* 32c0 */
  0x006a, 0x006a, 0x006a, 0x0069, 0x0069, 0x0069, 0x0068, 0x0068, /* 32c8 */
  0x0067, 0x0067, 0x0067, 0x0066, 0x0066, 0x0066, 0x0066, 0x0065, /* 32d0 */
  0x0065, 0x0065, 0x0064, 0x0064, 0x0064, 0x0063, 0x0063, 0x0063, /* 32d8 */
  0x0062, 0x0062, 0x0062, 0x0061, 0x0061, 0x0061, 0x0061, 0x0060, /* 32e0 */
  0x0060, 0x0060, 0x0060, 0x005f, 0x005f, 0x005f, 0x005f, 0x005e, /* 32e8 */
  0x005e, 0x005e, 0x005e, 0x005d, 0x005d, 0x005d, 0x005c, 0x005c, /* 32f0 */
  0x005c, 0x005c, 0x005b, 0x005b, 0x005b, 0x005b, 0x005a, 0x005a, /* 32f8 */
  0x005a, 0x005a, 0x0059, 0x0059, 0x0059, 0x0059, 0x0058, 0x0058, /* 3300 */
  0x0058, 0x0058, 0x0057, 0x0057, 0x0057, 0x0057, 0x0056, 0x0056, /* 3308 */
  0x0056, 0x0056, 0x0055, 0x0055, 0x0055, 0x0055, 0x0055, 0x0054, /* 3310 */
  0x0054, 0x0054, 0x0054, 0x0053, 0x0053, 0x0053, 0x0053, 0x0053, /* 3318 */
  0x0052, 0x0052, 0x0052, 0x0052, 0x0052, 0x0051, 0x0051, 0x0051, /* 3320 */
  0x0051, 0x0051, 0x0050, 0x0050, 0x0050, 0x0050, 0x0006, 0x8006, /* 3328 */
  0x004f, 0x0006, 0x0005, 0x004e, 0x004e, 0x004e, 0x004e, 0x004e, /* 3330 */
  0x0006, 0x8007, 0x004d, 0x0006, 0x0005, 0x004c, 0x004c, 0x004c, /* 3338 */
  0x004c, 0x004c, 0x0006, 0x8006, 0x004b, 0x0006, 0x8006, 0x004a, /* 3340 */
  0x0006, 0x8006, 0x0049, 0x0006, 0x8006, 0x0048, 0x0006, 0x8006, /* 3348 */
  0x0047, 0x0006, 0x8007, 0x0046, 0x0006, 0x8007, 0x0045, 0x0006, /* 3350 */
  0x8006, 0x0044, 0x0006, 0x8007, 0x0043, 0x0006, 0x8008, 0x0042, /* 3358 */
  0x0006, 0x8007, 0x0041, 0x0006, 0x8008, 0x0040, 0x0006, 0x8008, /* 3360 */
  0x003f, 0x0006, 0x8008, 0x003e, 0x0006, 0x8009, 0x003d, 0x0006, /* 3368 */
  0x8008, 0x003c, 0x0006, 0x800a, 0x003b, 0x0006, 0x8009, 0x003a, /* 3370 */
  0x0006, 0x800d, 0x0039, 0x0006, 0x800a, 0x0038, 0x0006, 0x800b, /* 3378 */
  0x0037, 0x0006, 0x800a, 0x0036, 0x0006, 0x800c, 0x0035, 0x0006, /* 3380 */
  0x800b, 0x0034, 0x0006, 0x800d, 0x0033, 0x0006, 0x800c, 0x0032, /* 3388 */
  0x0006, 0x800d, 0x0031, 0x0006, 0x800e, 0x0030, 0x0006, 0x800e, /* 3390 */
  0x002f, 0x0006, 0x800f, 0x002e, 0x0006, 0x8010, 0x002d, 0x0006, /* 3398 */
  0x8010, 0x002c, 0x0006, 0x8011, 0x002b, 0x0006, 0x8012, 0x002a, /* 33a0 */
  0x0006, 0x8012, 0x0029, 0x0006, 0x8014, 0x0028, 0x0006, 0x8014, /* 33a8 */
  0x0027, 0x0006, 0x801d, 0x0026, 0x0006, 0x8017, 0x0025, 0x0006, /* 33b0 */
  0x8019, 0x0024, 0x0006, 0x8019, 0x0023, 0x0006, 0x801c, 0x0022, /* 33b8 */
  0x0006, 0x801d, 0x0021, 0x0006, 0x801c, 0x0020, 0x0006, 0x0080, /* 33c0 */
  0x4000, 0x4206, 0x440c, 0x460f, 0x480f, 0x4a0c, 0x4c03, 0x4df4, /* 33c8 */
  0x4fdf, 0x51c2, 0x539c, 0x556e, 0x5735, 0x58f2, 0x5aa5, 0x5c4c, /* 33d0 */
  0x5de7, 0x5f77, 0x60fa, 0x6271, 0x63db, 0x6538, 0x6689, 0x67ce, /* 33d8 */
  0x6906, 0x6a31, 0x6b50, 0x6c63, 0x6d6b, 0x6e66, 0x6f57, 0x703c, /* 33e0 */
  0x7117, 0x71e7, 0x72ae, 0x736a, 0x741e, 0x74c8, 0x756a, 0x7603, /* 33e8 */
  0x7694, 0x771e, 0x77a0, 0x781c, 0x7890, 0x78ff, 0x7967, 0x79ca, /* 33f0 */
  0x7a27, 0x7a7f, 0x7ad2, 0x7b20, 0x7b6a, 0x7baf, 0x7bf1, 0x7c2f, /* 33f8 */
  0x7c69, 0x7ca0, 0x7cd4, 0x7d04, 0x7d32, 0x7d5d, 0x7d86, 0x7dac, /* 3400 */
  0x7dd0, 0x7df2, 0x7e11, 0x7e2f, 0x7e4b, 0x7e66, 0x7e7e, 0x7e96, /* 3408 */
  0x7eac, 0x7ec1, 0x7ed4, 0x7ee6, 0x7ef7, 0x7f07, 0x7f17, 0x7f25, /* 3410 */
  0x7f32, 0x7f3e, 0x7f4a, 0x7f55, 0x7f60, 0x7f69, 0x7f73, 0x7f7b, /* 3418 */
  0x7f83, 0x7f8b, 0x7f92, 0x7f99, 0x7f9f, 0x7fa5, 0x7fab, 0x7fb0, /* 3420 */
  0x7fb4, 0x7fb9, 0x7fbe, 0x7fc2, 0x7fc5, 0x7fc9, 0x7fcc, 0x7fcf, /* 3428 */
  0x7fd2, 0x7fd5, 0x7fd8, 0x7fda, 0x7fdc, 0x7fdf, 0x7fe1, 0x7fe2, /* 3430 */
  0x7fe4, 0x7fe6, 0x7fe8, 0x7fe9, 0x7fea, 0x7fec, 0x7fed, 0x7fee, /* 3438 */
  0x7fef, 0x7ff0, 0x7ff1, 0x7ff2, 0x7ff3, 0x7ff3, 0x7ff4, 0x7ff5, /* 3440 */
  0x0007, 0x0001, 0x8f3d, 0x0006, 0x0020, 0x3e10, 0xb803, 0x3e13, /* 3448 */
  0xf80e, 0x4090, 0xb801, 0xbd86, 0x380d, 0x2403, 0xd100, 0x3200, /* 3450 */
  0x0801, 0xf0c2, 0x084c, 0x4dc7, 0x2021, 0x0fff, 0xfe00, 0xad02, /* 3458 */
  0x0024, 0x3810, 0xa440, 0x3800, 0xe401, 0x36f3, 0x5801, 0x36f3, /* 3460 */
  0xd80e, 0x2000, 0x0000, 0x36f0, 0x9803, 0x0007, 0x0001, 0x8f4d, /* 3468 */
  0x0006, 0x0044, 0x3e14, 0x3812, 0x3e11, 0xb807, 0x3e13, 0xf80e, /* 3470 */
  0x4000, 0x384d, 0x4112, 0x0024, 0x4295, 0xe0e1, 0x0000, 0x0600, /* 3478 */
  0x2803, 0xd9c4, 0x3301, 0x8c07, 0xf5f2, 0x0024, 0x6102, 0x0024, /* 3480 */
  0xaf1e, 0x044c, 0x2403, 0xda02, 0xb284, 0x0024, 0x6812, 0x07c7, /* 3488 */
  0x6172, 0x0447, 0xfefc, 0x0024, 0x48be, 0x0024, 0xaf1e, 0x0024, /* 3490 */
  0xf7fe, 0x0024, 0x4244, 0x2c07, 0x625c, 0xac63, 0x3301, 0x8c07, /* 3498 */
  0x2803, 0xd9c8, 0xf5f2, 0x9810, 0x6254, 0x1810, 0x6102, 0x0024, /* 34a0 */
  0xaf1e, 0x060c, 0x36f3, 0x0024, 0x36f3, 0x4024, 0x36f3, 0xd80e, /* 34a8 */
  0x36f1, 0x9807, 0x2000, 0x0000, 0x36f4, 0x1812, 0x0007, 0x0001, /* 34b0 */
  0x8f6f, 0x0006, 0x0040, 0x3e14, 0x3804, 0x3e13, 0x7801, 0x3e10, /* 34b8 */
  0xb803, 0x3e11, 0xb807, 0x3e03, 0xf80e, 0x0037, 0x9550, 0x0000, /* 34c0 */
  0x0182, 0xac22, 0x0024, 0x0000, 0x2002, 0x0000, 0x018e, 0x2403, /* 34c8 */
  0xe08e, 0xf400, 0x4403, 0x3011, 0x8024, 0x4328, 0x0007, 0x6fce, /* 34d0 */
  0x0024, 0x0000, 0x0024, 0x2803, 0xe081, 0x6326, 0x0024, 0x4486, /* 34d8 */
  0x0024, 0xf224, 0x40d0, 0x3011, 0x8024, 0x3011, 0xd80e, 0x6fc2, /* 34e0 */
  0x1bcf, 0x0037, 0x5542, 0x2803, 0xe281, 0x36f1, 0x9807, 0xf400, /* 34e8 */
  0x4403, 0x6320, 0x9803, 0xf200, 0x1bc2, 0x36f3, 0x5801, 0x2000, /* 34f0 */
  0x0000, 0x36f4, 0x1804, 0x0007, 0x0001, 0x8f8f, 0x0006, 0x000a, /* 34f8 */
  0x0000, 0x0200, 0xb386, 0x3803, 0xad06, 0x0024, 0x2000, 0x0000, /* 3500 */
  0xc320, 0x1bc3, 0x0007, 0x0001, 0x8f94, 0x0006, 0x0016, 0xb69e, /* 3508 */
  0x41c6, 0x3e00, 0xb803, 0x0fff, 0xfe03, 0x0000, 0x3fc2, 0xaf32, /* 3510 */
  0x4083, 0xbcd2, 0x0024, 0xbfde, 0x9803, 0x0000, 0x0202, 0xaf2e, /* 3518 */
  0x1bc2, 0x2000, 0x0000, 0xccf2, 0x0024, 0x0007, 0x0001, 0x8f9f, /* 3520 */
  0x0006, 0x0018, 0x4080, 0x184c, 0x3e13, 0x780f, 0x2803, 0xe9c5, /* 3528 */
  0x4090, 0xb80e, 0x2403, 0xe940, 0x3e04, 0x0440, 0x3810, 0x0440, /* 3530 */
  0x3604, 0x0024, 0x3009, 0x1bce, 0x3603, 0x5bcf, 0x2000, 0x0000, /* 3538 */
  0x0000, 0x0024, 0x0007, 0x0001, 0x8fab, 0x0006, 0x0024, 0x4298, /* 3540 */
  0x4117, 0x0fff, 0xfc04, 0x2803, 0xed18, 0x6248, 0x4041, 0x0000, /* 3548 */
  0x0024, 0x2803, 0xeec8, 0x0000, 0x0024, 0x2000, 0x0000, 0xac22, /* 3550 */
  0x45c4, 0x4c82, 0x45c4, 0x003f, 0xffc0, 0x2000, 0x0014, 0xf292, /* 3558 */
  0x0024, 0x0000, 0x0000, 0x2000, 0x0000, 0x0020, 0x0001, 0x2000, /* 3560 */
  0x0000, 0xbc82, 0x45c4,
#ifndef SKIP_PLUGIN_VARNAME
};
#endif
#endif




#endif
